#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2021 Mopi
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# A Dance of Fire and Ice
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220808.2

GAME_ID='a-dance-of-fire-and-ice'
GAME_NAME='A Dance of Fire and Ice'

ARCHIVE_BASE_0='a-dance-of-fire-and-ice-win.zip'
ARCHIVE_BASE_0_MD5='bfbd66a50119e8b13d35362eb408759f'
ARCHIVE_BASE_0_SIZE='640000'
ARCHIVE_BASE_0_VERSION='1.0-itch1'
ARCHIVE_BASE_0_URL='https://fizzd.itch.io/a-dance-of-fire-and-ice'

CONTENT_PATH_DEFAULT='.'
ARCHIVE_GAME_BIN_FILES='
A?Dance?of?Fire?and?Ice.exe
MonoBleedingEdge
UnityCrashHandler64.exe
UnityPlayer.dll'
ARCHIVE_GAME_DATA_FILES='
A?Dance?of?Fire?and?Ice_Data'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='A Dance of Fire and Ice.exe'
APP_MAIN_ICON='A Dance of Fire and Ice.exe'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID wine"

# Use persistent storage for user data

USER_PERSISTENT_DIRECTORIES='
User'
WINE_REGEDIT_PERSISTENT_KEYS='
HKEY_CURRENT_USER\Software\7th Beat Games\A Dance of Fire and Ice'

# Load common functions

target_version='2.18'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
