#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2019 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# A New Beginning
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220727.1

# Set game-specific variables

GAME_ID='a-new-beginning'
GAME_NAME='A New Beginning'

ARCHIVE_BASE_0='setup_a_new_beginning_final_cut_2.0.4.0395_(27805).exe'
ARCHIVE_BASE_0_MD5='f914a4260284285461fa9b3cc06b88ec'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1='setup_a_new_beginning_final_cut_2.0.4.0395_(27805)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='68520b98ded6409f0c17c0204c342a45'
ARCHIVE_BASE_0_SIZE='4200000'
ARCHIVE_BASE_0_VERSION='2.0.4.0395-gog27805'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/a_new_beginning'

CONTENT_PATH_DEFAULT='.'
ARCHIVE_DOC_DATA_FILES='
*.pdf'
ARCHIVE_GAME_BIN_FILES='
*.dll
*.ini
anb.exe
VisionaireConfigurationTool.exe'
ARCHIVE_GAME_DATA_FILES='
*.jpg
*.vis
*.xml
characters
documents
scenes
videos'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='anb.exe'
APP_MAIN_ICON="${CONTENT_PATH_DEFAULT}/anb.exe"

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine libGL.so.1"

# Use persistent storage for saved games and settings

APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
userdir:users/${USER}/Local Settings/Application Data/Daedalic Entertainment/A New Beginning - Final Cut'
DATA_FILES="$DATA_FILES userdir/config.ini"
DATA_DIRS="$DATA_DIRS userdir/Savegames"

# Work around audio issues

PKG_BIN_DEPS="$PKG_BIN_DEPS winetricks"
APP_WINETRICKS="$APP_WINETRICKS dsound"

# Load common functions

target_version='2.17'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_get_from_workdir 'APP_MAIN'

# Include game data

prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
