#!/bin/sh
set -o errexit

###
# Copyright © 2015-2022, Antoine "vv221/vv222" Le Gonidec
# Copyright © 2016-2022, Mopi
# Copyright © 2017-2022, Jacek Szafarkiewicz
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Aragami
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220113.4

# Set game-specific variables

GAME_ID='aragami'
GAME_NAME='Aragami'

# Archives

## Base game

ARCHIVE_BASE_GOG_1='aragami_en_01_09_20943.sh'
ARCHIVE_BASE_GOG_1_MD5='46c8315350a4036dcc09b6c3946ddc02'
ARCHIVE_BASE_GOG_1_TYPE='mojosetup'
ARCHIVE_BASE_GOG_1_SIZE='6800000'
ARCHIVE_BASE_GOG_1_VERSION='01.09-gog20943'
ARCHIVE_BASE_GOG_1_URL='https://www.gog.com/game/aragami'

ARCHIVE_BASE_GOG_0='gog_aragami_2.9.0.12.sh'
ARCHIVE_BASE_GOG_0_MD5='42d0952de9b0373786f2902aa596b4ff'
ARCHIVE_BASE_GOG_0_TYPE='mojosetup'
ARCHIVE_BASE_GOG_0_SIZE='6800000'
ARCHIVE_BASE_GOG_0_VERSION='01.08-gog2.9.0.12'

# This installer used to be sold at Humble Bundle,
# but they now sell Steam keys only.
ARCHIVE_BASE_HUMBLE_0='aragami_01_08_Linux.zip'
ARCHIVE_BASE_HUMBLE_0_MD5='4be0b7f674eec62184df216fcaba77b5'
ARCHIVE_BASE_HUMBLE_0_SIZE='6800000'
ARCHIVE_BASE_HUMBLE_0_VERSION='01.08-humble170503'

## Nightfall expansion

ARCHIVE_OPTIONAL_NIGHTFALL_0='aragami_nightfall_dlc_en_gog_1_21278.sh'
ARCHIVE_OPTIONAL_NIGHTFALL_0_MD5='40920a28f030147a524e5ac89e2cf14b'
ARCHIVE_OPTIONAL_NIGHTFALL_0_SIZE='7400000'
ARCHIVE_OPTIONAL_NIGHTFALL_0_TYPE='mojosetup'
ARCHIVE_OPTIONAL_NIGHTFALL_0_URL='https://www.gog.com/game/aragami_nightfall'


UNITY3D_NAME='Aragami'

CONTENT_PATH_DEFAULT_GOG='data/noarch/game'
CONTENT_PATH_DEFAULT_HUMBLE='.'
ARCHIVE_GAME_BIN32_FILES="
${UNITY3D_NAME}.x86
${UNITY3D_NAME}_Data/Mono/x86
${UNITY3D_NAME}_Data/Plugins/x86"
ARCHIVE_GAME_BIN64_FILES="
${UNITY3D_NAME}.x86_64
${UNITY3D_NAME}_Data/Mono/x86_64
${UNITY3D_NAME}_Data/Plugins/x86_64"
ARCHIVE_GAME_DATA_FILES="
${UNITY3D_NAME}_Data"

PACKAGES_LIST='PKG_BIN32 PKG_BIN64 PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN32_ARCH='32'
PKG_BIN32_DEPS="$PKG_DATA_ID libc.so.6 libz.so.1 libGL.so.1 libX11.so.6 libgtk-x11-2.0.so.0 libgdk_pixbuf-2.0.so.0 libgobject-2.0.so.0 libglib-2.0.so.0 xcursor libxrandr"

PKG_BIN64_ARCH='64'
PKG_BIN64_DEPS="$PKG_BIN32_DEPS"

# Load common functions

target_version='2.15'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Check for the presence of the Nightfall expansion archive

archive_initialize_optional \
	'ARCHIVE_NIGHTFALL' \
	'ARCHIVE_OPTIONAL_NIGHTFALL_0'

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"

# Extract game data from the Nightfall expansion archive

if [ "$ARCHIVE_NIGHTFALL" ]; then
	(
		ARCHIVE='ARCHIVE_NIGHTFALL'
		extract_data_from "$ARCHIVE_NIGHTFALL"
	)
fi

# Include game data

prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Include game icon

PKG='PKG_DATA'
icons_get_from_package 'APP_MAIN'

# Write launchers

for PKG in 'PKG_BIN32' 'PKG_BIN64'; do
	launchers_write 'APP_MAIN'
done

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
