#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2022 Anna Lea
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Armikrog
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220121.1

# Set game-specific variables

GAME_ID='armikrog'
GAME_NAME='Armikrog'

ARCHIVE_BASE_WINDOWS_0='setup_armikrog_1.05_(20650).exe'
ARCHIVE_BASE_WINDOWS_0_MD5='9b18bfd56117bcdbd95434203303b941'
ARCHIVE_BASE_WINDOWS_0_TYPE='innosetup'
ARCHIVE_BASE_WINDOWS_0_SIZE='2900000'
ARCHIVE_BASE_WINDOWS_0_VERSION='1.05-gog20650'
ARCHIVE_BASE_WINDOWS_0_URL='https://www.gog.com/game/armikrog'

ARCHIVE_BASE_LINUX_0='gog_armikrog_2.5.0.6.sh'
ARCHIVE_BASE_LINUX_0_MD5='4ca9ac6d05ac66c18229e41da6fd89dd'
ARCHIVE_BASE_LINUX_0_TYPE='mojosetup'
ARCHIVE_BASE_LINUX_0_SIZE='2900000'
ARCHIVE_BASE_LINUX_0_VERSION='2016.01.11-gog2.5.0.6'
ARCHIVE_BASE_LINUX_0_URL='https://www.gog.com/game/armikrog'

UNITY3D_NAME='Armikrog'

CONTENT_PATH_DEFAULT_WINDOWS='.'
CONTENT_PATH_DEFAULT_LINUX='data/noarch/game'
ARCHIVE_GAME_BIN_WINDOWS_FILES="
*.dll
${UNITY3D_NAME}.exe
${UNITY3D_NAME}_Data/mono"
ARCHIVE_GAME_BIN32_LINUX_FILES="
${UNITY3D_NAME}.x86
${UNITY3D_NAME}_Data/Mono/x86
${UNITY3D_NAME}_Data/Plugins/x86"
ARCHIVE_GAME_BIN64_LINUX_FILES="
${UNITY3D_NAME}.x86_64
${UNITY3D_NAME}_Data/Mono/x86_64
${UNITY3D_NAME}_Data/Plugins/x86_64"
ARCHIVE_GAME_DATA_FILES="
${UNITY3D_NAME}_Data"

APP_MAIN_TYPE_WINDOWS='wine'
APP_MAIN_EXE_WINDOWS="${UNITY3D_NAME}.exe"
APP_MAIN_ICON_WINDOWS="${UNITY3D_NAME}.exe"

PACKAGES_LIST_WINDOWS='PKG_BIN_WINDOWS PKG_DATA'
PACKAGES_LIST_LINUX='PKG_BIN32_LINUX PKG_BIN64_LINUX PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_ID_LINUX="${PKG_DATA_ID}-linux"
PKG_DATA_ID_WINDOWS="${PKG_DATA_ID}-windows"
PKG_DATA_PROVIDE="$PKG_DATA_ID"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ID="$GAME_ID"

PKG_BIN_WINDOWS_ID="${PKG_BIN_ID}-windows"
PKG_BIN_WINDOWS_PROVIDE="$PKG_BIN_ID"
PKG_BIN_WINDOWS_ARCH='32'
PKG_BIN_WINDOWS_DEPS="$PKG_DATA_ID_WINDOWS wine"

PKG_BIN32_LINUX_ID="${PKG_BIN_ID}-linux"
PKG_BIN32_LINUX_PROVIDE="$PKG_BIN_ID"
PKG_BIN32_LINUX_ARCH='32'
PKG_BIN32_LINUX_DEPS="$PKG_DATA_ID_LINUX libc.so.6 libstdc++.so.6 libGLU.so.1 libGL.so.1 libX11.so.6 libgdk-x11-2.0.so.0 libgdk_pixbuf-2.0.so.0 libgobject-2.0.so.0 libglib-2.0.so.0 xcursor libxrandr freetype"
PKG_BIN32_LINUX_DEPS_ARCH='lib32-libxext lib32-atk lib32-pango lib32-cairo lib32-fontconfig'
PKG_BIN32_LINUX_DEPS_DEB='libxext6, libatk1.0-0, libpangoft2-1.0-0, libpangocairo-1.0-0, libcairo2, libpango-1.0-0, libfontconfig1'
PKG_BIN32_LINUX_DEPS_GENTOO='x11-libs/libXext[abi_x86_32] dev-libs/atk[abi_x86_32] x11-libs/pango[abi_x86_32] x11-libs/cairo[abi_x86_32] media-libs/fontconfig[abi_x86_32]'

PKG_BIN64_LINUX_ID="${PKG_BIN_ID}-linux"
PKG_BIN64_LINUX_PROVIDE="$PKG_BIN_ID"
PKG_BIN64_LINUX_ARCH='64'
PKG_BIN64_LINUX_DEPS="$PKG_BIN32_LINUX_DEPS"
PKG_BIN64_LINUX_DEPS_ARCH='libxext atk pango cairo fontconfig'
PKG_BIN64_LINUX_DEPS_DEB="$PKG_BIN32_LINUX_DEPS_DEB"
PKG_BIN64_LINUX_DEPS_GENTOO='x11-libs/libXext dev-libs/atk x11-libs/pango x11-libs/cairo media-libs/fontconfig'

# Use persistent storage for user data (Windows build)

APP_WINE_LINK_DIRS='
userdata:users/${USER}/AppData/LocalLow/PencilTestStudios/Armikrog'
DATA_DIRS_WINDOWS='./userdata'

# Load common functions

target_version='2.15'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Use archive specific values for app related variables

use_archive_specific_value 'APP_MAIN_ICON'

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"

# Enforce a consistent Unity3D name

(
	content_path=$(content_path_default)
	unity3d_name=$(unity3d_name)
	alternative_name='armikrog'
	cd "${PLAYIT_WORKDIR}/gamedata/${content_path}"
	if [ -e "${alternative_name}.exe" ]; then
		mv "${alternative_name}.exe" "${unity3d_name}.exe"
	fi
	if [ -e "${alternative_name}_data" ]; then
		mv "${alternative_name}_data" "${unity3d_name}_Data"
	fi
)

# Include game data

prepare_package_layout

# Include game icon

case "$ARCHIVE" in
	('ARCHIVE_BASE_LINUX_'*)
		PKG='PKG_DATA'
		icons_get_from_package 'APP_MAIN'
	;;
	('ARCHIVE_BASE_WINDOWS_'*)
		PKG='PKG_BIN_WINDOWS'
		icons_get_from_package 'APP_MAIN'
		icons_move_to 'PKG_DATA'
	;;
esac

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

APP_MAIN_EXE=$(get_context_specific_value 'archive' 'APP_MAIN_EXE')
APP_MAIN_TYPE=$(get_context_specific_value 'archive' 'APP_MAIN_TYPE')
DATA_DIRS=$(get_context_specific_value 'archive' 'DATA_DIRS')
for PKG in \
	'PKG_BIN_WINDOWS' \
	'PKG_BIN32_LINUX' \
	'PKG_BIN64_LINUX'
do
	if packages_get_list | grep --quiet --fixed-strings --word-regexp "$PKG"; then
		launchers_write 'APP_MAIN'
	fi
done

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
