#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2021 Mopi
# SPDX-FileCopyrightText: © 2021 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Assassin's Creed
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220322.3

# Set game-specific variables

GAME_ID='assassins-creed-1'
GAME_NAME='Assassinʼs Creed'

ARCHIVE_BASE_EN_0='setup_assassins_creed_1.02_v2_(28524).exe'
ARCHIVE_BASE_EN_0_MD5='b14aa9508ce9653597558a6d834e2766'
ARCHIVE_BASE_EN_0_TYPE='innosetup'
ARCHIVE_BASE_EN_0_PART1='setup_assassins_creed_1.02_v2_(28524)-1.bin'
ARCHIVE_BASE_EN_0_PART1_MD5='08f2ac5b1c558483ea27c921a7d7aad7'
ARCHIVE_BASE_EN_0_PART1_TYPE='innosetup'
ARCHIVE_BASE_EN_0_PART2='setup_assassins_creed_1.02_v2_(28524)-2.bin'
ARCHIVE_BASE_EN_0_PART2_MD5='150870977feb60c9f344e35d220e1198'
ARCHIVE_BASE_EN_0_PART2_TYPE='innosetup'
ARCHIVE_BASE_EN_0_SIZE='7200000'
ARCHIVE_BASE_EN_0_VERSION='1.02-gog28524'
ARCHIVE_BASE_EN_0_URL='https://www.gog.com/game/assassins_creed_directors_cut'

ARCHIVE_BASE_FR_0='setup_assassins_creed_1.02_v2_(french)_(28524).exe'
ARCHIVE_BASE_FR_0_MD5='eb346d8ec12bb055f941446d24207dbd'
ARCHIVE_BASE_FR_0_TYPE='innosetup'
ARCHIVE_BASE_FR_0_PART1='setup_assassins_creed_1.02_v2_(french)_(28524)-1.bin'
ARCHIVE_BASE_FR_0_PART1_MD5='08f2ac5b1c558483ea27c921a7d7aad7'
ARCHIVE_BASE_FR_0_PART1_TYPE='innosetup'
ARCHIVE_BASE_FR_0_PART2='setup_assassins_creed_1.02_v2_(french)_(28524)-2.bin'
ARCHIVE_BASE_FR_0_PART2_MD5='2e31309a834daa7c7640a4848e701574'
ARCHIVE_BASE_FR_0_PART2_TYPE='innosetup'
ARCHIVE_BASE_FR_0_SIZE='7200000'
ARCHIVE_BASE_FR_0_VERSION='1.02-gog28524'
ARCHIVE_BASE_FR_0_URL='https://www.gog.com/game/assassins_creed_directors_cut'

CONTENT_PATH_DEFAULT='.'
ARCHIVE_DOC_L10N_FILES_EN='
manual
eula/english*
readme/english*'
ARCHIVE_DOC_L10N_FILES_FR='
manual
eula/french*
readme/french*'
ARCHIVE_GAME_BIN_FILES='
assassinscreed_dx10.exe
assassinscreed_dx9.exe
assassinscreed_game.exe
binkw32.dll
eax.dll'
ARCHIVE_GAME_L10N_FILES='
datapc_streamedsounds???.forge'
ARCHIVE_GAME_DATA_FILES='
*.forge
defaultbindings.map
resources
videos'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='assassinscreed_dx9.exe'
APP_MAIN_ICON='assassinscreed_game.exe'

PACKAGES_LIST='PKG_L10N PKG_DATA PKG_BIN'

PKG_L10N_ID="${GAME_ID}-l10n"
PKG_L10N_ID_EN="${PKG_L10N_ID}-en"
PKG_L10N_ID_FR="${PKG_L10N_ID}-fr"
PKG_L10N_PROVIDE="$PKG_L10N_ID"
PKG_L10N_DESCRIPTION_EN='English localization'
PKG_L10N_DESCRIPTION_FR='French localization'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID $PKG_L10N_ID wine"

# Use persistent storage for user data

APP_WINE_LINK_DIRS='
userdata:users/${USER}/Application Data/Ubisoft/Assassin'\''s Creed'
DATA_DIRS='./userdata'

# Load common functions

target_version='2.15'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Use DXVK for Direct3D rendering (32-bit)

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'

# Use DXVK for Direct3D rendering (32-bit)
if [ ! -e dxvk_installed ]; then
	# Wait until the WINE prefix creation is complete
	printf "Waiting for the WINE prefix initialization to complete, it might take a couple seconds…\\n"
	while [ ! -f "${WINEPREFIX}/system.reg" ]; do
		sleep 1s
	done

	if \
		command -v dxvk-setup >/dev/null 2>&1 && \
		command -v wine-development >/dev/null 2>&1
	then
		dxvk-setup install --development
		touch dxvk_installed
	elif command -v winetricks >/dev/null 2>&1; then
		winetricks dxvk
		touch dxvk_installed
	else
		message="\\033[1;33mWarning:\\033[0m\\n"
		message="${message}DXVK patches could not be installed in the WINE prefix.\\n"
		message="${message}The game might run with display or performance issues.\\n"
		printf "\\n${message}\\n"
	fi

	# Wait a bit to ensure there is no lingering wine process
	sleep 1s
fi'
case "$OPTION_PACKAGE" in
	('deb')
		# Debian-based distributions should use repositories-provided dxvk
		# winetricks is used as a fallback for branches not having access to dxvk-setup
		extra_dependencies='mesa-vulkan-drivers | vulkan-icd, dxvk-wine32-development | winetricks, dxvk | winetricks'
		if [ -n "$PKG_BIN_DEPS_DEB" ]; then
			PKG_BIN_DEPS_DEB="${PKG_BIN_DEPS_DEB}, ${extra_dependencies}"
		else
			PKG_BIN_DEPS_DEB="$extra_dependencies"
		fi
	;;
	(*)
		# Default is to use winetricks
		PKG_BIN_DEPS="$PKG_BIN_DEPS winetricks"
	;;
esac

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Ensure ability fo fully control the camera with the mouse
# cf. https://appdb.winehq.org/objectManager.php?sClass=version&iId=28057#notes

PKG='PKG_BIN'
package_path=$(package_get_path "$PKG")
APP_REGEDIT="${APP_REGEDIT} registry-keys/init.reg"
REGISTRY_FILE="${package_path}${PATH_GAME}/registry-keys/init.reg"
mkdir --parents "$(dirname "$REGISTRY_FILE")"
cat > "$REGISTRY_FILE" << 'EOF'
Windows Registry Editor Version 5.00

[HKEY_CURRENT_USER\Software\Wine\X11 Driver]
"GrabFullscreen"="Y"
EOF

# Set game text language

PKG='PKG_L10N'
package_path=$(package_get_path "$PKG")
case "$ARCHIVE" in
	('ARCHIVE_BASE_FR'*)
		language='French'
	;;
	('ARCHIVE_BASE_EN'*|*)
		language='English'
	;;
esac
APP_REGEDIT="${APP_REGEDIT} registry-keys/language.reg"
REGISTRY_FILE="${package_path}${PATH_GAME}/registry-keys/language.reg"
mkdir --parents "$(dirname "$REGISTRY_FILE")"
cat > "$REGISTRY_FILE" << EOF
Windows Registry Editor Version 5.00

[HKEY_LOCAL_MACHINE\\Software\\Ubisoft\\Assassin's Creed]
"Language"="$language"
EOF

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
