#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Atlantis 1
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220701.1

GAME_ID='atlantis-1-the-lost-tales'
GAME_NAME='Atlantis: The Lost Tales'

ARCHIVE_BASE_EN_0='setup_atlantis_the_lost_tales_2.0.0.15.exe'
ARCHIVE_BASE_EN_0_MD5='287170bea9041b4e29888d97f87eb9fc'
ARCHIVE_BASE_EN_0_TYPE='innosetup'
ARCHIVE_BASE_EN_0_SIZE='1900000'
ARCHIVE_BASE_EN_0_VERSION='1.0-gog2.0.0.15'
ARCHIVE_BASE_EN_0_URL='https://www.gog.com/game/atlantis_the_lost_tales'

ARCHIVE_BASE_FR_0='setup_atlantis_the_lost_tales_french_2.1.0.15.exe'
ARCHIVE_BASE_FR_0_MD5='0cb6b037a457d35dacd23e1f22aea57b'
ARCHIVE_BASE_FR_0_TYPE='innosetup'
ARCHIVE_BASE_FR_0_SIZE='1900000'
ARCHIVE_BASE_FR_0_VERSION='1.0-gog2.1.0.15'
ARCHIVE_BASE_FR_0_URL='https://www.gog.com/game/atlantis_the_lost_tales'

CONTENT_PATH_DEFAULT='app'
ARCHIVE_DOC_DATA_FILES='
*.pdf'
ARCHIVE_GAME_BIN_FILES='
*.exe
*.dll'
ARCHIVE_GAME_L10N_FILES='
images/end.tga
scenar
sprlist
wav'
ARCHIVE_GAME_DATA_FILES='
*.big
cyclo
dialog
images
puzzles
sprite
ubb_vue
wam'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='atlantis.exe'
APP_MAIN_ICON='atlantis.exe'

PACKAGES_LIST='PKG_BIN PKG_L10N PKG_DATA'

PKG_L10N_ID="${GAME_ID}-l10n"
PKG_L10N_ID_EN="${PKG_L10N_ID}-en"
PKG_L10N_ID_FR="${PKG_L10N_ID}-fr"
PKG_L10N_PROVIDE="$PKG_L10N_ID"
PKG_L10N_DESCRIPTION_EN='English localization'
PKG_L10N_DESCRIPTION_FR='French localization'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_ID="$GAME_ID"
PKG_BIN_ID_EN="${PKG_BIN_ID}-en"
PKG_BIN_ID_FR="${PKG_BIN_ID}-fr"
PKG_BIN_PROVIDE="$PKG_BIN_ID"
PKG_BIN_DEPS="$PKG_L10N_ID $PKG_DATA_ID wine"
PKG_BIN_DESCRIPTION_EN='English version'
PKG_BIN_DESCRIPTION_FR='French version'

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Set required registry key

PKG='PKG_BIN'
package_path=$(package_get_path "$PKG")

registry_file='registry-tweaks/set-game-directory.reg'
registry_file_path="${package_path}${PATH_GAME}/${registry_file}"
registry_file_directory=$(dirname "$registry_file_path")

APP_REGEDIT="$APP_REGEDIT $registry_file"

game_id=$(game_id)
game_directory="C:\\\\${game_id}\\\\"

mkdir --parents "$registry_file_directory"
cat > "$registry_file_path" << EOF
Windows Registry Editor Version 5.00

[HKEY_CURRENT_USER\\Software\\CRYO\\Atlantis\\GameDirectory]
@="${game_directory}"
EOF

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
