#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2021 Mopi
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Batman: Arkham City
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20230417.2

GAME_ID='batman-arkham-2'
GAME_NAME='Batman: Arkham City'

ARCHIVE_BASE_0='setup_batman_arkham_city_goty_1.1_(38264).exe'
ARCHIVE_BASE_0_MD5='e8bfd823cfcfec2147f736bb696a85c8'
ARCHIVE_BASE_0_EXTRACTOR='innoextract'
ARCHIVE_BASE_0_EXTRACTOR_OPTIONS='--progress=1 --silent'
ARCHIVE_BASE_0_PART1='setup_batman_arkham_city_goty_1.1_(38264)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='5e1213208d59a42ec0fd808bfee2f189'
ARCHIVE_BASE_0_PART1_EXTRACTOR='innoextract'
ARCHIVE_BASE_0_PART2='setup_batman_arkham_city_goty_1.1_(38264)-2.bin'
ARCHIVE_BASE_0_PART2_MD5='fa9fcbaf8ef9de81dc1638bbc9db0353'
ARCHIVE_BASE_0_PART2_EXTRACTOR='innoextract'
ARCHIVE_BASE_0_PART3='setup_batman_arkham_city_goty_1.1_(38264)-3.bin'
ARCHIVE_BASE_0_PART3_MD5='685be8b8bbd0fe3f831fb5cf0506a735'
ARCHIVE_BASE_0_PART3_EXTRACTOR='innoextract'
ARCHIVE_BASE_0_PART4='setup_batman_arkham_city_goty_1.1_(38264)-4.bin'
ARCHIVE_BASE_0_PART4_MD5='0ccafb2161130774710b470692ba8b39'
ARCHIVE_BASE_0_PART4_EXTRACTOR='innoextract'
ARCHIVE_BASE_0_PART5='setup_batman_arkham_city_goty_1.1_(38264)-5.bin'
ARCHIVE_BASE_0_PART5_MD5='2122f11dc24618e8c902e6706c26f7c2'
ARCHIVE_BASE_0_PART5_EXTRACTOR='innoextract'
ARCHIVE_BASE_0_SIZE='20000000'
ARCHIVE_BASE_0_VERSION='1.1-gog38264'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/batman_arkham_city_goty'

CONTENT_PATH_DEFAULT='.'
ARCHIVE_DOC_L10N_EN_FILES='
readme.rtf'
ARCHIVE_DOC_L10N_FR_FILES='
readme_FRA.rtf'
ARCHIVE_GAME_BIN_FILES='
*.dll
Binaries
engine
Setup
BmGame/Config'
ARCHIVE_GAME_L10N_EN_FILES='
BmGame/Localization/INT
BmGame/CookedPCConsole/English(US)'
ARCHIVE_GAME_L10N_FR_FILES='
BmGame/Localization/FRA
BmGame/CookedPCConsole/French(France)'
ARCHIVE_GAME_DATA_MOVIES_FILES='
BmGame/Movies
BmGame/MoviesStereo'
ARCHIVE_GAME_DATA_TEXTURES_FILES='
BmGame/CookedPCConsole/*.tfc'
ARCHIVE_GAME_DATA_FILES='
BmGame/CookedPCConsole/*.bin
BmGame/CookedPCConsole/*.upk
BmGame/CookedPCConsole/CookedBanks.txt
BmGame/CookedPCConsole/GuidMap
BmGame/CookedPCConsole/SFX
BmGame/Splash'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='Binaries/Win32/BmLauncher.exe'
APP_MAIN_ICON='Binaries/Win32/BmLauncher.exe'

# Packages

PACKAGES_LIST='PKG_BIN PKG_L10N_EN PKG_L10N_FR PKG_DATA_MOVIES PKG_DATA_TEXTURES PKG_DATA'

## Common data

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_DATA_MOVIES_ID="${PKG_DATA_ID}-movies"
PKG_DATA_MOVIES_DESCRIPTION="$PKG_DATA_DESCRIPTION - movies"
PKG_DATA_DEPS="$PKG_DATA_DEPS $PKG_DATA_MOVIES_ID"

PKG_DATA_TEXTURES_ID="${PKG_DATA_ID}-textures"
PKG_DATA_TEXTURES_DESCRIPTION="$PKG_DATA_DESCRIPTION - textures"
PKG_DATA_DEPS="$PKG_DATA_DEPS $PKG_DATA_TEXTURES_ID"

## Localizations

PKG_L10N_ID="${GAME_ID}-l10n"

PKG_L10N_EN_ID="${PKG_L10N_ID}-en"
PKG_L10N_EN_PROVIDE="$PKG_L10N_ID"
PKG_L10N_EN_DESCRIPTION='English localization'

PKG_L10N_FR_ID="${PKG_L10N_ID}-fr"
PKG_L10N_FR_PROVIDE="$PKG_L10N_ID"
PKG_L10N_FR_DESCRIPTION='French localization'

## Binaries

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_L10N_ID $PKG_DATA_ID wine"

# Use persistent storage for user data

APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
config:users/${USER}/My Documents/WB Games/Batman Arkham City GOTY/BmGame/Config
saves:users/${USER}/My Documents/WB Games/Batman Arkham City GOTY/SaveData'
USER_PERSISTENT_DIRECTORIES="$USER_PERSISTENT_DIRECTORIES"'
config
saves'

# Set up a WINE virtual desktop on first launch, using the current desktop resolution

sed_expression='s/.*primary.* ([0-9]+x[0-9]+).*/\1/p'
sed_options="--regexp-extended --silent --expression='$sed_expression'"
APP_WINETRICKS="$APP_WINETRICKS vd=\$(LANG=C xrandr | sed $sed_options)"
PKG_BIN_DEPS="$PKG_BIN_DEPS winetricks xrandr sed"

# Install "physx" winetricks verb

APP_WINETRICKS="$APP_WINETRICKS physx"
PKG_BIN_DEPS="$PKG_BIN_DEPS winetricks"

# Install .NET 3.5 runtime in the WINE prefix

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
# Do not disable mscoree library
export WINEDLLOVERRIDES="winemenubuilder.exe,mshtml=d"
# Install .NET 3.5 runtime on first launch
if [ ! -e dotnet35_installed ]; then
	sleep 3s
	winetricks dotnet35
	touch dotnet35_installed
fi'
PKG_BIN_DEPS="$PKG_BIN_DEPS winetricks"

# Install shipped DirectX in the WINE prefix

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
# Install shipped DirectX on first launch
if [ ! -e directx9_installed ]; then
	sleep 3s
	wine Setup/DxRedist/DXSETUP.exe
	touch directx9_installed
fi'

# Force language environment, to work around the lack of a game setting

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
# Force language environment, to work around the lack of a game setting
if [ -e "BmGame/Localization/FRA" ]; then
	export LANG=fr
elif [ -e "BmGame/Localization/INT" ]; then
	export LANG=en
fi'

# Run the game binary from its directory

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
# Run the game binary from its directory
cd "$(dirname "$APP_EXE")"
APP_EXE=$(basename "$APP_EXE")'

# Load common functions

target_version='2.17'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Use DXVK for Direct3D 9/10/11 rendering

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
# Use DXVK for Direct3D 9/10/11 rendering
if [ ! -e dxvk_installed ]; then
	# Wait until the WINE prefix creation is complete
	printf "Waiting for the WINE prefix initialization to complete, it might take a couple seconds…\\n"
	while [ ! -f "${WINEPREFIX}/system.reg" ]; do
		sleep 1s
	done

	if \
		command -v dxvk-setup >/dev/null 2>&1 && \
		command -v wine-development >/dev/null 2>&1
	then
		dxvk-setup install --development
		touch dxvk_installed
	elif command -v winetricks >/dev/null 2>&1; then
		winetricks dxvk
		touch dxvk_installed
	else
		message="\\033[1;33mWarning:\\033[0m\\n"
		message="${message}DXVK patches could not be installed in the WINE prefix.\\n"
		message="${message}The game might run with display or performance issues.\\n"
		printf "\\n${message}\\n"
	fi

	# Wait a bit to ensure there is no lingering wine process
	sleep 1s
fi'
case "$OPTION_PACKAGE" in
	('deb')
		# Debian-based distributions should use repositories-provided dxvk
		# winetricks is used as a fallback for branches not having access to dxvk-setup
		extra_dependencies='mesa-vulkan-drivers | vulkan-icd, dxvk-wine32-development | winetricks, dxvk | winetricks'
		if [ -n "$PKG_BIN_DEPS_DEB" ]; then
			PKG_BIN_DEPS_DEB="${PKG_BIN_DEPS_DEB}, ${extra_dependencies}"
		else
			PKG_BIN_DEPS_DEB="$extra_dependencies"
		fi
	;;
	(*)
		# Default is to use winetricks
		PKG_BIN_DEPS="${PKG_BIN_DEPS} winetricks"
	;;
esac

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icon

PKG='PKG_DATA'
icons_inclusion

# Include game data

prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Set the launcher language based on the installed texts localization

PKG='PKG_BIN'
package_path=$(package_get_path "$PKG")
config_file='BmGame/Config/Launcher.ini'
config_file_path_original="${package_path}${PATH_GAME}/${config_file}"
ini_section='\[Launcher\.Settings\]'
ini_field='ForceUseCulture'

PKG='PKG_L10N_EN'
package_path=$(package_get_path "$PKG")
config_file_path_destination="${package_path}${PATH_GAME}/${config_file}"
ini_value='en'
sed_expression="s/^${ini_section}/&\\n${ini_field}=${ini_value}/"
mkdir --parents "$(dirname "$config_file_path_destination")"
sed --expression="$sed_expression" "$config_file_path_original" > "$config_file_path_destination"
unix2dos --quiet "$config_file_path_destination"

PKG='PKG_L10N_FR'
package_path=$(package_get_path "$PKG")
config_file_path_destination="${package_path}${PATH_GAME}/${config_file}"
ini_value='fr'
sed_expression="s/^${ini_section}/&\\n${ini_field}=${ini_value}/"
mkdir --parents "$(dirname "$config_file_path_destination")"
sed --expression="$sed_expression" "$config_file_path_original" > "$config_file_path_destination"
unix2dos --quiet "$config_file_path_destination"

rm "$config_file_path_original"

# Set the game language based on the installed texts localization

PKG='PKG_BIN'
package_path=$(package_get_path "$PKG")
config_file='engine/config/BaseEngine.ini'
config_file_path_original="${package_path}${PATH_GAME}/${config_file}"
ini_field='Language'

PKG='PKG_L10N_EN'
package_path=$(package_get_path "$PKG")
config_file_path_destination="${package_path}${PATH_GAME}/${config_file}"
ini_value='INT'
sed_expression="s/^${ini_field}=.*/${ini_filed}=${ini_value}/"
mkdir --parents "$(dirname "$config_file_path_destination")"
sed --expression="$sed_expression" "$config_file_path_original" > "$config_file_path_destination"
unix2dos --quiet "$config_file_path_destination"

PKG='PKG_L10N_FR'
package_path=$(package_get_path "$PKG")
config_file_path_destination="${package_path}${PATH_GAME}/${config_file}"
ini_value='FRA'
sed_expression="s/^${ini_field}=.*/${ini_filed}=${ini_value}/"
mkdir --parents "$(dirname "$config_file_path_destination")"
sed --expression="$sed_expression" "$config_file_path_original" > "$config_file_path_destination"
unix2dos --quiet "$config_file_path_destination"

rm "$config_file_path_original"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

common_packages='PKG_BIN PKG_DATA PKG_DATA_MOVIES PKG_DATA_TEXTURES'
case "${LANG%_*}" in
	('fr')
		lang_string='version %s :'
		lang_en='anglaise'
		lang_fr='française'
	;;
	('en'|*)
		lang_string='%s version:'
		lang_en='English'
		lang_fr='French'
	;;
esac
printf '\n'
printf "$lang_string" "$lang_en"
print_instructions $common_packages 'PKG_L10N_EN'
printf "$lang_string" "$lang_fr"
print_instructions $common_packages 'PKG_L10N_FR'

exit 0
