#!/bin/sh
set -o errexit

###
# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
# Copyright (c) 2016-2021, Mopi
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Runner 2
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20211125.9

# Set game-specific variables

GAME_ID='bit-trip-runner-2'
GAME_NAME='Bit.Trip Presents… Runner2: Future Legend of Rhythm Alien'

ARCHIVE_BASE_GOG_0='gog_bit_trip_presents_runner2_future_legend_of_rhythm_alien_2.0.0.1.sh'
ARCHIVE_BASE_GOG_0_MD5='28c003bae691aa46d841547da8e3def6'
ARCHIVE_BASE_GOG_0_TYPE='mojosetup'
ARCHIVE_BASE_GOG_0_SIZE='1600000'
ARCHIVE_BASE_GOG_0_VERSION='1.0-gog2.0.0.1'
ARCHIVE_BASE_GOG_0_URL='https://www.gog.com/game/bittrip_presents_runner2_future_legend_of_rhythm_alien'

ARCHIVE_BASE_HUMBLE_32BIT_0='runner2_i386_1388171186.tar.gz'
ARCHIVE_BASE_HUMBLE_32BIT_0_MD5='ea105bdcd486879fb99889b87e90eed5'
ARCHIVE_BASE_HUMBLE_32BIT_0_SIZE='770000'
ARCHIVE_BASE_HUMBLE_32BIT_0_VERSION='1.0-humble1388171186'

ARCHIVE_BASE_HUMBLE_64BIT_0='runner2_amd64_1388171186.tar.gz'
ARCHIVE_BASE_HUMBLE_64BIT_0_MD5='2f7ccdb675a63a5fc152514682e97480'
ARCHIVE_BASE_HUMBLE_64BIT_0_SIZE='770000'
ARCHIVE_BASE_HUMBLE_64BIT_0_VERSION='1.0-humble1388171186'

ARCHIVE_DOC_MAIN_PATH_GOG='data/noarch/game/runner2-1.0-32'
ARCHIVE_DOC_MAIN_PATH_HUMBLE='runner2-1.0'
ARCHIVE_DOC_MAIN_FILES='
README
README.html'

ARCHIVE_GAME_BIN32_PATH_GOG='data/noarch/game/runner2-1.0-32/runner2'
ARCHIVE_GAME_BIN32_PATH_HUMBLE='runner2-1.0/runner2'
ARCHIVE_GAME_BIN32_FILES='
runner2
libfmodevent-4.44.08.so
libfmodex-4.44.08.so'

ARCHIVE_GAME_BIN64_PATH_GOG='data/noarch/game/runner2-1.0-64/runner2'
ARCHIVE_GAME_BIN64_PATH_HUMBLE='runner2-1.0/runner2'
ARCHIVE_GAME_BIN64_FILES='
runner2
libfmodevent64-4.44.07.so
libfmodex64-4.44.07.so'

ARCHIVE_GAME_DATA_PATH_GOG='data/noarch/game/runner2-1.0-32/runner2'
ARCHIVE_GAME_DATA_PATH_HUMBLE='runner2-1.0/runner2'
ARCHIVE_GAME_DATA_FILES='
Effects
Fonts
Gameplay
Graphics
Menus
Models
Shaders
Sounds
Textures
package.toc
Runner2.png'

APP_MAIN_TYPE='native'
APP_MAIN_EXE='runner2'
APP_MAIN_ICON='Runner2.png'

PACKAGES_LIST_GOG='PKG_BIN32 PKG_BIN64 PKG_DATA'
PACKAGES_LIST_HUMBLE_32BIT='PKG_BIN32 PKG_DATA'
PACKAGES_LIST_HUMBLE_64BIT='PKG_BIN64 PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN32_ARCH='32'
PKG_BIN32_DEPS="$PKG_DATA_ID libc.so.6 libstdc++.so.6 libz.so.1 libSDL-1.2.so.0 libGL.so.1"

PKG_BIN64_ARCH='64'
PKG_BIN64_DEPS="$PKG_BIN32_DEPS"

# Ensure easy upgrade from packages generated using pre-20211125.2 game script

PKG_BIN_PROVIDE='runner-2'
PKG_DATA_PROVIDE='runner-2-data'

# Load common functions

target_version='2.14'

if [ -z "$PLAYIT_LIB2" ]; then
	for path in \
		"$PWD" \
		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
		'/usr/local/share/games/play.it' \
		'/usr/local/share/play.it' \
		'/usr/share/games/play.it' \
		'/usr/share/play.it'
	do
		if [ -e "${path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=play.it-2/lib/libplayit2.sh
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
set_standard_permissions "${PLAYIT_WORKDIR}/gamedata"
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Add required library symlinks

PKG='PKG_BIN32'
if packages_get_list | grep --quiet "$PKG"; then
	(
		package_path=$(package_get_path "$PKG")
		cd "${package_path}${PATH_GAME}"
		ln --symbolic 'libfmodevent-4.44.08.so' 'libfmodevent.so'
		ln --symbolic 'libfmodex-4.44.08.so'    'libfmodex.so'
	)
fi
PKG='PKG_BIN64'
if packages_get_list | grep --quiet "$PKG"; then
	(
		package_path=$(package_get_path "$PKG")
		cd "${package_path}${PATH_GAME}"
		ln --symbolic 'libfmodevent64-4.44.07.so' 'libfmodevent64.so'
		ln --symbolic 'libfmodex64-4.44.07.so'    'libfmodex64.so'
	)
fi

# Include game icons

PKG='PKG_DATA'
icons_get_from_package 'APP_MAIN'

# Write launchers

for PKG in 'PKG_BIN32' 'PKG_BIN64'; do
	if packages_get_list | grep --quiet "$PKG"; then
		launchers_write 'APP_MAIN'
	fi
done

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
