#!/bin/sh
set -o errexit

###
# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Blacksad: Under the Skin
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20211027.1

# Set game-specific variables

GAME_ID='blacksad-under-the-skin'
GAME_NAME='Blacksad: Under the Skin'

ARCHIVE_BASE_0='setup_blacksad_under_the_skin_1.0.5_12210.2935.2020040301_(37312).exe'
ARCHIVE_BASE_0_MD5='9c9211aac30170bf4ac85950094f99a2'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1='setup_blacksad_under_the_skin_1.0.5_12210.2935.2020040301_(37312)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='0d21ed49ef3377b4816ae364cbb5eee1'
ARCHIVE_BASE_0_PART1_TYPE='innosetup'
ARCHIVE_BASE_0_PART2='setup_blacksad_under_the_skin_1.0.5_12210.2935.2020040301_(37312)-2.bin'
ARCHIVE_BASE_0_PART2_MD5='58e82951055a5c863cd804f2421e729f'
ARCHIVE_BASE_0_PART2_TYPE='innosetup'
ARCHIVE_BASE_0_PART3='setup_blacksad_under_the_skin_1.0.5_12210.2935.2020040301_(37312)-3.bin'
ARCHIVE_BASE_0_PART3_MD5='acf9dc21ffa4d483b124561e5b19633d'
ARCHIVE_BASE_0_PART3_TYPE='innosetup'
ARCHIVE_BASE_0_PART4='setup_blacksad_under_the_skin_1.0.5_12210.2935.2020040301_(37312)-4.bin'
ARCHIVE_BASE_0_PART4_MD5='d1c80d50a67c2a4212e9898416193562'
ARCHIVE_BASE_0_PART4_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='16000000'
ARCHIVE_BASE_0_VERSION='1.0.5-gog37312'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/blacksad_under_the_skin'

UNITY3D_NAME='blacksad'

ARCHIVE_GAME_BIN_PATH='.'
ARCHIVE_GAME_BIN_FILES="
*.dll
mono
${UNITY3D_NAME}.exe
${UNITY3D_NAME}_data/plugins"

ARCHIVE_GAME_DATA_ASSETS_PATH='.'
ARCHIVE_GAME_DATA_ASSETS_FILES="
${UNITY3D_NAME}_data/streamingassets"

ARCHIVE_GAME_DATA_PATH='.'
ARCHIVE_GAME_DATA_FILES="
${UNITY3D_NAME}_data"

APP_MAIN_TYPE='wine'
APP_MAIN_EXE="${UNITY3D_NAME}.exe"
APP_MAIN_ICON="${UNITY3D_NAME}.exe"

PACKAGES_LIST='PKG_BIN PKG_DATA_ASSETS PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_DATA_ASSETS_ID="${PKG_DATA_ID}-assets"
PKG_DATA_ASSETS_DESCRIPTION="$PKG_DATA_DESCRIPTION - assets"
PKG_DATA_DEPS="$PKG_DATA_DEPS $PKG_DATA_ASSETS_ID"

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID wine"

# Use persistent storage for user data

APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
userdata:users/$(id -un)/AppData/LocalLow/PenduloStudios/Blacksad'
DATA_DIRS="$DATA_DIRS ./userdata"

# Load common functions

target_version='2.14'

if [ -z "$PLAYIT_LIB2" ]; then
	for path in \
		"$PWD" \
		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
		'/usr/local/share/games/play.it' \
		'/usr/local/share/play.it' \
		'/usr/share/games/play.it' \
		'/usr/share/play.it'
	do
		if [ -e "${path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=play.it-2/lib/libplayit2.sh
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Delete temporary files

rm --recursive "$PLAYIT_WORKDIR/gamedata"

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
