#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2020 Mopi
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Broken Sword 4
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220126.1

# Set game-specific variables

GAME_ID='broken-sword-4'
GAME_NAME='Broken Sword Ⅳ: The Angel of Death'

ARCHIVE_BASE_FR_1='setup_broken_sword_4_the_angel_of_death_1.1a_(french)_(24519).exe'
ARCHIVE_BASE_FR_1_MD5='75736ac9d99d3a9c8fcc509bf425eaa3'
ARCHIVE_BASE_FR_1_TYPE='innosetup'
ARCHIVE_BASE_FR_1_PART1='setup_broken_sword_4_the_angel_of_death_1.1a_(french)_(24519)-1.bin'
ARCHIVE_BASE_FR_1_PART1_MD5='3600609e744183605ca94f5ab5e36325'
ARCHIVE_BASE_FR_1_PART1_TYPE='innosetup'
ARCHIVE_BASE_FR_1_SIZE='2800000'
ARCHIVE_BASE_FR_1_VERSION='1.1a-gog24519'
ARCHIVE_BASE_FR_1_URL='https://www.gog.com/game/broken_sword_4'

ARCHIVE_BASE_EN_1='setup_broken_sword_4_the_angel_of_death_1.1a_(24519).exe'
ARCHIVE_BASE_EN_1_MD5='25ed1fcd2a322bc6f722b84e899cdeb0'
ARCHIVE_BASE_EN_1_TYPE='innosetup'
ARCHIVE_BASE_EN_1_PART1='setup_broken_sword_4_the_angel_of_death_1.1a_(24519)-1.bin'
ARCHIVE_BASE_EN_1_PART1_MD5='75e4b7cc0c7d96f56c070a71442c49c0'
ARCHIVE_BASE_EN_1_PART1_TYPE='innosetup'
ARCHIVE_BASE_EN_1_SIZE='2800000'
ARCHIVE_BASE_EN_1_VERSION='1.1a-gog24519'
ARCHIVE_BASE_EN_1_URL='https://www.gog.com/game/broken_sword_4'

ARCHIVE_BASE_EN_0='setup_broken_sword_4_1.1_(15751).exe'
ARCHIVE_BASE_EN_0_MD5='b53297cce551b12e8bef23dade1eda68'
ARCHIVE_BASE_EN_0_TYPE='innosetup'
ARCHIVE_BASE_EN_0_PART1='setup_broken_sword_4_1.1_(15751)-1.bin'
ARCHIVE_BASE_EN_0_PART1_MD5='4518a353cc41a95745095ddfb220c750'
ARCHIVE_BASE_EN_0_PART1_TYPE='innosetup'
ARCHIVE_BASE_EN_0_SIZE='2900000'
ARCHIVE_BASE_EN_0_VERSION='1.1-gog15751'

CONTENT_PATH_DEFAULT='.'
CONTENT_PATH_DEFAULT_EN_0='app'
ARCHIVE_DOC_DATA_FILES='
manual.pdf'
ARCHIVE_GAME_BIN_FILES='
*.dll
bs4pc.exe
system'
ARCHIVE_GAME_L10N_FILES='
english.pak
french.pak'
ARCHIVE_GAME_DATA_FILES='
audio.pak
bs4.pak
data'
ARCHIVE_GAME0_DATA_PATH="${CONTENT_PATH_DEFAULT}/app"
ARCHIVE_GAME0_DATA_FILES='data'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='bs4pc.exe'
APP_MAIN_ICON='bs4pc.exe'

PACKAGES_LIST='PKG_BIN PKG_L10N PKG_DATA'

PKG_L10N_ID="${GAME_ID}-l10n"
PKG_L10N_ID_EN="${PKG_L10N_ID}-en"
PKG_L10N_ID_FR="${PKG_L10N_ID}-fr"
PKG_L10N_PROVIDE="$PKG_L10N_ID"
PKG_L10N_DESCRIPTION_EN='English localization'
PKG_L10N_DESCRIPTION_FR='French localization'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_L10N_ID $PKG_DATA_ID wine"

# Use persistent storage for user data

APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
saves:users/${USER}/Documents/Broken Sword - The Angel of Death'
DATA_DIRS='./saves'

# Load common functions

target_version='2.15'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Enable dxvk patches in the WINE prefix

# shellcheck disable=SC1004
APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
# Install dxvk on first launch
if [ ! -e dxvk_installed ]; then
	# Wait until the WINE prefix creation is complete
	printf "Waiting for the WINE prefix initialization to complete, it might take a couple seconds…\n"
	while [ ! -f "${WINEPREFIX}/system.reg" ]; do
		sleep 1s
	done

	if \
		command -v dxvk-setup >/dev/null 2>&1 && \
		command -v wine-development >/dev/null 2>&1
	then
		dxvk-setup install --development
		touch dxvk_installed
	elif command -v winetricks >/dev/null 2>&1; then
		winetricks dxvk
		touch dxvk_installed
	else
		message="\\033[1;33mWarning:\\033[0m\\n"
		message="${message}DXVK patches could not be installed in the WINE prefix.\\n"
		message="${message}The game might run with display or performance issues.\\n"
		printf "\\n${message}\\n"
	fi

	# Wait a bit to ensure there is no lingering wine process
	sleep 1s
fi'
case "$OPTION_PACKAGE" in
	('deb')
		# Debian-based distributions should use repositories-provided dxvk
		# winetricks is used as a fallback for branches not having access to dxvk-setup
		extra_dependencies='mesa-vulkan-drivers | vulkan-icd, dxvk-wine64-development | winetricks, dxvk | winetricks'
		if [ -n "$PKG_BIN_DEPS_DEB" ]; then
			PKG_BIN_DEPS_DEB="${PKG_BIN_DEPS_DEB}, ${extra_dependencies}"
		else
			PKG_BIN_DEPS_DEB="$extra_dependencies"
		fi
	;;
	(*)
		# Default is to use winetricks
		PKG_BIN_DEPS="${PKG_BIN_DEPS} winetricks"
	;;
esac

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Write launchers

launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
