#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Civilization 4
# send your bug reports to contact@dotslashplay.it
###

script_version=20221231.1

GAME_ID='civilization-4'
GAME_NAME='Civilization Ⅳ'

ARCHIVE_BASE_0='setup_civilization4_complete_2.0.0.4.exe'
ARCHIVE_BASE_0_MD5='8ddc5e0129d216cb397e8da5f95a8c92'
ARCHIVE_BASE_0_EXTRACTOR='innoextract'
ARCHIVE_BASE_0_EXTRACTOR_OPTIONS='--progress=1 --silent --gog'
ARCHIVE_BASE_0_PART1='setup_civilization4_complete_2.0.0.4-1.bin'
ARCHIVE_BASE_0_PART1_MD5='dbf971c1acbad3648697c7c343f14aad'
ARCHIVE_BASE_0_PART1_EXTRACTOR='unar'
ARCHIVE_BASE_0_SIZE='4800000'
ARCHIVE_BASE_0_VERSION='1.7.4.0-gog2.0.0.4'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/sid_meiers_civilization_iv_the_complete_edition'

CONTENT_PATH_DEFAULT='game/Civ4'
CONTENT_GAME_BIN_WARLORDS_FILES='
Warlords/Assets/Python/System
Warlords/CvGameCoreDLL
Warlords/*.dll
Warlords/*.exe'
CONTENT_GAME_BIN_SWORD_FILES='
Beyond the Sword/CvGameCoreDLL
Beyond the Sword/*.dll
Beyond the Sword/*.exe'
CONTENT_GAME_BIN_FILES='
Assets/Python/System
CvGameCoreDLL
Miles
*.dll
*.exe'
CONTENT_GAME_DATA_WARLORDS_FILES='
Warlords/Assets
Warlords/Mods
Warlords/PublicMaps
Warlords/Resource
Warlords/Shaders'
CONTENT_GAME_DATA_SWORD_FILES='
Beyond the Sword/Assets
Beyond the Sword/Mods
Beyond the Sword/PublicMaps
Beyond the Sword/Resource
Beyond the Sword/Shaders'
CONTENT_GAME_DATA_FILES='
Assets
Mods
PublicMaps
Resource
Shaders'
CONTENT_DOC_DATA_WARLORDS_PATH="${CONTENT_PATH_DEFAULT}/.."
CONTENT_DOC_DATA_WARLORDS_FILES="
Sid Meier's Civilization 4 - Warlords.pdf
Sid Meier's Civilization 4 - Warlords (FR).pdf"
CONTENT_DOC_DATA_SWORD_PATH="${CONTENT_PATH_DEFAULT}/.."
CONTENT_DOC_DATA_SWORD_FILES="
Sid Meier's Civilization 4 - Beyond the Sword.pdf
Sid Meier's Civilization 4 - Beyond the Sword (FR).pdf"
CONTENT_DOC_DATA_PATH="${CONTENT_PATH_DEFAULT}/.."
CONTENT_DOC_DATA_FILES="
Sid Meier's Civilization 4.pdf
Sid Meier's Civilization 4 (FR).pdf"
CONTENT_DOC0_DATA_PATH="${CONTENT_PATH_DEFAULT}/../Readme"
CONTENT_DOC0_DATA_FILES='
*/Readme.htm'

APP_MAIN_EXE='Civilization4.exe'
APP_MAIN_ICON='Assets/res/Civ4Game.ico'

APP_WARLORDS_ID="${GAME_ID}-warlords"
APP_WARLORDS_NAME="$GAME_NAME - Warlords"
APP_WARLORDS_EXE='Warlords/Civ4Warlords.exe'
APP_WARLORDS_ICONS_LIST='APP_WARLORDS_ICON16 APP_WARLORDS_ICON32 APP_WARLORDS_ICON64'
APP_WARLORDS_ICON16='Warlords/Assets/res/CIV_Warlords_16.ico'
APP_WARLORDS_ICON32='Warlords/Assets/res/CIV_Warlords_32.ico'
APP_WARLORDS_ICON64='Warlords/Assets/res/CIV_Warlords_64.ico'

APP_SWORD_ID="${GAME_ID}-beyond-the-sword"
APP_SWORD_NAME="$GAME_NAME - Beyond the Sword"
APP_SWORD_EXE='Beyond the Sword/Civ4BeyondSword.exe'
APP_SWORD_ICON='Beyond the Sword/Assets/res/Civ4BtS.ico'

APP_WINE_LINK_DIRS='
userdata:users/${USER}/AppData/Local/My Games/civilization-4
userdocs:users/${USER}/Documents/My Games/civilization-4
userdata_warlords:users/${USER}/AppData/Local/My Games/Warlords
userdocs_warlords:users/${USER}/Documents/My Games/Warlords
userdata_beyond-the-sword:users/${USER}/AppData/Local/My Games/Beyond the Sword
userdocs_beyond-the-sword:users/${USER}/Documents/My Games/Beyond the Sword'
USER_PERSISTENT_DIRECTORIES='
userdata/Profiles
userdocs/Saves
userdata_warlords/Profiles
userdocs_warlords/Saves
userdata_beyond-the-sword/Profiles
userdocs_beyond-the-sword/Saves'
USER_PERSISTENT_FILES='
userdocs/CivilizationIV.ini
userdocs_warlords/CivilizationIV.ini
userdocs_beyond-the-sword/CivilizationIV.ini'

PACKAGES_LIST='PKG_BIN_WARLORDS PKG_BIN_SWORD PKG_BIN PKG_DATA_WARLORDS PKG_DATA_SWORD PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_DATA_WARLORDS_ID="${GAME_ID}-warlords-data"
PKG_DATA_WARLORDS_DESCRIPTION='Warlords - data'
PKG_DATA_WARLORDS_DEPS="$PKG_DATA_ID"

PKG_DATA_SWORD_ID="${GAME_ID}-beyond-the-sword-data"
PKG_DATA_SWORD_DESCRIPTION='Beyond the Sword - data'
PKG_DATA_SWORD_DEPS="$PKG_DATA_ID"

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID"

PKG_BIN_WARLORDS_ID="${GAME_ID}-warlords"
PKG_BIN_WARLORDS_DESCRIPTION='Warlords'
PKG_BIN_WARLORDS_ARCH='32'
PKG_BIN_WARLORDS_DEPS="$PKG_DATA_WARLORDS_ID"

PKG_BIN_SWORD_ID="${GAME_ID}-beyond-the-sword"
PKG_BIN_SWORD_DESCRIPTION='Beyond the Sword'
PKG_BIN_SWORD_ARCH='32'
PKG_BIN_SWORD_DEPS="$PKG_DATA_SWORD_ID"

# Load common functions

target_version='2.21'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_inclusion 'APP_MAIN'
PKG='PKG_DATA_WARLORDS'
icons_inclusion 'APP_WARLORDS'
PKG='PKG_DATA_SWORD'
icons_inclusion 'APP_SWORD'

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Ensure fonts expected by the game are available

path_game_data=$(path_game_data)
PATH_FONTS="${OPTION_PREFIX}/share/fonts/truetype/$(game_id)"
package_path=$(package_get_path 'PKG_DATA')
mkdir --parents "${package_path}${PATH_FONTS}"
for font_file in \
	'Assets/res/Fonts/sylfaen.ttf' \
	'Resource/Civ4/sylfaenbi.ttf' \
	'Resource/Civ4/sylfaenb.ttf' \
	'Resource/Civ4/sylfaeni.ttf' \
	'Resource/Civ4/sylfaen.ttf' \
	'Resource/Fonts/arial.ttf' \
	'Resource/Fonts/sylfaen.ttf'
do
	font_path_game="${path_game_data}/${font_file}"
	font_path_system="${PATH_FONTS}/$(basename "$font_file")"
	mv --force "${package_path}${font_path_game}" "${package_path}${font_path_system}"
	ln --symbolic "$font_path_system" "${package_path}${font_path_game}"
done

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'
(
	# Ensure the winecfg launcher is not written,
	# it is already provided by the main game package.
	launcher_write_script_wine_winecfg() { true ; }
	launcher_write_desktop() {
		local application desktop_file
		application="$1"
		desktop_file=$(launcher_desktop_filepath "$application")
		mkdir --parents "$(dirname "$desktop_file")"
		launcher_desktop "$application" > "$desktop_file"
	}
	PKG='PKG_BIN_WARLORDS'
	launchers_write 'APP_WARLORDS'
	PKG='PKG_BIN_SWORD'
	launchers_write 'APP_SWORD'
)

# Build package

write_metadata
build_pkg

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
