#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2020 Mopi
# SPDX-FileCopyrightText: © 2023 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Cook, Serve, Delicious 2
# send your bug reports to contact@dotslashplay.it
###

script_version=20230817.1

GAME_ID='cook-serve-delicious-2'
GAME_NAME='Cook, Serve, Delicious! 2!!'

ARCHIVE_BASE_0='CSD2_Linux_v2_60m1_1.zip'
ARCHIVE_BASE_0_MD5='1842d43dc715a61d1776a3432b7bf758'
ARCHIVE_BASE_0_SIZE='1000000'
ARCHIVE_BASE_0_VERSION='1.0-itch1'
ARCHIVE_BASE_0_URL='https://chubigans.itch.io/cook-serve-delicious-2'

CONTENT_PATH_DEFAULT='.'
CONTENT_GAME_BIN_FILES='
NEW_CSD2_PS4Steam'
CONTENT_GAME_DATA_FILES='
assets'

USER_PERSISTENT_FILES='
assets/options.ini'

APP_MAIN_EXE='NEW_CSD2_PS4Steam'
APP_MAIN_ICON='assets/icon.png'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libcurl-gnutls.so.4
libdl.so.2
libgcc_s.so.1
libGL.so.1
libGLU.so.1
libm.so.6
libpthread.so.0
librt.so.1
libstdc++.so.6
libX11.so.6
libXext.so.6
libXrandr.so.2
libXxf86vm.so.1
libz.so.1'

# Load common functions

target_version='2.25'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Ensure availability of required OpenSSL libraries

ARCHIVE_REQUIRED_OPENSSL='libssl_1.0.0_64-bit.tar.gz'
ARCHIVE_REQUIRED_OPENSSL_MD5='89917bef5dd34a2865cb63c2287e0bd4'
ARCHIVE_REQUIRED_OPENSSL_URL='https://downloads.dotslashplay.it/resources/libssl/'
CONTENT_OPENSSL_PATH='.'
CONTENT_OPENSSL_FILES='
libcrypto.so.1.0.0
libssl.so.1.0.0'
PKG_BIN_DEPENDENCIES_LIBRARIES="$(dependencies_list_native_libraries 'PKG_BIN')
libc.so.6
libdl.so.2"
archive_initialize_required \
	'ARCHIVE_OPENSSL' \
	'ARCHIVE_REQUIRED_OPENSSL'
archive_extraction 'ARCHIVE_OPENSSL'
content_inclusion 'OPENSSL' 'PKG_BIN' "$(path_libraries)"
rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
