#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2020 ahub
# SPDX-FileCopyrightText: © 2021 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Devil Daggers
# send your bug reports to contact@dotslashplay.it
###

script_version=20230815.1

GAME_ID='devil-daggers' # used for package name
GAME_NAME='Devil Daggers' # used for menu display

ARCHIVE_BASE_2='devil_daggers_v3_2_51024.sh'
ARCHIVE_BASE_2_MD5='f9f7f4c07ddfe248881e4adb9de79ab1'
ARCHIVE_BASE_2_SIZE='460000'
ARCHIVE_BASE_2_VERSION='3.2-gog51024'
ARCHIVE_BASE_2_URL='https://www.gog.com/game/devil_daggers'

ARCHIVE_BASE_1='devil_daggers_v3_1_45183.sh'
ARCHIVE_BASE_1_MD5='2276b69f73738a0bad313a6e442558f4'
ARCHIVE_BASE_1_SIZE='460000'
ARCHIVE_BASE_1_VERSION='3.1-gog45183'

ARCHIVE_BASE_0='devil_daggers_en_update_1_20080.sh'
ARCHIVE_BASE_0_MD5='cf92f20e5a1662e9585fa500608ebdd1'
ARCHIVE_BASE_0_SIZE='420000' # rounded up
ARCHIVE_BASE_0_VERSION='3.0-gog20080' # get that from the filename gameVersion-providerVersion

CONTENT_PATH_DEFAULT='data/noarch/game'
CONTENT_GAME_BIN_FILES='
devildaggers'
CONTENT_GAME_DATA_FILES='
dd
core
res
default-44100.mhr
default-48000.mhr'

APP_MAIN_EXE='devildaggers'
APP_MAIN_ICON='../support/icon.png'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libdl.so.2
libgcc_s.so.1
libGL.so.1
libm.so.6
libopenal.so.1
libpthread.so.0
libstdc++.so.6
libX11.so.6
libz.so.1'

# Load common functions

target_version='2.25'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Ensure availability of OpenSSL 1.1 libraries

ARCHIVE_REQUIRED_OPENSSL='openssl_1.1.1n.tar.xz'
ARCHIVE_REQUIRED_OPENSSL_URL='https://downloads.dotslashplay.it/resources/openssl1.1/'
ARCHIVE_REQUIRED_OPENSSL_MD5='dade7a54b213be8ac6e0bc2b571570cc'
CONTENT_OPENSSL_PATH='x86_64-linux-gnu'
CONTENT_OPENSSL_FILES='
libcrypto.so.1.1
libssl.so.1.1'
archive_initialize_required \
	'ARCHIVE_OPENSSL' \
	'ARCHIVE_REQUIRED_OPENSSL'
archive_extraction 'ARCHIVE_OPENSSL'
content_inclusion 'OPENSSL' 'PKG_BIN' "$(path_libraries)"
rm --recursive "${PLAYIT_WORKDIR}/gamedata"
PKG_BIN_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES
libc.so.6
libdl.so.2
libpthread.so.0"

# Ensure availability of CURL_OPENSSL_3 symbol with game build < 3.1

case "$(context_archive)" in
	('ARCHIVE_BASE_0')
		ARCHIVE_REQUIRED_LIBCURL3='curl_7.52.1_amd64.tar.xz'
		ARCHIVE_REQUIRED_LIBCURL3_URL='https://downloads.dotslashplay.it/resources/curl/'
		ARCHIVE_REQUIRED_LIBCURL3_MD5='493fe839171c9dac03a94d832697899c'
		CONTENT_LIBCURL3_PATH='.'
		CONTENT_LIBCURL3_FILES='
		libcrypto.so.1.0.2
		libssl.so.1.0.2
		libcurl.so.3
		libcurl.so.4
		libcurl.so.4.4.0'
		archive_initialize_required \
			'ARCHIVE_LIBCURL3' \
			'ARCHIVE_REQUIRED_LIBCURL3'
		archive_extraction 'ARCHIVE_LIBCURL3'
		content_inclusion 'LIBCURL3' 'PKG_BIN' "$(path_libraries)"
		rm --recursive "${PLAYIT_WORKDIR}/gamedata"
		PKG_BIN_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES
		libcom_err.so.2
		libc.so.6
		libdl.so.2
		libgssapi_krb5.so.2
		libidn2.so.0
		libk5crypto.so.3
		libkrb5.so.3
		libnghttp2.so.14
		libpsl.so.5
		libpthread.so.0
		librtmp.so.1
		libssh2.so.1
		libz.so.1"
	;;
esac

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
