#!/bin/sh
set -o errexit

###
# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
# Copyright (c) 2015-2021, mortalius
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Don't Starve: Shipwrecked
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20211217.2

# Set game-specific variables

GAME_ID='dont-starve'
GAME_NAME='Donʼt Starve'

EXPANSION_ID='shipwrecked'
EXPANSION_NAME='Shipwrecked'

ARCHIVE_BASE_0='don_t_starve_shipwrecked_dlc_4294041_41439.sh'
ARCHIVE_BASE_0_MD5='ff762f9b6a3ef71e6b802fe596196925'
ARCHIVE_BASE_0_TYPE='mojosetup'
ARCHIVE_BASE_0_SIZE='830000'
ARCHIVE_BASE_0_VERSION='4294041-gog41439'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/dont_starve_shipwrecked'

ARCHIVE_BASE_MULTIARCH_1='don_t_starve_shipwrecked_dlc_en_20171215_17628.sh'
ARCHIVE_BASE_MULTIARCH_1_MD5='463825173d76f294337f0ae7043d7cf6'
ARCHIVE_BASE_MULTIARCH_1_TYPE='mojosetup'
ARCHIVE_BASE_MULTIARCH_1_SIZE='1200000'
ARCHIVE_BASE_MULTIARCH_1_VERSION='246924-gog17628'

ARCHIVE_BASE_MULTIARCH_0='gog_don_t_starve_shipwrecked_dlc_2.0.0.2.sh'
ARCHIVE_BASE_MULTIARCH_0_MD5='b1d4152639a272a959d36eacf8cb859e'
ARCHIVE_BASE_MULTIARCH_0_TYPE='mojosetup'
ARCHIVE_BASE_MULTIARCH_0_SIZE='1200000'
ARCHIVE_BASE_MULTIARCH_0_VERSION='1.0-gog2.0.0.2'

CONTENT_PATH_DEFAULT='data/noarch/game'

ARCHIVE_GAME_MAIN_PATH="$CONTENT_PATH_DEFAULT"
ARCHIVE_GAME_MAIN_FILES='
data
manifest_dlc0002.json'

PKG_MAIN_ID="${GAME_ID}-${EXPANSION_ID}"
PKG_MAIN_DESCRIPTION="$EXPANSION_NAME"
PKG_MAIN_DEPS="$GAME_ID"

# Keep compatibility with old archives

CONTENT_PATH_DEFAULT_MULTIARCH='data/noarch/game/dontstarve32'
ARCHIVE_GAME_MAIN_PATH_MULTIARCH="$CONTENT_PATH_DEFAULT_MULTIARCH"

# Load common functions

target_version='2.14'

if [ -z "$PLAYIT_LIB2" ]; then
	for path in \
		"$PWD" \
		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
		'/usr/local/share/games/play.it' \
		'/usr/local/share/play.it' \
		'/usr/share/games/play.it' \
		'/usr/share/play.it'
	do
		if [ -e "${path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=play.it-2/lib/libplayit2.sh
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

GAME_NAME="$GAME_NAME - $EXPANSION_NAME"
print_instructions

exit 0
