#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Mopi
# SPDX-FileCopyrightText: © 2017 Antoine Le Gonidec <vv221@dotslashplay.it>
# SPDX-FileCopyrightText: © 2018 BetaRays
# SPDX-FileCopyrightText: © 2021 Hoël Bézier
set -o errexit

###
# Don't Starve
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220928.1

GAME_ID='dont-starve'
GAME_NAME='Donʼt Starve'

ARCHIVE_BASE_0='don_t_starve_4294041_41439.sh'
ARCHIVE_BASE_0_MD5='05baa7fb659f79d4676a59bf3a64fc76'
ARCHIVE_BASE_0_TYPE='mojosetup'
ARCHIVE_BASE_0_SIZE='950000'
ARCHIVE_BASE_0_VERSION='4294041-gog41439'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/dont_starve'

ARCHIVE_BASE_OLDPATH_0='don_t_starve_en_222215_22450.sh'
ARCHIVE_BASE_OLDPATH_0_MD5='611cd70afd9b9feb3aca4d1eaf9ebbda'
ARCHIVE_BASE_OLDPATH_0_TYPE='mojosetup'
ARCHIVE_BASE_OLDPATH_0_SIZE='760000'
ARCHIVE_BASE_OLDPATH_0_VERSION='276758-gog22450'

ARCHIVE_BASE_MULTIARCH_2='don_t_starve_en_20171215_17629.sh'
ARCHIVE_BASE_MULTIARCH_2_MD5='f7dda3b3bdb15ac62acb212a89b24623'
ARCHIVE_BASE_MULTIARCH_2_TYPE='mojosetup'
ARCHIVE_BASE_MULTIARCH_2_SIZE='670000'
ARCHIVE_BASE_MULTIARCH_2_VERSION='246924-gog17629'

ARCHIVE_BASE_MULTIARCH_1='gog_don_t_starve_2.7.0.9.sh'
ARCHIVE_BASE_MULTIARCH_1_MD5='01d7496de1c5a28ffc82172e89dd9cd6'
ARCHIVE_BASE_MULTIARCH_1_TYPE='mojosetup'
ARCHIVE_BASE_MULTIARCH_1_SIZE='660000'
ARCHIVE_BASE_MULTIARCH_1_VERSION='222215-gog2.7.0.9'

ARCHIVE_BASE_MULTIARCH_0='gog_don_t_starve_2.6.0.8.sh'
ARCHIVE_BASE_MULTIARCH_0_MD5='2b0d363bea53654c0267ae424de7130a'
ARCHIVE_BASE_MULTIARCH_0_TYPE='mojosetup'
ARCHIVE_BASE_MULTIARCH_0_SIZE='650000'
ARCHIVE_BASE_MULTIARCH_0_VERSION='198251-gog2.6.0.8'

CONTENT_PATH_DEFAULT='data/noarch/game'
CONTENT_PATH_DEFAULT_OLDPATH='data/noarch/game/dontstarve64'
CONTENT_PATH_DEFAULT_MULTIARCH='data/noarch/game/dontstarve64'
CONTENT_GAME_BIN64_FILES='
bin/dontstarve
bin/lib64/libfmodevent64.so
bin/lib64/libfmodevent64-4.44.??.so
bin/lib64/libfmodex64.so
bin/lib64/libfmodex64-4.44.??.so
bin/lib64/libSDL2*
*.json'
CONTENT_GAME_DATA_FILES='
data
mods
dontstarve.xpm'

APP_MAIN_TYPE='native'
APP_MAIN_EXE='bin/dontstarve'
APP_MAIN_ICON='dontstarve.xpm'

USER_PERSISTENT_DIRECTORIES='
mods'

PACKAGES_LIST='PKG_BIN64 PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN64_ARCH='64'
PKG_BIN64_DEPS="$PKG_DATA_ID"
PKG_BIN64_DEPENDENCIES_LIBRARIES='
libc.so.6
libcurl-gnutls.so.4
libdl.so.2
libgcc_s.so.1
libGL.so.1
libm.so.6
libpthread.so.0
librt.so.1
libstdc++.so.6'

# Run the game binary from its parent directory

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'

# Run the game binary from its parent directory
cd "$(dirname "$APP_EXE")"
APP_EXE=$(basename "$APP_EXE")'

# Keep compatibility with old archives

CONTENT_GAME_BIN32_PATH='data/noarch/game/dontstarve32'
CONTENT_GAME_BIN32_FILES='
bin/dontstarve
bin/lib32/libfmodevent.so
bin/lib32/libfmodevent-4.44.??.so
bin/lib32/libfmodex.so
bin/lib32/libfmodex-4.44.??.so
bin/lib32/libSDL2*
*.json'

PKG_BIN32_ARCH='32'
PKG_BIN32_DEPS="$PKG_BIN64_DEPS"

PACKAGES_LIST_MULTIARCH='PKG_BIN32 PKG_BIN64 PKG_DATA'

# Load common functions

target_version='2.18'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "$PLAYIT_WORKDIR/gamedata"

# Write launchers

for PKG in 'PKG_BIN32' 'PKG_BIN64'; do
	if \
		packages_get_list | \
		grep --quiet --fixed-strings --word-regexp "$PKG"
	then
		launchers_write
	fi
done

# Build package

write_metadata
build_pkg

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
