#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2019 BetaRays
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Duet
# send your bug reports to contact@dotslashplay.it
###

script_version=20230819.3

GAME_ID='duet'
GAME_NAME='Duet'

# This DRM-free build is no longer available for sale from humblebundle.com
ARCHIVE_BASE_0='Duet-Build1006023-Linux64.zip'
ARCHIVE_BASE_0_MD5='b9c34c29da94c199ee75a5e71272a1eb'
ARCHIVE_BASE_0_SIZE='210000'
ARCHIVE_BASE_0_VERSION='1.0-humble1006023'

CONTENT_PATH_DEFAULT='.'
CONTENT_LIBS_BIN_FILES='
libjpeg.so.8
libjpeg.so.8.0.2
libsfml-audio.so.2.3
libsfml-graphics.so.2.3
libsfml-system.so.2.3
libsfml-window.so.2.3
libsteam_api.so
libudev.so.0
libudev.so.0.13.0'
CONTENT_LIBS0_BIN_PATH='steam-runtime/amd64/usr/lib/x86_64-linux-gnu'
CONTENT_LIBS0_BIN_FILES='
libjpeg.so.8
libjpeg.so.8.0.2'
## TODO - Check if libudev.so.0 could be replaced with system-provided libudev0-shim.
CONTENT_LIBS1_BIN_PATH='steam-runtime/amd64/lib/x86_64-linux-gnu'
CONTENT_LIBS1_BIN_FILES='
libudev.so.0
libudev.so.0.13.0'
CONTENT_GAME_BIN_FILES='
Duet'
CONTENT_GAME_DATA_FILES='
Media'

APP_MAIN_EXE='Duet'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libdl.so.2
libfreetype.so.6
libgcc_s.so.1
libGL.so.1
libm.so.6
libogg.so.0
libopenal.so.1
libpthread.so.0
librt.so.1
libstdc++.so.6
libvorbisenc.so.2
libvorbisfile.so.3
libvorbis.so.0
libX11.so.6
libX11-xcb.so.1
libxcb-randr.so.0
libxcb.so.1'

# Load common functions

target_version='2.25'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Ensure availability of libFLAC.so.8

ARCHIVE_REQUIRED_LIBFLAC8='libflac8.tar.xz'
ARCHIVE_REQUIRED_LIBFLAC8_MD5='1f0d785f52474cb2232a2f8f8b561eda'
ARCHIVE_REQUIRED_LIBFLAC8_URL='https://downloads.dotslashplay.it/resources/flac/'
CONTENT_LIBFLAC8_PATH='x86_64-linux-gnu'
CONTENT_LIBFLAC8_FILES='
libFLAC.so.8
libFLAC.so.8.3.0'
archive_initialize_required \
	'ARCHIVE_LIBFLAC8' \
	'ARCHIVE_REQUIRED_LIBFLAC8'
archive_extraction 'ARCHIVE_LIBFLAC8'
content_inclusion 'LIBFLAC8' 'PKG_BIN' "$(path_libraries)"
rm --recursive "${PLAYIT_WORKDIR}/gamedata"
extra_dependencies='
libc.so.6
libm.so.6
libogg.so.0'
dependencies_add_native_libraries 'PKG_BIN' "$extra_dependencies"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

ARCHIVE_OPTIONAL_ICONS='duet_icons.tar.xz'
ARCHIVE_OPTIONAL_ICONS_MD5='57d79a524801768a742405a7a5310e08'
ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/games/duet/'
CONTENT_ICONS_PATH='.'
CONTENT_ICONS_FILES='
16x16
32x32
48x48
128x128
256x256'
archive_initialize_optional 'ARCHIVE_ICONS' 'ARCHIVE_OPTIONAL_ICONS'
if [ -n "${ARCHIVE_ICONS:-}" ]; then
	archive_extraction 'ARCHIVE_ICONS'
	content_inclusion 'ICONS' 'PKG_DATA' "$(path_icons)"
fi

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
