#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Mopi
# SPDX-FileCopyrightText: © 2017 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Edna & Harvey: Harvey's New Eyes
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220703.1

GAME_ID='edna-and-harvey-harveys-new-eyes'
GAME_NAME='Edna & Harvey: Harveyʼs New Eyes'

ARCHIVE_BASE_0='gog_edna_harvey_harvey_s_new_eyes_2.0.0.1.sh'
ARCHIVE_BASE_0_MD5='fa6f7fd271fe63bbe71e3190e0596546'
ARCHIVE_BASE_0_TYPE='mojosetup'
ARCHIVE_BASE_0_SIZE='990000'
ARCHIVE_BASE_0_VERSION='3.0.0442-gog2.0.0.1'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/edna_harvey_harveys_new_eyes'

CONTENT_PATH_DEFAULT='data/noarch/game'
ARCHIVE_DOC_FILES='
documents
version.txt'
ARCHIVE_GAME_BIN_FILES='
harvey
config.ini
libs64'
ARCHIVE_GAME_DATA_FILES='
characters
data.vis
lua
scenes
videos'

APP_MAIN_TYPE='native'
APP_MAIN_EXE='harvey'
APP_MAIN_LIBS='libs64'
APP_MAIN_ICON='data/noarch/support/icon.png'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID libc.so.6 libstdc++.so.6 libopenal.so.1 libz.so.1 libGL.so.1"

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'
prepare_package_layout

# Include game icon

PKG='PKG_DATA'
icons_get_from_workdir 'APP_MAIN'

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
