#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2022 Mopi
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Factory Town
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220509.1

# Set game-specific variables

GAME_ID='factory-town'
GAME_NAME='Factory Town'

ARCHIVE_BASE_0='setup_factory_town_1.13.3_(64bit)_(53563).exe'
ARCHIVE_BASE_0_MD5='4b9199687bd79a1d8f7641bf4577a2dd'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='630000'
ARCHIVE_BASE_0_VERSION='1.13.3-gog53563'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/factory_town'

UNITY3D_NAME='factory town'

CONTENT_PATH_DEFAULT='.'
ARCHIVE_GAME_BIN_FILES='
factory?town.exe
factory?town_data/plugins
monobleedingedge
unitycrashhandler64.exe
unityplayer.dll'
ARCHIVE_GAME_DATA_FILES='
factory?town_data'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE="${UNITY3D_NAME}.exe"
APP_MAIN_ICON="${UNITY3D_NAME}.exe"

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID wine"

# Use a dedicated log file for the current game session

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'

# Use a dedicated log file for the current game session
mkdir --parents logs
APP_OPTIONS="${APP_OPTIONS} -logFile ./logs/$(date +%F-%R).log"'

# Work around missing text

PKG_BIN_DEPS="$PKG_BIN_DEPS winetricks"
APP_WINETRICKS="$APP_WINETRICKS arial"

# Use persistent storage for user data

APP_WINE_LINK_DIRS='
userdata:users/${USER}/AppData/LocalLow/82 Apps/Factory Town'
DATA_DIRS='userdata/Saved?Games'

# Load common functions

target_version='2.15'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Use persistent storage for user data

PKG='PKG_BIN'
package_path=$(package_get_path "$PKG")
mkdir --parents "${package_path}${PATH_GAME}/userdata/Saved Games"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
