#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Mopi
# SPDX-FileCopyrightText: © 2017 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Fran Bow
# send your bug reports to contact@dotslashplay.it
###

script_version=20230817.1

GAME_ID='fran-bow'
GAME_NAME='Fran Bow'

ARCHIVE_BASE_0='gog_fran_bow_2.3.0.5.sh'
ARCHIVE_BASE_0_MD5='6e3013e9c8be4d25e1815f00bc177941'
ARCHIVE_BASE_0_SIZE='530000'
ARCHIVE_BASE_0_VERSION='160315-gog2.3.0.5'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/fran_bow'

CONTENT_PATH_DEFAULT='data/noarch/game'
CONTENT_GAME_BIN_FILES='
runner'
CONTENT_GAME_DATA_FILES='
assets'

APP_MAIN_EXE='runner'
APP_MAIN_ICON='assets/icon.png'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libdl.so.2
libgcc_s.so.1
libGL.so.1
libGLU.so.1
libm.so.6
libopenal.so.1
libpthread.so.0
librt.so.1
libstdc++.so.6
libX11.so.6
libXext.so.6
libXrandr.so.2
libXxf86vm.so.1
libz.so.1'

# Load common functions

target_version='2.25'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Ensure availability of required OpenSSL libraries

ARCHIVE_REQUIRED_OPENSSL='libssl_1.0.0_32-bit.tar.gz'
ARCHIVE_REQUIRED_OPENSSL_MD5='9443cad4a640b2512920495eaf7582c4'
ARCHIVE_REQUIRED_OPENSSL_URL='https://downloads.dotslashplay.it/resources/libssl/'
CONTENT_OPENSSL_PATH='.'
CONTENT_OPENSSL_FILES='
libcrypto.so.1.0.0
libssl.so.1.0.0'
PKG_BIN_DEPENDENCIES_LIBRARIES="$(dependencies_list_native_libraries 'PKG_BIN')
libc.so.6
libdl.so.2"
archive_initialize_required \
	'ARCHIVE_OPENSSL' \
	'ARCHIVE_REQUIRED_OPENSSL'
archive_extraction 'ARCHIVE_OPENSSL'
content_inclusion 'OPENSSL' 'PKG_BIN' "$(path_libraries)"
rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
