#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2023 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Frozen Synapse
# send your bug reports to contact@dotslashplay.it
###

script_version=20230215.1

GAME_ID='frozen-synapse'
GAME_NAME='Frozen Synapse'

ARCHIVE_BASE_0='frozen_synapse_en_35_hotfix_19572.sh'
ARCHIVE_BASE_0_MD5='7d629e7429b5250d0c9ca6b6d59f8b8a'
ARCHIVE_BASE_0_TYPE='mojosetup'
ARCHIVE_BASE_0_SIZE='270000'
ARCHIVE_BASE_0_VERSION='1.35-gog.19572'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/frozen_synapse'

CONTENT_PATH_DEFAULT='data/noarch/game'
CONTENT_GAME_BIN_FILES='
x86/FrozenSynapse'
CONTENT_GAME_DATA_FILES='
common
psychoff
TGB
tools
main.cs
cacert.pem
fs_icon.png
fontchars.txt
fontlist.txt'
CONTENT_DOC_DATA_FILES='
README-linux.txt
readme.txt'

APP_MAIN_EXE='x86/FrozenSynapse'
APP_MAIN_ICON='fs_icon.png'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libdl.so.2
libgcc_s.so.1
libm.so.6
libopenal.so.1
libpthread.so.0
libSDL-1.2.so.0
libstdc++.so.6'

# Load common functions

target_version='2.21'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# The game binary looks for libopenal.so instead of libopenal.so.1

## Unversioned libopenal.so is already provided by the base library packages
## on Arch Linux and Gentoo.
case "$OPTION_PACKAGE" in
	('deb')
		library_source='/usr/lib/i386-linux-gnu/libopenal.so.1'
		library_destination="$(package_path 'PKG_BIN')$(path_libraries)/libopenal.so"
		mkdir --parents "$(dirname "$library_destination")"
		ln --symbolic "$library_source" "$library_destination"
	;;
esac

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icon

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

write_metadata
build_pkg

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
