#!/bin/sh
set -o errexit

###
# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Giants: Citizen Kabuto
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20211007.1

# Set game-specific variables

GAME_ID='giants-citizen-kabuto'
GAME_NAME='Giants: Citizen Kabuto'

ARCHIVE_BASE_0='setup_giants_2.1.0.4.exe'
ARCHIVE_BASE_0_MD5='33015108ece9e52b1f525880f0867e11'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_VERSION='1.4-gog2.1.0.4'
ARCHIVE_BASE_0_SIZE='1600000'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/giants_citizen_kabuto'

ARCHIVE_DOC_DATA_PATH='app'
ARCHIVE_DOC_DATA_FILES='
*.txt
manual.pdf'

ARCHIVE_GAME0_BIN_PATH='app'
ARCHIVE_GAME0_BIN_FILES='
*.dll
*.ini
*.exe'

ARCHIVE_GAME1_BIN_PATH='app/__support/dx7'
ARCHIVE_GAME1_BIN_FILES='gg_dx7r.dll'

ARCHIVE_GAME_DATA_PATH='app'
ARCHIVE_GAME_DATA_FILES='
bin
music
stream
*stream
giants.ico
language_setup.png'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='giants.exe'
APP_MAIN_ICON='giants.ico'

APP_L10N_ID="${GAME_ID}_language"
APP_L10N_NAME="$GAME_NAME - Language setup"
APP_L10N_TYPE='wine'
APP_L10N_EXE='language_setup.exe'
APP_L10N_ICON='giants.ico'
APP_L10N_CAT='Settings'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine"

# Use persistent storage for user data

CONFIG_FILES='./*.ini'
DATA_DIRS='./savegame'

# Load common functions

target_version='2.14'

if [ -z "$PLAYIT_LIB2" ]; then
	for path in \
		"$PWD" \
		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
		'/usr/local/share/games/play.it' \
		'/usr/local/share/play.it' \
		'/usr/share/games/play.it' \
		'/usr/share/play.it'
	do
		if [ -e "${path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=play.it-2/lib/libplayit2.sh
. "$PLAYIT_LIB2"

# Set required registry keys on first launch

PKG='PKG_BIN'
registry_file="$(package_get_path "$PKG")${PATH_GAME}/${APP_REGEDIT:=registry/init.reg}"
mkdir --parents "$(dirname "$registry_file")"
cat > "$registry_file" << 'EOF'
REGEDIT4

[HKEY_CURRENT_USER\Software\PlanetMoon\Giants]
"1.00.000"=""
"DefPlayer"="Player"
EOF
cat >> "$registry_file" << EOF
"DestDir"="C:\\\\${GAME_ID}"
EOF
cat >> "$registry_file" << 'EOF'
"Language"="9"
"SrcDir"="C:\\"

[HKEY_CURRENT_USER\Software\PlanetMoon\Giants\IDs\Player]
"GameOptions"=dword:00000bf3
"VideoDepth"=dword:00000020
"VideoDevGuid"=hex:e0,3d,e6,84,aa,46,cf,11,81,6f,00,00,c0,20,15,6e
"VideoDrvGuid"=hex:3e,1e,b7,d7,d5,41,cf,11,f3,73,25,a2,0e,c2,cd,35
EOF

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Delete temporary files

rm --recursive "$PLAYIT_WORKDIR/gamedata"

# Get game icons

PKG='PKG_DATA'
icons_get_from_package 'APP_MAIN' 'APP_L10N'

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN' 'APP_L10N'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
