#!/bin/sh
set -o errexit

###
# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
# Copyright (c)      2021, Daguhh
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Hotline Miami 1
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20210815.5

# Set game-specific variables

GAME_ID='hotline-miami-1'
GAME_NAME='Hotline Miami 1'

ARCHIVE_BASE_HUMBLE_0='HotlineMiami_linux_1392944501.tar.gz'
ARCHIVE_BASE_HUMBLE_0_MD5='f68e5680f7f54f12b313cb533af53548'
ARCHIVE_BASE_HUMBLE_0_VERSION='1.0-humble.2014-02-20'
ARCHIVE_BASE_HUMBLE_0_SIZE='590000'
ARCHIVE_BASE_HUMBLE_0_URL='https://www.humblebundle.com/store/hotline-miami'

ARCHIVE_BASE_GOG_0='gog_hotline_miami_2.0.0.4.sh'
ARCHIVE_BASE_GOG_0_MD5='ce95f10b1cba248b531228936c491eb4'
ARCHIVE_BASE_GOG_0_TYPE='mojosetup'
ARCHIVE_BASE_GOG_0_VERSION='1.0-gog2.0.0.4'
ARCHIVE_BASE_GOG_0_SIZE='540000'
ARCHIVE_BASE_GOG_0_URL='https://www.gog.com/game/hotline_miami'

ARCHIVE_GAME_BIN_PATH_HUMBLE='.'
ARCHIVE_GAME_BIN_PATH_GOG='data/noarch/game'
ARCHIVE_GAME_BIN_FILES='hotline_launcher Hotline'

ARCHIVE_GAME_DATA_PATH_HUMBLE='.'
ARCHIVE_GAME_DATA_PATH_GOG='data/noarch/game'
ARCHIVE_GAME_DATA_FILES='*.ogg *.wad'

APP_MAIN_TYPE='native'
APP_MAIN_EXE='hotline_launcher'
# Only the GOG.com archive comes with an icon
APP_MAIN_ICON_GOG='data/noarch/support/icon.png'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID glibc libstdc++ glx libxrandr freetype libopenal.so.1 libvorbisfile.so.3 libX11.so.6 libGLU.so.1"
PKG_BIN_DEPS_ARCH='lib32-libvorbis lib32-libogg lib32-libx11 lib32-libxi lib32-libxcb lib32-libxext lib32-libxrender lib32-fontconfig'
PKG_BIN_DEPS_DEB='libvorbis0a, libogg0, libx11-xcb1, libxi6, libxcb1, libxext6, libxrender1, libfontconfig1'
PKG_BIN_DEPS_GENTOO='media-libs/libvorbis[abi_x86_32] media-libs/libogg[abi_x86_32] x11-libs/libX11[abi_x86_32] x11-libs/libXi[abi_x86_32] x11-libs/libxcb[abi_x86_32] x11-libs/libXext[abi_x86_32] x11-libs/libXrender[abi_x86_32] media-libs/fontconfig[abi_x86_32]'

# The game binary is linked against nVIDIA Cg non-free libraries.
# If a free alternative exists we should try to use that instead.

PKG_BIN_DEPS_ARCH="$PKG_BIN_DEPS_ARCH lib32-nvidia-cg-toolkit"
PKG_BIN_DEPS_DEB="$PKG_BIN_DEPS_DEB, libcggl, libcg"
PKG_BIN_DEPS_GENTOO="$PKG_BIN_DEPS_GENTOO media-gfx/nvidia-cg-toolkit[abi_x86_32]"

# Load common functions

target_version='2.13'

if [ -z "$PLAYIT_LIB2" ]; then
	for path in \
		"$PWD" \
		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
		'/usr/local/share/games/play.it' \
		'/usr/local/share/play.it' \
		'/usr/share/games/play.it' \
		'/usr/share/play.it'
	do
		if [ -e "${path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=play.it-2/lib/libplayit2.sh
. "$PLAYIT_LIB2"
 
# Extract game data
 
extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout
 
# Set execution permissions on all binaries

PKG='PKG_BIN'
chmod 755 "$(package_get_path "$PKG")${PATH_GAME}/Hotline"

# Extract icons
 
PKG='PKG_DATA'
use_archive_specific_value 'APP_MAIN_ICON'
if [ -n "$APP_MAIN_ICON" ]; then
	icons_get_from_workdir 'APP_MAIN'
fi

# Clean up temporary directories

rm --recursive "$PLAYIT_WORKDIR/gamedata"

# Write launchers
 
PKG='PKG_BIN'
launchers_write 'APP_MAIN'
 
# Build package
 
write_metadata
build_pkg
 
# Clean up
 
rm --recursive "$PLAYIT_WORKDIR"
 
# Print instructions
 
print_instructions
 
exit 0
