#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# I Have No Mouth And I Must Scream
# send your bug reports to contact@dotslashplay.it
###

script_version=20230119.1

GAME_ID='i-have-no-mouth-and-i-must-scream'
GAME_NAME='I Have No Mouth And I Must Scream'

ARCHIVE_BASE_EN_0='i_have_no_mouth_and_i_must_scream_en_1_0_17913.sh'
ARCHIVE_BASE_EN_0_MD5='93640c6a4dc73f4ed2d40b210b95ba4c'
ARCHIVE_BASE_EN_0_TYPE='mojosetup'
ARCHIVE_BASE_EN_0_SIZE='750000'
ARCHIVE_BASE_EN_0_VERSION='1.0-gog17913'
ARCHIVE_BASE_EN_0_URL='https://www.gog.com/game/i_have_no_mouth_and_i_must_scream'

ARCHIVE_BASE_FR_0='i_have_no_mouth_and_i_must_scream_fr_1_0_17913.sh'
ARCHIVE_BASE_FR_0_MD5='9124d7ccef36d4bb01dfae4d97cfbdea'
ARCHIVE_BASE_FR_0_TYPE='mojosetup'
ARCHIVE_BASE_FR_0_SIZE='570000'
ARCHIVE_BASE_FR_0_VERSION='1.0-gog17913'
ARCHIVE_BASE_FR_0_URL='https://www.gog.com/game/i_have_no_mouth_and_i_must_scream'

ARCHIVE_BASE_OLDTEMPLATE_EN_0='gog_i_have_no_mouth_and_i_must_scream_2.0.0.4.sh'
ARCHIVE_BASE_OLDTEMPLATE_EN_0_MD5='be690cfa08a87b350c26cbfdde5de401'
ARCHIVE_BASE_OLDTEMPLATE_EN_0_SIZE='780000'
ARCHIVE_BASE_OLDTEMPLATE_EN_0_VERSION='1.0-gog2.0.0.4'

ARCHIVE_BASE_OLDTEMPLATE_FR_0='gog_i_have_no_mouth_and_i_must_scream_french_2.0.0.4.sh'
ARCHIVE_BASE_OLDTEMPLATE_FR_0_MD5='e59029d2736ffa2859d73d56899055ee'
ARCHIVE_BASE_OLDTEMPLATE_FR_0_SIZE='500000'
ARCHIVE_BASE_OLDTEMPLATE_FR_0_VERSION='1.0-gog2.0.0.4'

CONTENT_PATH_DEFAULT='data/noarch/data'
CONTENT_GAME_MAIN_FILES='
*.res
*.re_'
CONTENT_DOC_MAIN_PATH='data/noarch/docs'
CONTENT_DOC_MAIN_FILES='
*.pdf
*.txt'
CONTENT_DOC0_MAIN_PATH='data/noarch/data/scream'
CONTENT_DOC0_MAIN_FILES='
readme.txt'

APP_MAIN_TYPE='scummvm'
APP_MAIN_SCUMMID='saga:ihnm'
APP_MAIN_ICON='../support/icon.png'

PKG_MAIN_ID="$GAME_ID"
PKG_MAIN_ID_EN="${GAME_ID}-en"
PKG_MAIN_ID_FR="${GAME_ID}-fr"
PKG_MAIN_ID_OLDTEMPLATE_EN="${GAME_ID}-en"
PKG_MAIN_ID_OLDTEMPLATE_FR="${GAME_ID}-fr"
PKG_MAIN_PROVIDE="$PKG_MAIN_ID"
PKG_MAIN_DEPS='scummvm'

# Older gog.com archives require to get files from an inner archive

SCRIPT_DEPS_OLDTEMPLATE='unar'

# Load common functions

target_version='2.20'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Older gog.com archives require to get files from an inner archive

case "$ARCHIVE" in
	('ARCHIVE_BASE_OLDTEMPLATE_'*)
		SCRIPT_DEPS="$SCRIPT_DEPS $SCRIPT_DEPS_OLDTEMPLATE"
		check_deps
	;;
esac

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'
(
	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"

	# Older gog.com archives require to get files from an inner archive
	case "$ARCHIVE" in
		('ARCHIVE_BASE_OLDTEMPLATE_'*)
			ARCHIVE_INNER='NoMouth.dat'
			ARCHIVE_INNER_TYPE='rar'
			archive_extraction 'ARCHIVE_INNER'
			rm "$ARCHIVE_INNER"
		;;
	esac

	# Convert all file names to lower case
	tolower .
)
## Older gog.com archives require to get files from an inner archive
CONTENT_PATH_DEFAULT_OLDTEMPLATE='.'

# Include game icons

icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

launchers_write

# Build packages

write_metadata
build_pkg

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
