#!/bin/sh
set -o errexit

###
# Copyright (c) 2015-2022, Antoine Le Gonidec <vv221@dotslashplay.it>
# Copyright (c) 2016-2022, Mopi
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# If Not Us
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220102.1

# Set game-specific variables

GAME_ID='if-not-us'
GAME_NAME='If Not Us'

ARCHIVE_BASE_32BIT_0='if not us - Linux32.zip'
ARCHIVE_BASE_32BIT_0_MD5='e18811fde9e2a096cca93ac990764255'
ARCHIVE_BASE_32BIT_0_SIZE='240000'
ARCHIVE_BASE_32BIT_0_VERSION='1.0-itch'
ARCHIVE_BASE_32BIT_0_URL='https://ub4q.itch.io/ifnotus'

ARCHIVE_BASE_64BIT_0='if not us - Linux64.zip'
ARCHIVE_BASE_64BIT_0_MD5='216690ba3a752f8a5548e38b933f7bc4'
ARCHIVE_BASE_64BIT_0_SIZE='240000'
ARCHIVE_BASE_64BIT_0_VERSION='1.0-itch'
ARCHIVE_BASE_64BIT_0_URL='https://ub4q.itch.io/ifnotus'

CONTENT_PATH_DEFAULT='.'
ARCHIVE_DOC_DATA_FILES='credits.html'
ARCHIVE_GAME_BIN_FILES='
chromedriver
if?not?us
lib
minidump_stackwalk
nacl_helper
nacl_helper_bootstrap
nacl_irt_x86_64.nexe
nwjc
payload
pnacl
snapshot_blob.bin'
ARCHIVE_GAME_DATA_FILES='
Gallery
locales
icudtl.dat
natives_blob.bin
nw_100_percent.pak
nw_200_percent.pak
nw_material_100_percent.pak
nw_material_200_percent.pak
resources.pak'

APP_MAIN_TYPE='native'
APP_MAIN_LIBS='lib'
APP_MAIN_EXE='if not us'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH_32BIT='32'
PKG_BIN_ARCH_64BIT='64'
PKG_BIN_DEPS="$PKG_DATA_ID libc.so.6 libstdc++.so.6 libgobject-2.0.so.0 libglib-2.0.so.0 libX11.so.6 libasound.so.2 libgtk-x11-2.0.so.0 libgdk-x11-2.0.so.0 libgdk_pixbuf-2.0.so.0 nss freetype libxrandr xcursor"
PKG_BIN_DEPS_ARCH_32BIT='lib32-gconf lib32-glib2 lib32-nspr lib32-fontconfig lib32-expat lib32-pango lib32-cairo lib32-libxi lib32-libxext lib32-libxfixes lib32-libxrender lib32-libxss lib32-libxcomposite lib32-libxdamage lib32-libxtst lib32-dbus lib32-atk lib32-libcups'
PKG_BIN_DEPS_ARCH_64BIT='gconf glib2 nspr fontconfig expat pango cairo libxi libxext libxfixes libxrender libxss libxcomposite libxdamage libxtst dbus atk libcups'
PKG_BIN_DEPS_DEB='libgconf-2-4, libglib2.0-0, libnspr4, libfontconfig1, libexpat1, libpangocairo-1.0-0, libpango-1.0-0, libcairo2, libxi6, libxext6, libxfixes3, libxrender1, libxss1, libxcomposite1, libxdamage1, libxtst6, libdbus-1-3, libatk1.0-0, libcups2'
PKG_BIN_DEPS_GENTOO_32BIT='gnome-base/gconf[abi_x86_32] dev-libs/glib[abi_x86_32] dev-libs/nspr[abi_x86_32] media-libs/fontconfig[abi_x86_32] dev-libs/expat[abi_x86_32] x11-libs/pango[abi_x86_32] x11-libs/cairo[abi_x86_32] x11-libs/libXi[abi_x86_32] x11-libs/libXext[abi_x86_32] x11-libs/libXfixes[abi_x86_32] x11-libs/libXrender[abi_x86_32] x11-libs/libXScrnSaver[abi_x86_32] x11-libs/libXcomposite[abi_x86_32] x11-libs/libXdamage[abi_x86_32] x11-libs/libXtst[abi_x86_32] sys-apps/dbus[abi_x86_32] dev-libs/atk[abi_x86_32] net-print/cups[abi_x86_32]'
PKG_BIN_DEPS_GENTOO_64BIT='gnome-base/gconf dev-libs/glib dev-libs/nspr media-libs/fontconfig dev-libs/expat x11-libs/pango x11-libs/cairo x11-libs/libXi x11-libs/libXext x11-libs/libXfixes x11-libs/libXrender x11-libs/libXScrnSaver x11-libs/libXcomposite x11-libs/libXdamage x11-libs/libXtst sys-apps/dbus dev-libs/atk net-print/cups'

# Load common functions

target_version='2.15'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
set_standard_permissions "$PLAYIT_WORKDIR/gamedata"
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
