#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2020 macaron
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Indiana Jones and the Last Crusade
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220807.1

GAME_ID='indiana-jones-and-the-last-crusade'
GAME_NAME='Indiana Jones and the Last Crusade'

ARCHIVE_BASE_0='indiana_jones_and_the_last_crusade_en_gog_2_20145.sh'
ARCHIVE_BASE_0_MD5='b00d2c5498376718caad19db54265b29'
ARCHIVE_BASE_0_TYPE='mojosetup'
ARCHIVE_BASE_0_SIZE='90000'
ARCHIVE_BASE_0_VERSION='1.0-gog20145'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/indiana_jones_and_the_last_crusade'

# Reference card and Grail Diary are missing from main archive
ARCHIVE_OPTIONAL_DOC0='indiana_jones_last_crucade_reference_card.zip'
ARCHIVE_OPTIONAL_DOC0_MD5='e6d8dc70f1dc06f0e58fb1636970b8c0'
ARCHIVE_OPTIONAL_DOC0_URL='https://www.gog.com/downloads/indiana_jones_and_the_last_crusade/73603'
ARCHIVE_OPTIONAL_DOC1='indiana_jones_last_crusade_grail_diary.zip'
ARCHIVE_OPTIONAL_DOC1_MD5='13eb5e708eb947107ee5d01930507df4'
ARCHIVE_OPTIONAL_DOC1_URL='https://www.gog.com/downloads/indiana_jones_and_the_last_crusade/73613'

# Fix typos in file names
ARCHIVE_OPTIONAL_DOC0_RENAME_FROM='Indiana Jones The Last Cusade - Reference Card.pdf'
ARCHIVE_OPTIONAL_DOC0_RENAME_TO='indiana jones and the last crusade - reference card.pdf'
ARCHIVE_OPTIONAL_DOC1_RENAME_FROM='Indiana Jones The Last Crusae - Grail Diary.pdf'
ARCHIVE_OPTIONAL_DOC1_RENAME_TO='indiana jones and the last crusade - grail diary.pdf'

CONTENT_PATH_DEFAULT='data/noarch/data'
ARCHIVE_GAME_MAIN_FILES='
*.lfl'
ARCHIVE_DOC_MAIN_PATH="${CONTENT_PATH_DEFAULT}/../docs"
ARCHIVE_DOC_MAIN_FILES='
*.txt'
ARCHIVE_DOC0_MAIN_PATH='indiana_jones_last_crucade_reference_card'
ARCHIVE_DOC0_MAIN_FILES='
*.pdf'
ARCHIVE_DOC1_MAIN_PATH='indiana_jones_last_crusade_grail_diary'
ARCHIVE_DOC1_MAIN_FILES='
*.pdf'

APP_MAIN_TYPE='scummvm'
APP_MAIN_SCUMMID='scumm:indy3'
APP_MAIN_ICON='../support/icon.png'

PKG_MAIN_DEPS='scummvm'

# Load common functions

target_version='2.17'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Check for the presence of optional documentation archives

archive_initialize_optional \
	'ARCHIVE_DOC0' \
	'ARCHIVE_OPTIONAL_DOC0'
archive_initialize_optional \
	'ARCHIVE_DOC1' \
	'ARCHIVE_OPTIONAL_DOC1'

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

(
	content_path=$(content_path_default)
	cd "${PLAYIT_WORKDIR}/gamedata/${content_path}"

	tolower .
)

if [ -n "$ARCHIVE_DOC0" ]; then
	archive_extraction 'ARCHIVE_DOC0'

	(
		content_path="$ARCHIVE_DOC0_MAIN_PATH"
		cd "${PLAYIT_WORKDIR}/gamedata/${content_path}"

		mv \
			"$ARCHIVE_OPTIONAL_DOC0_RENAME_FROM" \
			"$ARCHIVE_OPTIONAL_DOC0_RENAME_TO"
	)
fi

if [ -n "$ARCHIVE_DOC1" ]; then
	archive_extraction 'ARCHIVE_DOC1'

	(
		content_path="$ARCHIVE_DOC1_MAIN_PATH"
		cd "${PLAYIT_WORKDIR}/gamedata/${content_path}"

		mv \
			"$ARCHIVE_OPTIONAL_DOC1_RENAME_FROM" \
			"$ARCHIVE_OPTIONAL_DOC1_RENAME_TO"
	)
fi

# Include game icons

icons_inclusion

# Include game data

prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

launchers_write

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
