#!/bin/sh
set -o errexit

###
# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
# Copyright (c) 2020-2021, HS-157
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Just Cause 2
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20211031.8

# Set game-specific variables

GAME_ID='just-cause-2'
GAME_NAME='Just Cause 2'

ARCHIVE_BASE_0='setup_just_cause_2_-_complete_edition_1.0.0.2_(50335).exe'
ARCHIVE_BASE_0_MD5='32cc043750be9e09354a3605f05f7de4'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1='setup_just_cause_2_-_complete_edition_1.0.0.2_(50335)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='4f100ae3a4ba93b72de4247aa7a61f29'
ARCHIVE_BASE_0_PART1_TYPE='innosetup'
ARCHIVE_BASE_0_PART2='setup_just_cause_2_-_complete_edition_1.0.0.2_(50335)-2.bin'
ARCHIVE_BASE_0_PART2_MD5='338797d683e65f69c834731f41855a12'
ARCHIVE_BASE_0_PART2_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='9100000'
ARCHIVE_BASE_0_VERSION='1.0.0.2-gog'

ARCHIVE_DOC_L10N_EN_PATH='.'
ARCHIVE_DOC_L10N_EN_FILES='
jc2?readme_en.rtf'

ARCHIVE_DOC_L10N_FR_PATH='.'
ARCHIVE_DOC_L10N_FR_FILES='
jc2?readme_fr.rtf'

ARCHIVE_GAME_BIN_PATH='.'
ARCHIVE_GAME_BIN_FILES='
*.dll
*.exe'

ARCHIVE_GAME_L10N_EN_PATH='.'
ARCHIVE_GAME_L10N_EN_FILES='
sound/fmod/dialog_mission?specific_eng.fsb
sound/fmod/dialog_pa_eng.fsb'

ARCHIVE_GAME_L10N_FR_PATH='.'
ARCHIVE_GAME_L10N_FR_FILES='
sound/fmod/dialog_mission?specific_fre.fsb
sound/fmod/dialog_pa_fre.fsb'

ARCHIVE_GAME_DATA_PATH='.'
ARCHIVE_GAME_DATA_FILES='
archives_win32
dlc
dx10_shaders_f.shader_bundle
dx10_specialshaders_f.shader_bundle
sound/fmod/cutscenes_common.fsb
sound/fmod/music_common.fsb
sound/fmod/music_stereo.fsb'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='justcause2.exe'
APP_MAIN_ICON='justcause2.exe'

PACKAGES_LIST='PKG_BIN PKG_L10N_EN PKG_L10N_FR PKG_DATA'

PKG_L10N_ID="${GAME_ID}-l10n"

PKG_L10N_EN_ID="${PKG_L10N_ID}-en"
PKG_L10N_EN_PROVIDE="$PKG_L10N_ID"
PKG_L10N_EN_DESCRIPTION='English localization'

PKG_L10N_FR_ID="${PKG_L10N_ID}-fr"
PKG_L10N_FR_PROVIDE="$PKG_L10N_ID"
PKG_L10N_FR_DESCRIPTION='French localization'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID $PKG_L10N_ID wine"

# Use persistent storage for user data

APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
userconfig:users/$(id -un)/My Documents/Square Enix/Just Cause 2
userdata:users/$(id -un)/Documents/My Games/Just Cause 2'
DATA_DIRS="$DATA_DIRS ./userdata"
CONFIG_DIRS="$CONFIG_DIRS ./userconfig"

# Work around a failure to start the game

APP_WINETRICKS="$APP_WINETRICKS d3dcompiler_47"
PKG_BIN_DEPS="$PKG_BIN_DEPS winetricks"

# Switch French keyboard layout to us-azerty to provide direct access to digits

PKG_BIN_DEPS_ARCH='xorg-setxkbmap'
PKG_BIN_DEPS_DEB='x11-xkb-utils'
PKG_BIN_DEPS_GENTOO='x11-apps/setxkbmap'

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'

# Switch French keyboard layout to us-azerty to provide direct access to digits
KEYBOARD_LAYOUT=$(LANG=C setxkbmap -query | awk "/layout:/ {print \$2}")
RESTORE_VARIANT=0
if [ "$KEYBOARD_LAYOUT" = "fr" ]; then
	KEYBOARD_VARIANT=$(LANG=C setxkbmap -query | awk "/variant:/ {print \$2}")
	if [ "$KEYBOARD_VARIANT" != "us-azerty" ]; then
		setxkbmap -variant us-azerty
		RESTORE_VARIANT=1
	fi
fi'
APP_MAIN_POSTRUN="$APP_MAIN_POSTRUN"'

# Restore the keyboard variant
if [ $RESTORE_VARIANT -eq 1 ]; then
	setxkbmap -variant "$KEYBOARD_VARIANT"
fi'

# Load common functions

target_version='2.14'

if [ -z "$PLAYIT_LIB2" ]; then
	for path in \
		"$PWD" \
		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
		'/usr/local/share/games/play.it' \
		'/usr/local/share/play.it' \
		'/usr/share/games/play.it' \
		'/usr/share/play.it'
	do
		if [ -e "${path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=play.it-2/lib/libplayit2.sh
. "$PLAYIT_LIB2"

# Set game language

PKG='PKG_L10N_EN'
path_game="$(package_get_path "$PKG")${PATH_GAME}"
l10n_conf_file="$path_game/goggame-1833855510.info"
mkdir --parents "$path_game"
cat > "$l10n_conf_file" << EOF
{
    "clientId": "54243798143089551",
    "gameId": "1833855510",
    "language": "English",
    "languages": [
        "en-US"
    ],
    "name": "Just Cause 2 - Complete Edition",
    "playTasks": [
        {
            "category": "game",
            "isPrimary": true,
            "languages": [
                "en-US",
                "ru-RU",
                "es-ES",
                "it-IT",
                "de-DE",
                "fr-FR",
                "pl-PL"
            ],
            "name": "Just Cause 2 - Complete Edition",
            "path": "JustCause2.exe",
            "type": "FileTask"
        }
    ],
    "rootGameId": "1833855510",
    "version": 1
}
EOF

PKG='PKG_L10N_FR'
path_game="$(package_get_path "$PKG")${PATH_GAME}"
l10n_conf_file="$path_game/goggame-1833855510.info"
mkdir --parents "$path_game"
cat > "$l10n_conf_file" << EOF
{
    "clientId": "54243798143089551",
    "gameId": "1833855510",
    "language": "French",
    "languages": [
        "fr-FR"
    ],
    "name": "Just Cause 2 - Complete Edition",
    "playTasks": [
        {
            "category": "game",
            "isPrimary": true,
            "languages": [
                "en-US",
                "ru-RU",
                "es-ES",
                "it-IT",
                "de-DE",
                "fr-FR",
                "pl-PL"
            ],
            "name": "Just Cause 2 - Complete Edition",
            "path": "JustCause2.exe",
            "type": "FileTask"
        }
    ],
    "rootGameId": "1833855510",
    "version": 1
}
EOF

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Delete temoprary files

rm --recursive "$PLAYIT_WORKDIR/gamedata"

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

case "${LANG%_*}" in
	('fr')
		lang_string='version %s :'
		lang_en='anglaise'
		lang_fr='française'
	;;
	('en'|*)
		lang_string='%s version:'
		lang_en='English'
		lang_fr='French'
	;;
esac
printf '\n'
printf "$lang_string" "$lang_en"
print_instructions 'PKG_L10N_EN' 'PKG_DATA' 'PKG_BIN'
printf "$lang_string" "$lang_fr"
print_instructions 'PKG_L10N_FR' 'PKG_DATA' 'PKG_BIN'

exit 0
