#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2018 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Keep Talking and Nobody Explodes
# send your bug reports to contact@dotslashplay.it
###

script_version=20230103.2

GAME_ID='keep-talking-and-nobody-explodes'
GAME_NAME='Keep Talking and Nobody Explodes'

UNITY3D_NAME='ktane'

ARCHIVE_BASE_2='Keep_Talking_and_Nobody_Explodes_1.9.24_-_StandaloneLinuxUniversal_Default.zip'
ARCHIVE_BASE_2_MD5='d54abf305fbb28f21ff8fc670cdbd284'
ARCHIVE_BASE_2_SIZE='720000'
ARCHIVE_BASE_2_VERSION='1.9.24-humble.2020.11.17'
ARCHIVE_BASE_2_URL='https://www.humblebundle.com/store/keep-talking-and-nobody-explodes'

ARCHIVE_BASE_1='Keep_Talking_and_Nobody_Explodes_1.8.3_-_StandaloneLinuxUniversal_Default.zip'
ARCHIVE_BASE_1_MD5='212e7d380c7214f87b05aa405fa41662'
ARCHIVE_BASE_1_SIZE='860000'
ARCHIVE_BASE_1_VERSION='1.8.3-humble.2019.03.07'

ARCHIVE_BASE_0='Keep_Talking_and_Nobody_Explodes_1.6.1_-_Linux.zip'
ARCHIVE_BASE_0_MD5='ac321144f9ed9dc6797d35a33bd0b0e7'
ARCHIVE_BASE_0_SIZE='940000'
ARCHIVE_BASE_0_VERSION='1.6.1-humble.2017.12.19'

ARCHIVE_OPTIONAL_MANUAL='Bomb-Defusal-Manual_1.pdf'
ARCHIVE_OPTIONAL_MANUAL_MD5='fde93a9ad8de6ab04bdff40359145e11'
ARCHIVE_OPTIONAL_MANUAL_TYPE='misc'
ARCHIVE_OPTIONAL_MANUAL_URL='http://www.bombmanual.com/manual/1/pdf/Bomb-Defusal-Manual_1.pdf'

CONTENT_PATH_DEFAULT='Keep Talking and Nobody Explodes'
CONTENT_GAME_BIN32_FILES="
${UNITY3D_NAME}.x86
${UNITY3D_NAME}_Data/Mono/x86
${UNITY3D_NAME}_Data/Plugins/x86"
CONTENT_GAME_BIN64_FILES="
${UNITY3D_NAME}.x86_64
${UNITY3D_NAME}_Data/Mono/x86_64
${UNITY3D_NAME}_Data/Plugins/x86_64"
CONTENT_GAME_DATA_FILES="
${UNITY3D_NAME}_Data"
CONTENT_DOC_DATA_PATH='Keep Talking and Nobody Explodes/Manuals'
CONTENT_DOC_DATA_FILES='
*.pdf'

PACKAGES_LIST='PKG_BIN32 PKG_BIN64 PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN32_ARCH='32'
PKG_BIN32_DEPS="$PKG_DATA_ID"
PKG_BIN32_DEPENDENCIES_LIBRARIES='
ld-linux-x86-64.so.2
libc.so.6
libdl.so.2
libgcc_s.so.1
libgdk_pixbuf-2.0.so.0
libglib-2.0.so.0
libgobject-2.0.so.0
libgtk-x11-2.0.so.0
libm.so.6
libpthread.so.0
librt.so.1
libstdc++.so.6
libz.so.1'

PKG_BIN64_ARCH='64'
PKG_BIN64_DEPS="$PKG_BIN32_DEPS"
PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN32_DEPENDENCIES_LIBRARIES"

# Load common functions

target_version='2.20'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Include game manual if it has been provided

archive_initialize_optional \
	'ARCHIVE_MANUAL' \
	'ARCHIVE_OPTIONAL_MANUAL'
if [ -n "$ARCHIVE_MANUAL" ]; then
	package_path=$(package_path 'PKG_DATA')
	path_documentation=$(path_documentation)
	path_destination="${package_path}${path_documentation}"
	mkdir --parents "$path_destination"
	cp "$ARCHIVE_MANUAL" "$path_destination"
fi

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

for PKG in 'PKG_BIN32' 'PKG_BIN64'; do
	launchers_write
done

# Build packages

write_metadata
build_pkg

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
