#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Mopi
# SPDX-FileCopyrightText: © 2018 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Knights of Pen and Paper
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220628.1

# Set game-specific variables

GAME_ID='knights-of-pen-and-paper'
GAME_NAME='Knights of Pen and Paper'

# Archives

## Kinghts of Pen and Paper (base game)

ARCHIVE_BASE_0='gog_knights_of_pen_and_paper_1_edition_2.0.0.1.sh'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/knights_of_pen_and_paper_1_deluxier_edition'
ARCHIVE_BASE_0_MD5='1f387b78bfe426b9396715fbfe3499b9'
ARCHIVE_BASE_0_VERSION='2.34c-gog2.0.0.1'
ARCHIVE_BASE_0_SIZE='120000'

## Deluxier Edition

ARCHIVE_OPTIONAL_DELUXIER_0='gog_knights_of_pen_and_paper_1_deluxier_edition_upgrade_2.0.0.1.sh'
ARCHIVE_OPTIONAL_DELUXIER_0_MD5='b3033693afd93cc885883aede7ede4b0'
ARCHIVE_OPTIONAL_DELUXIER_0_TYPE='mojosetup'


UNITY3D_NAME='knightspp'

CONTENT_PATH_DEFAULT='data/noarch/game'
ARCHIVE_GAME_BIN_FILES="
${UNITY3D_NAME}.x86
${UNITY3D_NAME}_Data/Mono
${UNITY3D_NAME}_Data/Plugins"
ARCHIVE_GAME_DATA_FILES="
${UNITY3D_NAME}_Data"

APP_MAIN_TYPE='native'
APP_MAIN_EXE="${UNITY3D_NAME}.x86"
APP_MAIN_ICON="${UNITY3D_NAME}_Data/Resources/UnityPlayer.png"

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID libc.so.6 libstdc++.so.6 libGLU.so.1 xcursor libxrandr"

# Use a dedicated log file for the current game session

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
# Use a dedicated log file for the current game session
mkdir --parents logs
APP_OPTIONS="${APP_OPTIONS} -logFile ./logs/$(date +%F-%R).log"'

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Load Deluxier Edition archive if it is available

archive_initialize_optional \
	'ARCHIVE_DELUXIER' \
	'ARCHIVE_OPTIONAL_DELUXIER_0'

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
if [ -n "$ARCHIVE_DELUXIER" ]; then
	(
		ARCHIVE='ARCHIVE_DELUXIER'
		extract_data_from "$ARCHIVE_DELUXIER"
	)
fi
prepare_package_layout

# Include game icon

PKG='PKG_DATA'
icons_get_from_package 'APP_MAIN'

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
