#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2018 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Kyn
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220805.1

GAME_ID='kyn'
GAME_NAME='Kyn'

# This DRM-free installer is no longer available for sale from gog.com
ARCHIVE_BASE_0='setup_kyn_update_4_(17655).exe'
ARCHIVE_BASE_0_MD5='ca2a665c27ef02f0bfa4e72dc368952c'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1='setup_kyn_update_4_(17655)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='8c6c13b15a4d39ac9389c7c4f9ce6760'
ARCHIVE_BASE_0_PART1_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='7900000'
ARCHIVE_BASE_0_VERSION='1.0.4-gog17655'

ARCHIVE_BASE_RAR_0='setup_kyn_2.1.0.4.exe'
ARCHIVE_BASE_RAR_0_MD5='a40cb85cdd40b7464eec92b2b9166f84'
ARCHIVE_BASE_RAR_0_TYPE='rar' # This is actually a InnoSetup installer based on a RAR archive
ARCHIVE_BASE_RAR_0_PART1='setup_kyn_2.1.0.4-1.bin'
ARCHIVE_BASE_RAR_0_PART1_MD5='4cfdca351969f2570a3657c772fd492e'
ARCHIVE_BASE_RAR_0_PART1_TYPE='rar'
ARCHIVE_BASE_RAR_0_SIZE='7900000'
ARCHIVE_BASE_RAR_0_VERSION='1.0-gog2.1.0.4'

UNITY3D_NAME='kyn'

CONTENT_PATH_DEFAULT='app'
CONTENT_PATH_DEFAULT_RAR='game'
ARCHIVE_GAME_BIN_FILES="
${UNITY3D_NAME}.exe
${UNITY3D_NAME}_data/mono
${UNITY3D_NAME}_data/plugins"
ARCHIVE_GAME_DATA_FILES="
${UNITY3D_NAME}_data"

APP_MAIN_TYPE='wine'
APP_MAIN_EXE="${UNITY3D_NAME}.exe"
APP_MAIN_ICON="${UNITY3D_NAME}.exe"

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine"

# Use a dedicated log file for the current game session

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
# Use a dedicated log file for the current game session
mkdir --parents logs
APP_OPTIONS="${APP_OPTIONS} -logFile ./logs/$(date +%F-%R).log"'

# Use persistent storage for user data

APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
saves:users/${USER}/AppData/LocalLow/Tangrin Entertainment/Kyn/Saves'
DATA_DIRS="$DATA_DIRS saves"

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

case "$ARCHIVE" in
	('ARCHIVE_BASE_RAR_'*)
		archive_extraction 'SOURCE_ARCHIVE_PART1'
		content_path=$(content_path_default)
		tolower "${PLAYIT_WORKDIR}/gamedata/${content_path}"
	;;
	(*)
		archive_extraction 'SOURCE_ARCHIVE'
	;;
esac
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
