#!/bin/sh
set -o errexit

###
# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
# Copyright (c)      2021, Anna Lea
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Leisure Suit Larry 1
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20210815.3

# Set game-specific variables

GAME_ID='leisure-suit-larry-1'
GAME_NAME='Leisure Suit Larry 1: In the Land of the Lounge Lizards'

ARCHIVE_BASE_AGI_0='leisure_suit_larry_en_gog_2_20270.sh'
ARCHIVE_BASE_AGI_0_MD5='bfd706b6e10333f538e30df3ccc572a4'
ARCHIVE_BASE_AGI_0_TYPE='mojosetup'
ARCHIVE_BASE_AGI_0_SIZE='94000'
ARCHIVE_BASE_AGI_0_VERSION='2-gog20270'
ARCHIVE_BASE_AGI_0_URL='https://www.gog.com/game/leisure_suit_larry'

ARCHIVE_BASE_SCI_0='leisure_suit_larry_vga_en_gog_2_20240.sh'
ARCHIVE_BASE_SCI_0_MD5='40b241062ea3945e20e2d3c8fc811e0c'
ARCHIVE_BASE_SCI_0_TYPE='mojosetup'
ARCHIVE_BASE_SCI_0_SIZE='97000'
ARCHIVE_BASE_SCI_0_VERSION='2-gog20240'
ARCHIVE_BASE_SCI_0_URL='https://www.gog.com/game/leisure_suit_larry'

ARCHIVE_DOC_MAIN_PATH='data/noarch/docs'
ARCHIVE_DOC_MAIN_FILES='
*.pdf
lsl1?answers.txt
lsl1?vga?answers.txt'

ARCHIVE_GAME_MAIN_PATH='data/noarch/data'
ARCHIVE_GAME_MAIN_FILES_AGI='
vol.*
object
*dir
words.tok'
ARCHIVE_GAME_MAIN_FILES_SCI='
*.bat
*.drv
*.exe
*.hlp
*.txt
resource.*
version'

APP_MAIN_TYPE='scummvm'
APP_MAIN_SCUMMID_AGI='lsl1'
APP_MAIN_SCUMMID_SCI='lsl1sci'
APP_MAIN_ICON='data/noarch/support/icon.png'

PACKAGES_LIST='PKG_MAIN'

PKG_MAIN_ID="$GAME_ID"
PKG_MAIN_PROVIDE="$PKG_MAIN_ID"
PKG_MAIN_ID_AGI="${PKG_MAIN_ID}-agi"
PKG_MAIN_ID_SCI="${PKG_MAIN_ID}-sci"
PKG_MAIN_DEPS='scummvm'

# Load common functions

target_version='2.13'

if [ -z "$PLAYIT_LIB2" ]; then
	for path in \
		"$PWD" \
		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
		'/usr/local/share/games/play.it' \
		'/usr/local/share/play.it' \
		'/usr/share/games/play.it' \
		'/usr/share/play.it'
	do
		if [ -e "${path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=play.it-2/lib/libplayit2.sh
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
tolower "$PLAYIT_WORKDIR/gamedata"
prepare_package_layout

# Get game icon

PKG='PKG_MAIN'
icons_get_from_workdir 'APP_MAIN'

# Clean up temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

use_archive_specific_value 'APP_MAIN_SCUMMID'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "${PLAYIT_WORKDIR}"

# Print instructions

print_instructions

exit 0
