#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Mark of the Ninja - Special Edition
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220710.1

GAME_ID='mark-of-the-ninja'
GAME_NAME='Mark of the Ninja'

GAME_ID_EXPANSION="${GAME_ID}-special-edition"
GAME_NAME_EXPANSION="$GAME_NAME - Special Edition"

# This DRM-free archive is no longer sold by GOG
ARCHIVE_BASE_0='gog_mark_of_the_ninja_special_edition_dlc_2.0.0.4.sh'
ARCHIVE_BASE_0_MD5='bbce70b80932ec9c14fbedf0b6b33eb1'
ARCHIVE_BASE_0_TYPE='mojosetup'
ARCHIVE_BASE_0_SIZE='250000'
ARCHIVE_BASE_0_VERSION='1.0-gog2.0.0.4'

CONTENT_PATH_DEFAULT='data/noarch/game'
ARCHIVE_GAME_BIN32_FILES='
bin/*32*'
ARCHIVE_GAME_BIN64_FILES='
bin/*64*'
ARCHIVE_GAME_DATA_FILES='
dlc'

PACKAGES_LIST='PKG_BIN32 PKG_BIN64 PKG_DATA'

PKG_DATA_ID="${GAME_ID_EXPANSION}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN32_ID="$GAME_ID_EXPANSION"
PKG_BIN32_ARCH='32'
PKG_BIN32_DEPS="$GAME_ID $PKG_DATA_ID libc.so.6 libstdc++.so.6 libGL.so.1 libSDL2-2.0.so.0"

PKG_BIN64_ID="$GAME_ID_EXPANSION"
PKG_BIN64_ARCH='64'
PKG_BIN64_DEPS="$PKG_BIN32_DEPS"

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Rename binaries do avoid collision with base game

PKG='PKG_BIN32'
(
	package_path=$(package_get_path "$PKG")
	cd "${package_path}${PATH_GAME}/bin"
	chmod +x 'ninja-bin32'
	mv 'ninja-bin32' 'ninja-bin32.dlc'
)
PKG='PKG_BIN64'
(
	package_path=$(package_get_path "$PKG")
	cd "${package_path}${PATH_GAME}/bin"
	chmod +x 'ninja-bin64'
	mv 'ninja-bin64' 'ninja-bin64.dlc'
)
PKG_BIN32_POSTINST_RUN="$PKG_BIN32_POSTINST_RUN
# Rename binaries do avoid collision with base game
cd '$PATH_GAME/bin'
mv 'ninja-bin32' 'ninja-bin32.orig'
ln --symbolic './ninja-bin32.dlc' 'ninja-bin32'"
PKG_BIN64_POSTINST_RUN="$PKG_BIN64_POSTINST_RUN
# Rename binaries do avoid collision with base game
cd '$PATH_GAME/bin'
mv 'ninja-bin64' 'ninja-bin64.orig'
ln --symbolic './ninja-bin64.dlc' 'ninja-bin64'"
PKG_BIN32_PRERM_RUN="$PKG_BIN32_PRERM_RUN
# Rename binaries do avoid collision with base game
cd '$PATH_GAME/bin'
rm 'ninja-bin32'
mv 'ninja-bin32.orig' 'ninja-bin32'"
PKG_BIN64_PRERM_RUN="$PKG_BIN64_PRERM_RUN
# Rename binaries do avoid collision with base game
cd '$PATH_GAME/bin'
rm 'ninja-bin64'
mv 'ninja-bin64.orig' 'ninja-bin64'"

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
