#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2020 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Memoranda
# send your bug reports to contact@dotslashplay.it
###

script_version=20230817.1

GAME_ID='memoranda'
GAME_NAME='Memoranda'

ARCHIVE_BASE_0='gog_memoranda_2.2.0.3.sh'
ARCHIVE_BASE_0_MD5='9671ebb592d4b4a028fd80f76e96c1a1'
ARCHIVE_BASE_0_SIZE='800000'
ARCHIVE_BASE_0_VERSION='1.0-gog2.2.0.3'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/memoranda'

CONTENT_PATH_DEFAULT='data/noarch/game'
CONTENT_GAME_BIN_FILES='
runner'
CONTENT_GAME_DATA_FILES='
assets'

APP_MAIN_EXE='runner'
APP_MAIN_ICON='assets/icon.png'
## Work around Mesa-related startup crash
APP_MAIN_PRERUN='# Work around Mesa-related startup crash
# cf. https://gitlab.freedesktop.org/mesa/mesa/issues/1310
export radeonsi_sync_compile=true
'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libdl.so.2
libgcc_s.so.1
libGL.so.1
libGLU.so.1
libm.so.6
libopenal.so.1
libpthread.so.0
librt.so.1
libstdc++.so.6
libX11.so.6
libXext.so.6
libXrandr.so.2
libXxf86vm.so.1
libz.so.1'

# Load common functions

target_version='2.25'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Ensure availability of required OpenSSL libraries

ARCHIVE_REQUIRED_OPENSSL='libssl_1.0.0_32-bit.tar.gz'
ARCHIVE_REQUIRED_OPENSSL_MD5='9443cad4a640b2512920495eaf7582c4'
ARCHIVE_REQUIRED_OPENSSL_URL='https://downloads.dotslashplay.it/resources/libssl/'
CONTENT_OPENSSL_PATH='.'
CONTENT_OPENSSL_FILES='
libcrypto.so.1.0.0
libssl.so.1.0.0'
PKG_BIN_DEPENDENCIES_LIBRARIES="$(dependencies_list_native_libraries 'PKG_BIN')
libc.so.6
libdl.so.2"
archive_initialize_required \
	'ARCHIVE_OPENSSL' \
	'ARCHIVE_REQUIRED_OPENSSL'
archive_extraction 'ARCHIVE_OPENSSL'
content_inclusion 'OPENSSL' 'PKG_BIN' "$(path_libraries)"
rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
## Build 512×512 icon from the 1024×1024 provided one
APP_MAIN_ICONS_LIST="$(application_icons_list 'APP_MAIN') APP_MAIN_ICON_512"
APP_MAIN_ICON_512='assets/icon_512.png'
(
	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
	convert "$APP_MAIN_ICON" -resize 512 "$APP_MAIN_ICON_512"
)
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
