#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2018 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Monkey Island 3
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220701.1

GAME_ID='monkey-island-3'
GAME_NAME='Monkey Island 3: The Curse of Monkey Island'

ARCHIVES_LIST='ARCHIVE_BASE_EN_0 ARCHIVE_BASE_FR_0 ARCHIVE_BASE_0'

ARCHIVE_BASE_EN_0='setup_the_curse_of_monkey_islandtm_1.0l_(20628).exe'
ARCHIVE_BASE_EN_0_MD5='fcd4a7cd9c0304c15a0a059f6eb299e8'
ARCHIVE_BASE_EN_0_TYPE='innosetup'
ARCHIVE_BASE_EN_0_PART1='setup_the_curse_of_monkey_islandtm_1.0l_(20628)-1.bin'
ARCHIVE_BASE_EN_0_PART1_MD5='931e6e35fdc7e0a14f2559984620f8f3'
ARCHIVE_BASE_EN_0_PART1_TYPE='innosetup'
ARCHIVE_BASE_EN_0_SIZE='1200000'
ARCHIVE_BASE_EN_0_VERSION='1.0l-gog20628'
ARCHIVE_BASE_EN_0_URL='https://www.gog.com/game/the_curse_of_monkey_island'

ARCHIVE_BASE_FR_0='setup_the_curse_of_monkey_islandtm_1.0l_(french)_(20628).exe'
ARCHIVE_BASE_FR_0_MD5='a0ebaa26154de4a76d20b0ef882445cf'
ARCHIVE_BASE_FR_0_TYPE='innosetup'
ARCHIVE_BASE_FR_0_PART1='setup_the_curse_of_monkey_islandtm_1.0l_(french)_(20628)-1.bin'
ARCHIVE_BASE_FR_0_PART1_MD5='10356610b119b917dbba13df9ed207a5'
ARCHIVE_BASE_FR_0_PART1_TYPE='innosetup'
ARCHIVE_BASE_FR_0_SIZE='1200000'
ARCHIVE_BASE_FR_0_VERSION='1.0l-gog20628'
ARCHIVE_BASE_FR_0_URL='https://www.gog.com/game/the_curse_of_monkey_island'

ARCHIVE_BASE_0='setup_the_curse_of_monkey_island_1.0_(18253).exe'
ARCHIVE_BASE_0_MD5='20c74e5f60bd724182ec2bdbae6d9a49'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='1200000'
ARCHIVE_BASE_0_VERSION='1.0-gog18253'

CONTENT_PATH_DEFAULT='.'
CONTENT_PATH_DEFAULT_0='app'
ARCHIVE_DOC_L10N_FILES='
*.pdf'
ARCHIVE_GAME_L10N_FILES='
resource/bbsan.san
resource/curserng.san
resource/finale.san
resource/language.tab
resource/lavaride.san
resource/liftcrse.san
resource/moreslaw.san
resource/newboots.san
resource/opening.san
resource/sinkshp.san
resource/voxdisk1.bun
resource/voxdisk2.bun
resource/wrecksan.san'
ARCHIVE_GAME_MAIN_FILES='
comi.la?
resource'

APP_MAIN_TYPE='scummvm'
APP_MAIN_SCUMMID='comi'
APP_MAIN_ICON='app/goggame-1528148981.ico'

PACKAGES_LIST='PKG_L10N PKG_MAIN'

PKG_L10N_ID="${GAME_ID}-l10n"
PKG_L10N_ID_EN="${PKG_L10N_ID}-en"
PKG_L10N_ID_FR="${PKG_L10N_ID}-fr"
PKG_L10N_ID_0="$PKG_L10N_ID_EN"
PKG_L10N_PROVIDE="$PKG_L10N_ID"
PKG_L10N_DESCRIPTION_EN='English localization'
PKG_L10N_DESCRIPTION_FR='French localization'
PKG_L10N_DESCRIPTION_0="$PKG_L10N_DESCRIPTION_EN"

PKG_MAIN_ID="$GAME_ID"
PKG_MAIN_DEPS="$PKG_L10N_ID scummvm"

# icotool is used for icon .ico → .png conversion

SCRIPT_DEPS="$SCRIPT_DEPS icotool"

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Work around "insufficient image data" issue with convert from imagemagick

icon_extract_png_from_ico() {
	local source_file destination_directory
	source_file="$1"
	destination_directory="$2"
	icotool --extract --output="$destination_directory" "$source_file" 2>/dev/null
}

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'
prepare_package_layout

# Include game icon

icons_get_from_workdir 'APP_MAIN'

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
