#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Neverwinter Nights 1
# send your bug reports to contact@dotslashplay.it
###

script_version=20230101.1

GAME_ID='neverwinter-nights-1'
GAME_NAME='Neverwinter Nights'

ARCHIVE_BASE_DE_0='setup_nwn_diamond_german_2.1.0.21.exe'
ARCHIVE_BASE_DE_0_MD5='63a32f4fdb2939e73ac40d80f5798e28'
ARCHIVE_BASE_DE_0_EXTRACTOR='innoextract'
ARCHIVE_BASE_DE_0_EXTRACTOR_OPTIONS='--progress=1 --silent --lowercase --gog'
ARCHIVE_BASE_DE_0_PART1='setup_nwn_diamond_german_2.1.0.21-1.bin'
ARCHIVE_BASE_DE_0_PART1_MD5='e6c50d030b046c05ccf87601844ccc23'
ARCHIVE_BASE_DE_0_PART1_TYPE='rar'
ARCHIVE_BASE_DE_0_SIZE='4400000'
ARCHIVE_BASE_DE_0_VERSION='1.68-gog2.1.0.21'
ARCHIVE_BASE_DE_0_URL='https://www.gog.com/game/neverwinter_nights_enhanced_edition_pack'

ARCHIVE_BASE_EN_0='setup_nwn_diamond_2.1.0.21.exe'
ARCHIVE_BASE_EN_0_MD5='cd809b9d22022adb01b0d1d70c5afa8e'
ARCHIVE_BASE_EN_0_EXTRACTOR='innoextract'
ARCHIVE_BASE_EN_0_EXTRACTOR_OPTIONS='--progress=1 --silent --lowercase --gog'
ARCHIVE_BASE_EN_0_PART1='setup_nwn_diamond_2.1.0.21-1.bin'
ARCHIVE_BASE_EN_0_PART1_MD5='ce60bf104cc6082fe79d6f0bd7b48f51'
ARCHIVE_BASE_EN_0_PART1_TYPE='rar'
ARCHIVE_BASE_EN_0_SIZE='5100000'
ARCHIVE_BASE_EN_0_VERSION='1.69-gog2.1.0.21'
ARCHIVE_BASE_EN_0_URL='https://www.gog.com/game/neverwinter_nights_enhanced_edition_pack'

ARCHIVE_BASE_ES_0='setup_nwn_diamond_spanish_2.1.0.21.exe'
ARCHIVE_BASE_ES_0_MD5='70448f984b66a814bda712ecfef5977e'
ARCHIVE_BASE_ES_0_EXTRACTOR='innoextract'
ARCHIVE_BASE_ES_0_EXTRACTOR_OPTIONS='--progress=1 --silent --lowercase --gog'
ARCHIVE_BASE_ES_0_PART1='setup_nwn_diamond_spanish_2.1.0.21-1.bin'
ARCHIVE_BASE_ES_0_PART1_MD5='3b6dee19655a1280273c5d0652f74ab5'
ARCHIVE_BASE_ES_0_PART1_TYPE='rar'
ARCHIVE_BASE_ES_0_SIZE='4400000'
ARCHIVE_BASE_ES_0_VERSION='1.68-gog2.1.0.21'
ARCHIVE_BASE_ES_0_URL='https://www.gog.com/game/neverwinter_nights_enhanced_edition_pack'

ARCHIVE_BASE_FR_0='setup_nwn_diamond_french_2.1.0.21.exe'
ARCHIVE_BASE_FR_0_MD5='caadc0f809e10ddf781cacbebd1b25d9'
ARCHIVE_BASE_FR_0_EXTRACTOR='innoextract'
ARCHIVE_BASE_FR_0_EXTRACTOR_OPTIONS='--progress=1 --silent --lowercase --gog'
ARCHIVE_BASE_FR_0_PART1='setup_nwn_diamond_french_2.1.0.21-1.bin'
ARCHIVE_BASE_FR_0_PART1_MD5='aeb4b99635bdc046560477b2b11307e3'
ARCHIVE_BASE_FR_0_PART1_TYPE='rar'
ARCHIVE_BASE_FR_0_SIZE='4300000'
ARCHIVE_BASE_FR_0_VERSION='1.68-gog2.1.0.21'
ARCHIVE_BASE_FR_0_URL='https://www.gog.com/game/neverwinter_nights_enhanced_edition_pack'

ARCHIVE_BASE_PL_0='setup_nwn_diamond_polish_2.1.0.21.exe'
ARCHIVE_BASE_PL_0_MD5='5779b5c690984a79c617efc7649e66a3'
ARCHIVE_BASE_PL_0_EXTRACTOR='innoextract'
ARCHIVE_BASE_PL_0_EXTRACTOR_OPTIONS='--progress=1 --silent --lowercase --gog'
ARCHIVE_BASE_PL_0_PART1='setup_nwn_diamond_polish_2.1.0.21-1.bin'
ARCHIVE_BASE_PL_0_PART1_MD5='540c20cd68079c7a214af65296b4a8b1'
ARCHIVE_BASE_PL_0_PART1_TYPE='rar'
ARCHIVE_BASE_PL_0_SIZE='4400000'
ARCHIVE_BASE_PL_0_VERSION='1.68-gog2.1.0.21'
ARCHIVE_BASE_PL_0_URL='https://www.gog.com/game/neverwinter_nights_enhanced_edition_pack'

CONTENT_PATH_DEFAULT='game'
CONTENT_LIBS_BIN_PATH='lib'
CONTENT_LIBS_BIN_FILES='
*'
CONTENT_LIBS0_BIN_PATH='miles'
CONTENT_LIBS0_BIN_FILES='
*'
CONTENT_GAME_BIN_FILES='
dmclient
fixinstall
nwmain
nwserver
nwn.ini'
CONTENT_GAME_BIN_PATH='.'
CONTENT_GAME_BIN_FILES='
dmclient
fixinstall
lib
miles
nwmain
nwserver
nwn.ini'
CONTENT_GAME0_BIN_PATH='support/app'
CONTENT_GAME0_BIN_FILES='
nwncdkey.ini'
CONTENT_GAME1_BIN_PATH='.'
CONTENT_GAME1_BIN_FILES='
nwmovies
nwmovies_install.pl'
CONTENT_GAME_L10N_FILES='
*.key
*.tlk
movies/Chap?_Chap?.bik
movies/credits.bik
movies/ending.bik
movies/prelude.bik
movies/prelude_chap1.bik
movies/XP?_*.bik
data/*convo.bif
data/models_??.bif
data/music*.bif
data/templates.bif
data/*voicesets.bif
data/xp1_sounds*.bif
data/xp2_german.bif
data/xp2_french.bif
data/xp2_polish.bif'
CONTENT_DOC_L10N_PATH="${CONTENT_PATH_DEFAULT}/docs"
CONTENT_DOC_L10N_FILES='
*'
CONTENT_GAME_DATA_FILES='
ambient
dmvault
hak
localvault
modules
music
nwm
override
texturepacks
movies/*Logo.bik
movies/dd_??_credits.bik
movies/fge_logo_black.bik
movies/NWNintro.bik
movies/premiumdemo.bik
movies/WOTCLogo.bik
data/2da.bif
data/aurora_???.bif
data/editor.bif
data/ini.bif
data/loadscreens.bif
data/misc.bif
data/scripts.bif
data/sounds.bif
data/textures_??.bif
data/xp1.bif
data/xp1patch.bif
data/xp1_models.bif
data/xp1_scripts.bif
data/xp1_templates.bif
data/xp1_textures.bif
data/xp1_tiles.bif
data/xp2.bif
data/xp2_models.bif
data/xp2_scripts.bif
data/xp2_templates.bif
data/xp2_textures.bif
data/xp2_tiles.bif'
CONTENT_GAME0_DATA_PATH='.'
CONTENT_GAME0_DATA_FILES='
override'
CONTENT_DOC_DATA_PATH='.'
CONTENT_DOC_DATA_FILES='
*.txt'

APP_MAIN_EXE='nwmain'
APP_MAIN_ICON='nwn.exe'
APP_MAIN_PRERUN='
export SDL_MOUSE_RELATIVE=0
export SDL_VIDEO_X11_DGAMOUSE=0'

USER_PERSISTENT_DIRECTORIES='
portraits
saves
servervault'
USER_PERSISTENT_FILES='
*.ini'

PACKAGES_LIST='PKG_BIN PKG_L10N PKG_DATA'

PKG_L10N_ID="${GAME_ID}-l10n"
PKG_L10N_ID_DE="${PKG_L10N_ID}-de"
PKG_L10N_ID_ES="${PKG_L10N_ID}-es"
PKG_L10N_ID_EN="${PKG_L10N_ID}-en"
PKG_L10N_ID_FR="${PKG_L10N_ID}-fr"
PKG_L10N_ID_PL="${PKG_L10N_ID}-pl"
PKG_L10N_PROVIDE="$PKG_L10N_ID"
PKG_L10N_DESCRIPTION='Localization'
PKG_L10N_DESCRIPTION_DE="$PKG_L10N_DESCRIPTION - German"
PKG_L10N_DESCRIPTION_ES="$PKG_L10N_DESCRIPTION - Spanish"
PKG_L10N_DESCRIPTION_EN="$PKG_L10N_DESCRIPTION - English"
PKG_L10N_DESCRIPTION_FR="$PKG_L10N_DESCRIPTION - French"
PKG_L10N_DESCRIPTION_PL="$PKG_L10N_DESCRIPTION - Polish"

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID $PKG_L10N_ID"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libGL.so.1
libGLU.so.1
libm.so.6
libpthread.so.0
libSDL-1.2.so.0'

# Play movies using nwmovies

## NWMovies won’t be included in Arch Linux packages until this bug is fixed:
## https://forge.dotslashplay.it/play.it/games/-/issues/45

## TODO - We could probably build the preload library at package building time
APP_MAIN_PRERUN_NWMOVIES='
# Play movies using nwmovies
PLAYIT_LIBS_PATH_USER="${HOME}/.local/lib/games/${GAME_ID}"
if [ ! -e "${PLAYIT_LIBS_PATH_USER}/nwmovies/nwmovies.so" ]; then
	sed --in-place "s/mpv /mpv --fs --no-osc /" ./nwmovies/nwplaymovie
	./nwmovies/nwmovies_install.pl build >/dev/null 2>\&1
	mkdir --parents "$PLAYIT_LIBS_PATH_USER"
	cp \
		nwmovies/nwmovies.so \
		nwmovies/libdis/libdisasm.so \
		"$PLAYIT_LIBS_PATH_USER"
	mkdir --parents "$USER_PERSISTENT_PATH"
	cp --no-dereference --parents \
		nwmovies/nwplaymovie \
		nwplaymovie \
		"$USER_PERSISTENT_PATH"
fi
if [ ! -e nwmovies.ini ]; then
	PLAYIT_LIBS_PATH_SYSTEM="/usr/lib/games/${GAME_ID}"
	PLAYIT_LIBS_PATH_USER="${HOME}/.local/lib/games/${GAME_ID}"
	if [ -e "$PLAYIT_LIBS_PATH_SYSTEM" ]; then
		LD_LIBRARY_PATH="${PLAYIT_LIBS_PATH_SYSTEM}:${LD_LIBRARY_PATH}"
	fi
	if [ -e "$PLAYIT_LIBS_PATH_USER" ]; then
		LD_LIBRARY_PATH="${PLAYIT_LIBS_PATH_USER}:${LD_LIBRARY_PATH}"
	fi
	export LD_LIBRARY_PATH
	"./$APP_EXE" $APP_OPTIONS $@
fi'
PKG_BIN_DEPS_NWMOVIES='gcc32'
## TODO - Gentoo-specific dependencies are missing
PKG_BIN_DEPS_NWMOVIES_DEB='libelf-dev, libsdl1.2-dev:amd64 | libsdl1.2-dev, mpv:amd64 | mpv'

# Load common functions

target_version='2.20'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Check presence of Linux engine archives

ARCHIVE_REQUIRED_LINUX_COMMON='nwn-linux-common.tar.gz'
ARCHIVE_REQUIRED_LINUX_COMMON_URL='https://downloads.dotslashplay.it/games/neverwinter-nights-1/'
ARCHIVE_REQUIRED_LINUX_COMMON_MD5='9aa7dae2ba9111c96b10679fa085c66e'

package_version=$(packages_get_version 'SOURCE_ARCHIVE')
case "$package_version" in
	('1.69-'*)
		ARCHIVE_REQUIRED_LINUX='nwn-linux-1.69.tar.gz'
		ARCHIVE_REQUIRED_LINUX_URL='https://downloads.dotslashplay.it/games/neverwinter-nights-1/'
		ARCHIVE_REQUIRED_LINUX_MD5='b703f017446440e386ae142c1aa74a71'
	;;
	('1.68-'*)
		ARCHIVE_REQUIRED_LINUX='nwn-linux-1.68.tar.gz'
		ARCHIVE_REQUIRED_LINUX_URL='https://downloads.dotslashplay.it/games/neverwinter-nights-1/'
		ARCHIVE_REQUIRED_LINUX_MD5='7d46737ff2d25470f8d6b389bb53cd1a'
	;;
esac

archive_initialize_required 'ARCHIVE_LINUX_COMMON' \
	'ARCHIVE_REQUIRED_LINUX_COMMON'

archive_initialize_required 'ARCHIVE_LINUX' \
	'ARCHIVE_REQUIRED_LINUX'

# Check presence of NWMovies archive

ARCHIVE_OPTIONAL_NWMOVIES='nwmovies-mpv.tar.gz'
ARCHIVE_OPTIONAL_NWMOVIES_URL='https://sites.google.com/site/gogdownloader/nwmovies-mpv.tar.gz'
ARCHIVE_OPTIONAL_NWMOVIES_MD5='71f3d88db1cd75665b62b77f7604dce1'

case "$OPTION_PACKAGE" in
	('arch')
		# NWMovies won’t be included in Arch Linux packages until this bug is fixed:
		# https://forge.dotslashplay.it/play.it/games/-/issues/45
	;;
	(*)
		archive_initialize_optional 'ARCHIVE_NWMOVIES' \
			'ARCHIVE_OPTIONAL_NWMOVIES'

		if [ -n "$ARCHIVE_NWMOVIES" ]; then
			APP_MAIN_PRERUN="$APP_MAIN_PRERUN $APP_MAIN_PRERUN_NWMOVIES"
			PKG_BIN_DEPS="$PKG_BIN_DEPS $PKG_BIN_DEPS_NWMOVIES"
			## TODO - Gentoo-specific dependencies are missing
			PKG_BIN_DEPS_DEB="$PKG_BIN_DEPS_NWMOVIES_DEB"
		fi
	;;
esac

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'
archive_extraction 'ARCHIVE_LINUX_COMMON'
archive_extraction 'ARCHIVE_LINUX'
if [ -n "$ARCHIVE_NWMOVIES" ]; then
	archive_extraction 'ARCHIVE_NWMOVIES'
fi
(
	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"

	# Fixe case issues with some files.
	if [ -e 'dialog.TLK' ]; then
		mv 'dialog.TLK' 'dialog.tlk'
	fi
	if [ -e 'dialogF.TLK' ]; then
		mv 'dialogF.TLK' 'dialogf.tlk'
	fi
	for tiles in 'a' 'b' 'c'; do
		if [ -e "texturepacks/Tiles_TP${tiles}.ERF" ]; then
			mv "texturepacks/Tiles_TP${tiles}.ERF" "texturepacks/Tiles_Tp${tiles}.erf"
		fi
	done
)

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
