#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2021 Mopi
# SPDX-FileCopyrightText: © 2021 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Nine Noir Lives
# send your bug reports to contact@dotslashplay.it
###

script_version=20230322.1

GAME_ID='nine-noir-lives'
GAME_NAME='Nine Noir Lives'

GAME_ID_DEMO="${GAME_ID}-demo"
GAME_NAME_DEMO="$GAME_NAME (demo)"

ARCHIVE_BASE_DEMO_0='setup_nine_noir_lives_demo_1.02_(46357).exe'
ARCHIVE_BASE_DEMO_0_MD5='f22c232ad0d7c1512b0aa90611f67340'
ARCHIVE_BASE_DEMO_0_TYPE='innosetup'
ARCHIVE_BASE_DEMO_0_SIZE='550000'
ARCHIVE_BASE_DEMO_0_VERSION='1.02-gog46357'
ARCHIVE_BASE_DEMO_0_URL='https://www.gog.com/game/nine_noir_lives_demo'

CONTENT_PATH_DEFAULT='.'
CONTENT_GAME_BIN_FILES='
nnl.exe
config.ini
*.dll'
CONTENT_GAME_DATA_FILES='
nnl.vis
*.vc
*.vi
*.vs
*.vt
*.vv'

USER_PERSISTENT_FILES='
config.ini'

APP_WINE_LINK_DIRS='
userdata:users/${USER}/AppData/Local/Silvernode Studios/NNL Demo'
USER_PERSISTENT_DIRECTORIES='
userdata'

APP_MAIN_EXE='nnl.exe'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_ID_DEMO="${GAME_ID_DEMO}-data"
PKG_DATA_PROVIDE="$PKG_DATA_ID"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ID="$GAME_ID"
PKG_BIN_ID_DEMO="$GAME_ID_DEMO"
PKG_BIN_PROVIDE="$PKG_BIN_ID"
PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID"

# Load common functions

target_version='2.22'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'
(
	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"

	# Delete unwanted files
	rm --force --recursive \
		'commonappdata' \
		'tmp'
)

# Include game icons

PKG='PKG_DATA'
icons_inclusion
## Delete broken 256×256 icon
broken_icon="$(package_path 'PKG_DATA')$(path_icons)/256x256/apps/$(game_id).png"
rm --force "$broken_icon"
rmdir --ignore-fail-on-non-empty --parents "$(dirname "$broken_icon")"

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

write_metadata
build_pkg

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
