#!/bin/sh
set -o errexit

###
# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
# Copyright (c) 2016-2021, Mopi
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Out There
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20210930.6

# Set game-specific variables

GAME_ID='out-there'
GAME_NAME='Out There: Ω Edition'

ARCHIVE_BASE_LINUX_0='OutThere2-4-2Linux.zip'
ARCHIVE_BASE_LINUX_0_MD5='8ea51a42c9ad221e3d258e404c7106b0'
ARCHIVE_BASE_LINUX_0_SIZE='340000'
ARCHIVE_BASE_LINUX_0_VERSION='2.4.2-humble170213'
ARCHIVE_BASE_LINUX_0_URL='https://www.humblebundle.com/store/out-there-edition'

ARCHIVE_BASE_WINDOWS_0='OutThere2-4-2.zip'
ARCHIVE_BASE_WINDOWS_0_MD5='8b23dde3778ade4db73a3ed76c4134cd'
ARCHIVE_BASE_WINDOWS_0_SIZE='300000'
ARCHIVE_BASE_WINDOWS_0_VERSION='2.4.2-humble170213'
ARCHIVE_BASE_WINDOWS_0_URL='https://www.humblebundle.com/store/out-there-edition'

UNITY3D_NAME='OutThereOmega'

ARCHIVE_GAME_WINDOWS_BIN_PATH='.'
ARCHIVE_GAME_WINDOWS_BIN_FILES='
outthereomega.exe
outthereomega_Data/Plugins
outthereomega_Data/Mono'

ARCHIVE_GAME_LINUX_BIN32_PATH='.'
ARCHIVE_GAME_LINUX_BIN32_FILES="
${UNITY3D_NAME}.x86
${UNITY3D_NAME}_Data/Mono/x86
${UNITY3D_NAME}_Data/Plugins/x86"

ARCHIVE_GAME_LINUX_BIN64_PATH='.'
ARCHIVE_GAME_LINUX_BIN64_FILES="
${UNITY3D_NAME}.x86_64
${UNITY3D_NAME}_Data/Mono/x86_64
${UNITY3D_NAME}_Data/Plugins/x86_64"

ARCHIVE_GAME_DATA_PATH='.'
ARCHIVE_GAME_DATA_FILES_LINUX="${UNITY3D_NAME}_Data"
ARCHIVE_GAME_DATA_FILES_WINDOWS='
outthereomega_Data'

# Main application - Windows

APP_MAIN_TYPE_WINDOWS='wine'
APP_MAIN_EXE_WINDOWS='outthereomega.exe'
APP_MAIN_ICON_WINDOWS='outthereomega.exe'

PACKAGES_LIST_LINUX='PKG_LINUX_BIN32 PKG_LINUX_BIN64 PKG_DATA'
PACKAGES_LIST_WINDOWS='PKG_WINDOWS_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_PROVIDE="$PKG_DATA_ID"
PKG_DATA_DESCRIPTION='data'
PKG_DATA_ID_LINUX="${PKG_DATA_ID}-linux"
PKG_DATA_ID_WINDOWS="${PKG_DATA_ID}-windows"

PKG_BIN_ID="$GAME_ID"

PKG_LINUX_BIN32_ID="${PKG_BIN_ID}-linux"
PKG_LINUX_BIN32_PROVIDE="$PKG_BIN_ID"
PKG_LINUX_BIN32_ARCH='32'
PKG_LINUX_BIN32_DEPS="$PKG_DATA_ID xcursor libxrandr libc.so.6 libstdc++.so.6 libGL.so.1 libgtk-x11-2.0.so.0 libudev.so.1 libX11.so.6 libgdk_pixbuf-2.0.so.0 libgdk_pixbuf-2.0.so.0 libgobject-2.0.so.0 libglib-2.0.so.0"

PKG_LINUX_BIN64_ID="${PKG_BIN_ID}-linux"
PKG_LINUX_BIN64_PROVIDE="$PKG_BIN_ID"
PKG_LINUX_BIN64_ARCH='64'
PKG_LINUX_BIN64_DEPS="$PKG_BIN32_DEPS"

PKG_WINDOWS_BIN_ID="${PKG_BIN_ID}-windows"
PKG_WINDOWS_BIN_PROVIDE="$PKG_BIN_ID"
PKG_WINDOWS_BIN_ARCH='32'
PKG_WINDOWS_BIN_DEPS="$PKG_DATA_ID wine libGL.so.1"

# Use persistent storage for saved games (Windows version)

case "$ARCHIVE" in
	('ARCHIVE_BASE_WINDOWS'*)
		APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
		userdata:users/${USER}/Local Settings/Application Data/MiClos Studio/OutThereOmegaEdition'
		DATA_DIRS="$DATA_DIRS userdata"
	;;
esac

# Load common functions

target_version='2.14'

if [ -z "$PLAYIT_LIB2" ]; then
	for path in \
		"$PWD" \
		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
		'/usr/local/share/games/play.it' \
		'/usr/local/share/play.it' \
		'/usr/share/games/play.it' \
		'/usr/share/play.it'
	do
		if [ -e "${path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=play.it-2/lib/libplayit2.sh
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Include game icon

export APP_MAIN_ICON=$(get_context_specific_value 'archive' 'APP_MAIN_ICON')
case "$ARCHIVE" in
	('ARCHIVE_BASE_LINUX'*)
		PKG='PKG_DATA'
		icons_get_from_package 'APP_MAIN'
	;;
	('ARCHIVE_BASE_WINDOWS'*)
		PKG='PKG_WINDOWS_BIN'
		icons_get_from_package 'APP_MAIN'
		icons_move_to 'PKG_DATA'
	;;
esac

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

export APP_MAIN_TYPE=$(get_context_specific_value 'archive' 'APP_MAIN_TYPE')
for PKG in \
	'PKG_LINUX_BIN32' \
	'PKG_LINUX_BIN64' \
	'PKG_WINDOWS_BIN'
do
	if packages_get_list | grep --quiet "$PKG"; then
		launchers_write 'APP_MAIN'
	fi
done

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
