#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Rakuen
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220720.1

GAME_ID='rakuen'
GAME_NAME='Rakuen'

ARCHIVE_BASE_0='rakuen_linux.tgz'
ARCHIVE_BASE_0_MD5='cae92b2e92cd4e15796a7faa765d2e64'
ARCHIVE_BASE_0_SIZE='200000'
ARCHIVE_BASE_0_VERSION='1.0-humble1'
ARCHIVE_BASE_0_URL='https://www.humblebundle.com/store/rakuen'

CONTENT_PATH_DEFAULT='Rakuen'
ARCHIVE_DOC_DATA_FILES='
*.pdf'
ARCHIVE_GAME_BIN32_FILES='
Rakuen.x86
lib'
ARCHIVE_GAME_BIN64_FILES='
Rakuen.amd64
lib64'
ARCHIVE_GAME_DATA_FILES='
Audio
Engine.ini
Engine.rgssad
Fonts
icon.png
mkxp
mkxp.conf'

APP_MAIN_TYPE='native'
APP_MAIN_PREFIX_TYPE='none'
APP_MAIN_LIBS_BIN32='lib'
APP_MAIN_LIBS_BIN64='lib64'
APP_MAIN_EXE_BIN32='Rakuen.x86'
APP_MAIN_EXE_BIN64='Rakuen.amd64'
APP_MAIN_ICON='icon.png'

PACKAGES_LIST='PKG_BIN32 PKG_BIN64 PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN32_ARCH='32'
PKG_BIN32_DEPS="$PKG_DATA_ID libc.so.6 libSDL2-2.0.so.0"

PKG_BIN64_ARCH='64'
PKG_BIN64_DEPS="$PKG_BIN32_DEPS"

# Use persistent storage for user data

DATA_FILES='Engine.ini mkxp.conf'

# Load common functions

target_version='2.17'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'
content_path=$(content_path_default)
set_standard_permissions "${PLAYIT_WORKDIR}/gamedata/${content_path}"

# Include game icon

PKG='PKG_DATA'
icons_inclusion

# Include game data

prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

for PKG in 'PKG_BIN32' 'PKG_BIN64'; do
	launchers_write
done

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
