#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Mopi
# SPDX-FileCopyrightText: © 2017 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Regency Solitaire
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220831.1

GAME_ID='regency-solitaire'
GAME_NAME='Regency Solitaire'

# Archives

## Regency Solitaire (game archive)

ARCHIVE_BASE_0='RegencySolitaireV117b_1472495785.tar.gz'
ARCHIVE_BASE_0_MD5='15e8377d2cac99a52407cb399bd1ee7c'
ARCHIVE_BASE_0_SIZE='71000'
ARCHIVE_BASE_0_VERSION='1.17b-humble160829'
ARCHIVE_BASE_0_URL='https://www.humblebundle.com/store/regency-solitaire'

## Optional icons pack

ARCHIVE_OPTIONAL_ICONS='regency-solitaire_icons.tar.gz'
ARCHIVE_OPTIONAL_ICONS_MD5='01a7c7b168e2cb315d2058ff5e6a53aa'
ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/resources/regency-solitaire/'

# Archives content

## Regency Solitaire (game archive)

CONTENT_PATH_DEFAULT='RegencySolitaireV117b'
ARCHIVE_GAME_BIN_FILES='
RegencySolitaire'
ARCHIVE_GAME_DATA_FILES='
data'

## Optional icons pack

ARCHIVE_ICONS_PATH='.'
ARCHIVE_ICONS_FILES='
16x16
32x32
48x48
256x256'


APP_MAIN_TYPE='native'
APP_MAIN_EXE='RegencySolitaire'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID libc.so.6 libstdc++.so.6 libGLU.so.1"

# Load common functions

target_version='2.17'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'
(
	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
	
	set_standard_permissions .
)

# Include game icons

PKG='PKG_DATA'
archive_initialize_optional \
	'ARCHIVE_ICONS' \
	'ARCHIVE_OPTIONAL_ICONS'
if [ -n "$ARCHIVE_ICONS" ]; then
	archive_extraction 'ARCHIVE_ICONS'
	organize_data 'ICONS' "$PATH_ICON_BASE"
fi

# Include game data

prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build package

write_metadata
build_pkg

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
