#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2018 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Republique
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220706.1

GAME_ID='republique'
GAME_NAME='Republique'

# This DRM-free archive is no longer sold by GOG
ARCHIVE_BASE_0='setup_republique_remastered_33555_(18824).exe'
ARCHIVE_BASE_0_MD5='e1c57ea3489a5ffd222990ab28a9ffe7'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1='setup_republique_remastered_33555_(18824)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='f8d81dd49c0a17e772601880c1d76058'
ARCHIVE_BASE_0_PART1_TYPE='innosetup'
ARCHIVE_BASE_0_PART2='setup_republique_remastered_33555_(18824)-2.bin'
ARCHIVE_BASE_0_PART2_MD5='485f3c68ca8bf61e328f2e659afc59b2'
ARCHIVE_BASE_0_PART2_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='7800000'
ARCHIVE_BASE_0_VERSION='1.0-gog18824'

ARCHIVE_BASE_RAR_0='setup_republique_remastered_2.2.0.4.exe'
ARCHIVE_BASE_RAR_0_MD5='e2a15feb5b9217bebf0fec26e2a81869'
ARCHIVE_BASE_RAR_0_TYPE='rar' # This is actually a InnoSetup installer based on a RAR archive
ARCHIVE_BASE_RAR_0_PART1='setup_republique_remastered_2.2.0.4-1.bin'
ARCHIVE_BASE_RAR_0_PART1_MD5='b7a869b84db07e5981b9eb8be9ff2bda'
ARCHIVE_BASE_RAR_0_PART1_TYPE='rar'
ARCHIVE_BASE_RAR_0_PART2='setup_republique_remastered_2.2.0.4-2.bin'
ARCHIVE_BASE_RAR_0_PART2_MD5='604d6b34fa4b2cc24f79659922f188e2'
ARCHIVE_BASE_RAR_0_PART2_TYPE='rar'
ARCHIVE_BASE_RAR_0_SIZE='7800000'
ARCHIVE_BASE_RAR_0_VERSION='1.0-gog2.2.0.4'

UNITY3D_NAME='republique'

CONTENT_PATH_DEFAULT='app'
CONTENT_PATH_DEFAULT_RAR='game'
ARCHIVE_GAME_BIN_FILES="
${UNITY3D_NAME}.exe
${UNITY3D_NAME}_data/mono
${UNITY3D_NAME}_data/plugins"
ARCHIVE_GAME_DATA_FILES="
${UNITY3D_NAME}_data"

APP_MAIN_TYPE='wine'
APP_MAIN_EXE="${UNITY3D_NAME}.exe"
APP_MAIN_ICON="${UNITY3D_NAME}.exe"

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine"

# Use persistent storage for user data

APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
saves:users/${USER}/AppData/LocalLow/Camouflaj/R__publique/Save'
DATA_DIRS="$DATA_DIRS saves"

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

case "$ARCHIVE" in
	('ARCHIVE_BASE_RAR_'*)
		archive_part1_path=$(realpath --canonicalize-existing "$SOURCE_ARCHIVE_PART1")
		archive_part2_path=$(realpath --canonicalize-existing "$SOURCE_ARCHIVE_PART2")
		game_id=$(game_id)
		ln --symbolic "$archive_part1_path" "${PLAYIT_WORKDIR}/${game_id}.r00"
		ln --symbolic "$archive_part2_path" "${PLAYIT_WORKDIR}/${game_id}.r01"
		(
			SOURCE_ARCHIVE_PART1="${PLAYIT_WORKDIR}/${game_id}.r00"
			archive_extraction 'SOURCE_ARCHIVE_PART1'
		)
		rm \
			"${PLAYIT_WORKDIR}/${game_id}.r00" \
			"${PLAYIT_WORKDIR}/${game_id}.r01"
		tolower "${PLAYIT_WORKDIR}/gamedata"
	;;
	(*)
		archive_extraction 'SOURCE_ARCHIVE'
	;;
esac
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
