#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2022 Mopi
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Retour sur l'Ile Mystérieuse
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220822.1

GAME_ID='retour-sur-lile-mysterieuse'
GAME_NAME='Retour sur l’Ile Mystérieuse'

ARCHIVE_BASE_0='setup_return_to_mysterious_island_2.1.0.17.exe'
ARCHIVE_BASE_0_MD5='d31567796e419eb0c295bf978aa1d434'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='1500000'
ARCHIVE_BASE_0_VERSION='1.0-gog2.1.0.17'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/return_to_mysterious_island'

CONTENT_PATH_DEFAULT='app'
ARCHIVE_GAME_BIN_FILES='
*.dll
game.exe'
ARCHIVE_GAME_L10N_FR_FILES='
datas/loc/fr
datas/cd?/loc_fr_*'
ARCHIVE_GAME_L10N_GE_FILES='
datas/loc/ge
datas/cd?/loc_ge_*'
ARCHIVE_GAME_L10N_IT_FILES='
datas/loc/it
datas/cd?/loc_it_*'
ARCHIVE_GAME_L10N_SP_FILES='
datas/loc/sp
datas/cd?/loc_sp_*'
ARCHIVE_GAME_L10N_RU_FILES='
datas/loc/ru
datas/cd?/loc_ru_*'
ARCHIVE_GAME_L10N_US_FILES='
datas/loc/us
datas/cd?/loc_us_*'
ARCHIVE_GAME_DATA_FILES='
datas'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='game.exe'
APP_MAIN_ICON='game.exe'

PACKAGES_LIST='PKG_BIN PKG_L10N_FR PKG_L10N_GE PKG_L10N_IT PKG_L10N_SP PKG_L10N_RU PKG_L10N_US PKG_DATA'

PKG_L10N_ID="${GAME_ID}-l10n"
PKG_L10N_FR_ID="${PKG_L10N_ID}-fr"
PKG_L10N_GE_ID="${PKG_L10N_ID}-ge"
PKG_L10N_IT_ID="${PKG_L10N_ID}-it"
PKG_L10N_SP_ID="${PKG_L10N_ID}-sp"
PKG_L10N_RU_ID="${PKG_L10N_ID}-ru"
PKG_L10N_US_ID="${PKG_L10N_ID}-us"
PKG_L10N_FR_PROVIDE="$PKG_L10N_ID"
PKG_L10N_GE_PROVIDE="$PKG_L10N_ID"
PKG_L10N_IT_PROVIDE="$PKG_L10N_ID"
PKG_L10N_SP_PROVIDE="$PKG_L10N_ID"
PKG_L10N_RU_PROVIDE="$PKG_L10N_ID"
PKG_L10N_US_PROVIDE="$PKG_L10N_ID"
PKG_L10N_FR_DESCRIPTION='French localization'
PKG_L10N_GE_DESCRIPTION='German localization'
PKG_L10N_IT_DESCRIPTION='Italian localization'
PKG_L10N_SP_DESCRIPTION='Spanish localization'
PKG_L10N_RU_DESCRIPTION='Russian localization'
PKG_L10N_US_DESCRIPTION='English localization'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID $PKG_L10N_ID wine"

# Use persistent storage for user data

USER_PERSISTENT_DIRECTORIES='
users'

# Load common functions

target_version='2.17'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

(
	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"

	# Fix game install path in configuration
	ini_file='config.ini'
	ini_field='PATH'
	ini_value="C:\\\\${game_id}\\\\datas"
	pattern="s/^${ini_field}=.*/${ini_field}=${ini_value}/"
	dos2unix --quiet "$ini_file"
	sed --in-place "$pattern" "$ini_file"
	unix2dos --quiet "$ini_file"

	# Include configuration file in localization packages
	source_file='config.ini'
	dos2unix --quiet "$source_file"
	for lang in \
		'FR' \
		'GE' \
		'IT' \
		'RU' \
		'SP' \
		'US'
	do
		PKG="PKG_L10N_${lang}"
		package_path=$(package_get_path "$PKG")
		destination_file="${package_path}${PATH_GAME}/config.ini"
		destination_directory=$(dirname "$destination_file")
		ini_field='LOC'
		ini_value="$lang"
		pattern="s/^${ini_field}=.*/${ini_field}=${ini_value}/"
		mkdir --parents "$destination_directory"
		sed "$pattern" "$source_file" > "$destination_file"
		unix2dos --quiet "$destination_file"
	done
)

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build package

write_metadata
build_pkg

# Print instructions

common_packages='PKG_BIN PKG_DATA'
case "${LANG%_*}" in
	('fr')
		message='version %s :'
		lang_fr='française'
		lang_ge='allemande'
		lang_it='italienne'
		lang_sp='espagnole'
		lang_ru='russe'
		lang_us='anglaise'
	;;
	('en'|*)
		message='%s version:'
		lang_fr='French'
		lang_ge='German'
		lang_it='Italian'
		lang_sp='Spanish'
		lang_ru='Russian'
		lang_us='English'
	;;
esac
printf '\n'
printf "$message" "$lang_fr"
print_instructions 'PKG_L10N_FR' $common_packages
printf "$message" "$lang_ge"
print_instructions 'PKG_L10N_GE' $common_packages
printf "$message" "$lang_it"
print_instructions 'PKG_L10N_IT' $common_packages
printf "$message" "$lang_sp"
print_instructions 'PKG_L10N_SP' $common_packages
printf "$message" "$lang_ru"
print_instructions 'PKG_L10N_RU' $common_packages
printf "$message" "$lang_us"
print_instructions 'PKG_L10N_US' $common_packages

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
