#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Risk of Rain
# send your bug reports to contact@dotslashplay.it
###

script_version=20230815.1

GAME_ID='risk-of-rain'
GAME_NAME='Risk of Rain'

ARCHIVE_BASE_GOG_1='gog_risk_of_rain_2.1.0.6.sh'
ARCHIVE_BASE_GOG_1_MD5='423ea26f877eb8f0d72e04dffffbf81a'
ARCHIVE_BASE_GOG_1_SIZE='180000'
ARCHIVE_BASE_GOG_1_VERSION='1.2.8-gog2.1.0.6'
ARCHIVE_BASE_GOG_1_URL='https://www.gog.com/game/risk_of_rain'

ARCHIVE_BASE_GOG_0='gog_risk_of_rain_2.1.0.5.sh'
ARCHIVE_BASE_GOG_0_MD5='34f8e1e2dddc6726a18c50b27c717468'
ARCHIVE_BASE_GOG_0_SIZE='180000'
ARCHIVE_BASE_GOG_0_VERSION='1.2.8-gog2.1.0.5'

ARCHIVE_BASE_HUMBLE_0='Risk_of_Rain_v1.3.0_DRM-Free_Linux_.zip'
ARCHIVE_BASE_HUMBLE_0_MD5='21eb80a7b517d302478c4f86dd5ea9a2'
ARCHIVE_BASE_HUMBLE_0_SIZE='100000'
ARCHIVE_BASE_HUMBLE_0_VERSION='1.3.0-humble160519'
ARCHIVE_BASE_HUMBLE_0_URL='https://www.humblebundle.com/store/risk-of-rain'

CONTENT_PATH_DEFAULT_GOG='data/noarch/game'
CONTENT_PATH_DEFAULT_HUMBLE='.'
CONTENT_GAME_BIN_FILES='
Risk_of_Rain'
CONTENT_GAME_DATA_FILES='
assets'

APP_MAIN_EXE='Risk_of_Rain'
APP_MAIN_ICON='assets/icon.png'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libdl.so.2
libgcc_s.so.1
libGL.so.1
libGLU.so.1
libm.so.6
libopenal.so.1
libpthread.so.0
librt.so.1
libstdc++.so.6
libX11.so.6
libXext.so.6
libXrandr.so.2
libXxf86vm.so.1
libz.so.1'

# Load common functions

target_version='2.25'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Ensure availability of CURL_OPENSSL_3 symbol

ARCHIVE_REQUIRED_LIBCURL3='curl_7.52.1_i386.tar.xz'
ARCHIVE_REQUIRED_LIBCURL3_MD5='66f1576d802937ba576b203b0d654922'
ARCHIVE_REQUIRED_LIBCURL3_URL='https://downloads.dotslashplay.it/resources/curl/'
CONTENT_LIBCURL3_PATH='.'
CONTENT_LIBCURL3_FILES='
libcrypto.so.1.0.2
libssl.so.1.0.2
libcurl.so.3
libcurl.so.4
libcurl.so.4.4.0'
archive_initialize_required \
	'ARCHIVE_LIBCURL3' \
	'ARCHIVE_REQUIRED_LIBCURL3'
archive_extraction 'ARCHIVE_LIBCURL3'
content_inclusion 'LIBCURL3' 'PKG_BIN' "$(path_libraries)"
rm --recursive "${PLAYIT_WORKDIR}/gamedata"
PKG_BIN_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES
libcom_err.so.2
libc.so.6
libdl.so.2
libgssapi_krb5.so.2
libidn2.so.0
libk5crypto.so.3
libkrb5.so.3
libnghttp2.so.14
libpsl.so.5
libpthread.so.0
librtmp.so.1
libssh2.so.1
libz.so.1"

# Ensure availability of libSSL 1.0.0 (32-bit)

option_package=$(option_value 'package')
case "$option_package" in
	('deb')
		ARCHIVE_OPTIONAL_LIBSSL32='libssl_1.0.0_32-bit.tar.gz'
		ARCHIVE_OPTIONAL_LIBSSL32_MD5='9443cad4a640b2512920495eaf7582c4'
		ARCHIVE_OPTIONAL_LIBSSL32_URL='https://downloads.dotslashplay.it/resources/libssl/'
		CONTENT_LIBSSL32_PATH='.'
		CONTENT_LIBSSL32_FILES='
		libcrypto.so.1.0.0
		libssl.so.1.0.0'
		archive_initialize_required \
			'ARCHIVE_LIBSSL32' \
			'ARCHIVE_OPTIONAL_LIBSSL32'
		archive_extraction 'ARCHIVE_LIBSSL32'
		content_inclusion 'LIBSSL32' 'PKG_BIN' "$(path_libraries)"
		rm --recursive "${PLAYIT_WORKDIR}/gamedata"
		PKG_BIN_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES
		libc.so.6
		libdl.so.2"
	;;
	(*)
		PKG_BIN_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES
		libcrypto.so.1.0.0
		libssl.so.1.0.0"
	;;
esac

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
