#!/bin/sh
set -o errexit

###
# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
# Copyright (c) 2016-2021, Mopi
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Shelter
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20211020.1

# Set game-specific variables

GAME_ID='shelter-1'
GAME_NAME='Shelter'

# Archives

## Humble Bundle

ARCHIVE_BASE_HUMBLE_0='Shelter_PC_Gold_v5.zip'
ARCHIVE_BASE_HUMBLE_0_MD5='32b84f87d7c24f57809670742adad3f7'
ARCHIVE_BASE_HUMBLE_0_SIZE='550000'
ARCHIVE_BASE_HUMBLE_0_VERSION='1.0-humble1'
ARCHIVE_BASE_HUMBLE_0_URL='https://www.humblebundle.com/store/shelter'

## GOG

ARCHIVE_BASE_GOG_1='setup_shelter_1.0_(18565).exe'
ARCHIVE_BASE_GOG_1_MD5='7d1a2df224b43ce5a80008af13edde1d'
ARCHIVE_BASE_GOG_1_TYPE='innosetup'
ARCHIVE_BASE_GOG_1_SIZE='560000'
ARCHIVE_BASE_GOG_1_VERSION='1.0-gog18565'
ARCHIVE_BASE_GOG_1_URL='https://www.gog.com/game/shelter'

ARCHIVE_BASE_GOG_0='setup_shelter_2.0.0.6.exe'
ARCHIVE_BASE_GOG_0_MD5='06860af1df9a8120bce4e97d899b3edd'
ARCHIVE_BASE_GOG_0_TYPE='innosetup'
ARCHIVE_BASE_GOG_0_SIZE='570000'
ARCHIVE_BASE_GOG_0_VERSION='1.0-gog2.0.0.6'


UNITY3D_NAME='shelter'

ARCHIVE_GAME_BIN_PATH_GOG='app'
ARCHIVE_GAME_BIN_PATH_HUMBLE='.'
ARCHIVE_GAME_BIN_FILES="
${UNITY3D_NAME}.exe
${UNITY3D_NAME}_data/mono"

ARCHIVE_GAME_DATA_PATH_GOG='app'
ARCHIVE_GAME_DATA_PATH_HUMBLE='.'
ARCHIVE_GAME_DATA_FILES="${UNITY3D_NAME}_data"

APP_MAIN_TYPE='wine'
APP_MAIN_EXE="${UNITY3D_NAME}.exe"
APP_MAIN_ICON="${UNITY3D_NAME}.exe"

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine"

# Use persistent storage for user data

APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
saves:users/$(id -un)/Application Data/Might and Delight/Shelter'
DATA_DIRS="$DATA_DIRS ./saves"

# Ensure smooth upgrade from previous game id

PKG_BIN_PROVIDE='shelter'
PKG_DATA_PROVIDE='shelter-data'

# Load common functions

target_version='2.14'

if [ -z "$PLAYIT_LIB2" ]; then
	for path in \
		"$PWD" \
		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
		'/usr/local/share/games/play.it' \
		'/usr/local/share/play.it' \
		'/usr/share/games/play.it' \
		'/usr/share/play.it'
	do
		if [ -e "${path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=play.it-2/lib/libplayit2.sh
. "$PLAYIT_LIB2"

# Check for the presence of the "rename" command
# On Arch Linux is is provided under the name "perl-rename"

unset RENAME_CMD
for rename_cmd in 'perl-rename' 'rename'; do
	if command -v "$rename_cmd" >/dev/null 2>&1; then
		RENAME_CMD="$rename_cmd"
		break
	fi
done
if [ -z "$RENAME_CMD" ]; then
	error_dependency_not_found 'rename'
	exit 1
fi

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
case "$ARCHIVE" in
	('ARCHIVE_BASE_HUMBLE_'*)
		tolower "$PLAYIT_WORKDIR/gamedata"
	;;
esac

# Enforce a consistent Unity3D name

(
	archive_inner_path=$(get_context_specific_value 'archive' 'ARCHIVE_GAME_BIN_PATH')
	cd "$PLAYIT_WORKDIR/gamedata/$archive_inner_path"
	"$RENAME_CMD" "s/.*_data/$(unity3d_name)_data/" *_data
	"$RENAME_CMD" "s/.*\.exe/$(unity3d_name).exe/" *.exe
)

# Include game files

prepare_package_layout

# Delete temporary files

rm --recursive "$PLAYIT_WORKDIR/gamedata"

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
