#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Mopi
# SPDX-FileCopyrightText: © 2017 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Solar 2
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220627.1

GAME_ID='solar-2'
GAME_NAME='Solar 2'

ARCHIVE_BASE_0='solar2-linux-1.10_1409159048.tar.gz'
ARCHIVE_BASE_0_MD5='243918907eea486fdc820b7cac0c260b'
ARCHIVE_BASE_0_SIZE='130000'
ARCHIVE_BASE_0_VERSION='1.10-humble1'
ARCHIVE_BASE_0_URL='https://www.humblebundle.com/store/solar-2'

CONTENT_PATH_DEFAULT='Solar2'
ARCHIVE_GAME_BIN_FILES='
Solar2.bin.x86
display.txt
lib/libmad.so.0.2.1
lib/libmikmod.so.2.0.4
lib/libmono-2.0.so.1
lib/libopenal.so.1.13.0
lib/libSDL_mixer-1.2.so.0.10.1'
ARCHIVE_GAME_DATA_FILES='
Solar2.exe
*.dll
*.config
mono
Languages
MonoContent'

APP_MAIN_TYPE='native'
APP_MAIN_EXE='Solar2.bin.x86'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID libc.so.6 libstdc++.so.6"

# Use persistent storage for user data

CONFIG_FILES='./display.txt'
DATA_DIRS='./Languages'

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Include icons from the optional archive if it is provided

ARCHIVE_OPTIONAL_ICONS='solar-2_icons.tar.gz'
ARCHIVE_OPTIONAL_ICONS_MD5='d8f8557a575cb5b5824d72718428cd33'
ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/resources/solar-2/'

ARCHIVE_ICONS_PATH='.'
ARCHIVE_ICONS_FILES='16x16 32x32 48x48 64x64'

archive_initialize_optional \
	'ARCHIVE_ICONS' \
	'ARCHIVE_OPTIONAL_ICONS'
if [ -n "$ARCHIVE_ICONS" ]; then
	PKG='PKG_DATA'
	(
		ARCHIVE='ARCHIVE_ICONS'
		extract_data_from "$ARCHIVE_ICONS"
	)
	organize_data 'ICONS' "$PATH_ICON_BASE"
	rm --recursive "${PLAYIT_WORKDIR}/gamedata"
else
	case "${LANG%_*}" in
		('fr')
			message='Lʼarchive suivante nʼayant pas été fournie, le lanceur pour ce jeu nʼutilisera pas dʼicône spécifique : %s\n'
			message="$message"'Cette archive peut être téléchargée depuis %s\n'
		;;
		('en'|*)
			message='Due to the following archive missing, the game launcher will not use a specific icon: %s\n'
			message="$message"'This archive can be downloaded from %s\n'
		;;
	esac
	print_warning
	printf "$message" "$ARCHIVE_OPTIONAL_ICONS" "$ARCHIVE_OPTIONAL_ICONS_URL"
	printf '\n'
fi

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
set_standard_permissions "${PLAYIT_WORKDIR}/gamedata"
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Create required library links

PKG='PKG_BIN'
package_path=$(package_get_path "$PKG")
(
	cd "${package_path}${PATH_GAME}/lib"
	ln --symbolic 'libmad.so.0.2.1' 'libmad.so.0'
	ln --symbolic 'libmikmod.so.2.0.4' 'libmikmod.so.2'
	ln --symbolic 'libmono-2.0.so.1' 'libmono-2.0.so'
	ln --symbolic 'libopenal.so.1.13.0' 'libopenal.so.1'
	ln --symbolic 'libSDL_mixer-1.2.so.0.10.1' 'libSDL_mixer-1.2.so.0'
)

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

#print instructions

print_instructions

exit 0
