#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Spellforce
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220628.1

GAME_ID='spellforce'
GAME_NAME='Spellforce'

ARCHIVE_BASE_0='setup_spellforce_-_platinum_edition_1.54.75000_(17748).exe'
ARCHIVE_BASE_0_MD5='ed34fb43d8042ff61a889865148b8dd2'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1='setup_spellforce_-_platinum_edition_1.54.75000_(17748)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='60fca014e7ccd4630a7ec3cedb23942a'
ARCHIVE_BASE_0_PART1_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='3900000'
ARCHIVE_BASE_0_VERSION='1.54.7500-gog17748'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/spellforce_platinum'

CONTENT_PATH_DEFAULT='app'
ARCHIVE_DOC_DATA_FILES='
manual.pdf
readme.rtf'
ARCHIVE_GAME_BIN_FILES='
ar.exe
binkw32.dll
dbghelp.dll
mss32.dll
spellforce.exe'
ARCHIVE_GAME_DATA_FILES='
data
map
miles
pak
videos
spellforce_addon2.ico
spellforce_addon.ico'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='spellforce.exe'
APP_MAIN_ICON='spellforce.exe'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine"

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Register CD key

PKG='PKG_BIN'
package_path=$(package_get_path "$PKG")
registry_file='registry-tweaks/register-cd-key.reg'
APP_REGEDIT="$APP_REGEDIT $registry_file"
registry_file_path="${package_path}${PATH_GAME}/${registry_file}"
registry_file_directory=$(dirname "$registry_file_path")
mkdir --parents "$registry_file_directory"
cat > "$registry_file_path" << 'EOF'
Windows Registry Editor Version 5.00

[HKEY_LOCAL_MACHINE\Software\Microsoft\Windows\CurrentVersion\Uninstall\SpellForce]
"CDKEY"="2M0VY-3QIPS-TTKC1-RV90B-0QMXG"
EOF

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
