#!/bin/sh
set -o errexit

###
# Copyright © 2015-2022, Antoine Le Gonidec <vv221@dotslashplay.it>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Spore
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220105.5

# Set game-specific variables

GAME_ID='spore'
GAME_NAME='Spore'

ARCHIVE_BASE_0='setup_spore_3.1.0.22_(10834).exe'
ARCHIVE_BASE_0_MD5='195652ca3eb62fe725f7b334cb27874e'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1='setup_spore_3.1.0.22_(10834)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='384354f468d981965d45f437e54a13ab'
ARCHIVE_BASE_0_PART1_TYPE='innosetup'
ARCHIVE_BASE_0_PART2='setup_spore_3.1.0.22_(10834)-2.bin'
ARCHIVE_BASE_0_PART2_MD5='885466a612c4243ef10758c7c6cfcfbb'
ARCHIVE_BASE_0_PART2_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='6300000'
ARCHIVE_BASE_0_VERSION='3.1.0.22-gog10834'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/spore_collection'

CONTENT_PATH_DEFAULT='app'
ARCHIVE_DOC_DATA_FILES='support'
ARCHIVE_GAME_BIN_FILES='
sporebin
sporebinep1'
ARCHIVE_GAME_DATA_FILES='
data
dataep1
bp1content'
ARCHIVE_PREFERENCES_PATH="${CONTENT_PATH_DEFAULT}/__support/add"
ARCHIVE_PREFERENCES_FILES='login.prop'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='sporebin/sporeapp.exe'
APP_MAIN_ICON='sporebin/sporeapp.exe'

APP_EP1_ID="${GAME_ID}-ep1"
APP_EP1_NAME="${GAME_NAME} - Galactic Adventures"
APP_EP1_TYPE='wine'
APP_EP1_EXE='sporebinep1/sporeapp.exe'
APP_EP1_ICON='sporebinep1/sporeapp.exe'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine"

# Use persistent t=storage for user data

APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
userdata:users/${USER}/Application Data/Spore
userdata:users/${USER}/AppData/Roaming/Spore
creations:users/${USER}/My Documents/My Spore Creations
creations:users/${USER}/Documents/My Spore Creations'
CONFIG_DIRS='userdata/Preferences'
DATA_DIRS='userdata/Games ./creations'
DATA_FILES='userdata/*.package'

# Load common functions

target_version='2.15'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout
organize_data 'PREFERENCES' "${PATH_GAME}/userdata/Preferences"

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Set required registry keys

PKG='PKG_BIN'
package_path=$(package_get_path "$PKG")

registry_dump_file='registry-dumps/init-spore.reg'
registry_dump_path="${package_path}${PATH_GAME}/${registry_dump_file}"
registry_dump_directory=$(dirname "$registry_dump_path")
APP_REGEDIT="$APP_REGEDIT $registry_dump_file"

game_id=$(game_id)
installloc="C:\\\\${game_id}"
datadir="C:\\\\${game_id}\\\\data"

mkdir --parents "$registry_dump_directory"

{
	cat <<- 'EOF'
	Windows Registry Editor Version 5.00

	[HKEY_LOCAL_MACHINE\Software\electronic arts\spore]
	"appdir"="Spore"
	"installcompleted"=dword:00000001
	"locale"="en-us"
	"playerdir"="My Spore Creations"
	"reindexyesorno"=dword:00000000
	EOF
	cat <<- EOF
	"installloc"="${installloc}"
	"datadir"="${datadir}"
	EOF
} > "$registry_dump_path"

registry_dump_file='registry-dumps/init-spore-ep1.reg'
registry_dump_path="${package_path}${PATH_GAME}/${registry_dump_file}"
registry_dump_directory=$(dirname "$registry_dump_path")
APP_REGEDIT="$APP_REGEDIT $registry_dump_file"

datadir="C:\\\\${game_id}\\\\dataep1\\\\"

mkdir --parents "$registry_dump_directory"

{
	cat <<- 'EOF'
	Windows Registry Editor Version 5.00

	[HKEY_LOCAL_MACHINE\Software\electronic arts\spore_EP1]
	"AddOnID"=dword:00000002
	"PackID"=dword:07a7f786
	EOF
	cat <<- EOF
	"DataDir"="${datadir}"
	EOF
} > "$registry_dump_path"

registry_dump_file='registry-dumps/init-spore-creepy-and-cute-parts-pack.reg'
registry_dump_path="${package_path}${PATH_GAME}/${registry_dump_file}"
registry_dump_directory=$(dirname "$registry_dump_path")
APP_REGEDIT="$APP_REGEDIT $registry_dump_file"

datadir="C:\\\\${game_id}\\\\bp1content\\\\"

mkdir --parents "$registry_dump_directory"

{
	cat <<- 'EOF'
	Windows Registry Editor Version 5.00

	[HKEY_LOCAL_MACHINE\Software\electronic arts\spore Creepy and Cute Parts Pack]
	"AddOnID"=dword:00000001
	"PackID"=dword:06f4b5d1
	EOF
	cat <<- EOF
	"DataDir"="${datadir}"
	EOF
} > "$registry_dump_path"

# Include game icons

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN' 'APP_EP1'
icons_move_to 'PKG_DATA'

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN' 'APP_EP1'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
