#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2020 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Strike Suit Zero
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220628.1

GAME_ID='strike-suit-zero'
GAME_NAME='Strike Suit Zero'

ARCHIVE_BASE_0='StrikeSuitZero_linux_1389211698.zip'
ARCHIVE_BASE_0_MD5='94b1c2907ae61deb27eb77fee3fb9c19'
ARCHIVE_BASE_0_SIZE='2400000'
ARCHIVE_BASE_0_VERSION='1.0-humble1'
ARCHIVE_BASE_0_URL='https://www.humblebundle.com/store/strike-suit-zero'

CONTENT_PATH_DEFAULT='.'
ARCHIVE_GAME_BIN_FILES='
linux/main/binary/StrikeSuitZero
linux/main/binary/libfmodevent.so
linux/main/binary/libfmodeventnet.so
linux/main/binary/libfmodex-4.44.12.so
linux/main/binary/libfmodex.so
linux/main/binary/libsteam_api.so'
ARCHIVE_GAME_DATA_FILES='
linux/main/art
linux/main/audio
linux/main/fonts
linux/main/gui
linux/main/level
linux/main/levels
linux/main/localisation
linux/main/particles
linux/main/scripts
linux/main/shaders
linux/main/system
linux/main/textures
linux/main/video
linux/main/index.toc
linux/main/index.toc.txt'

APP_MAIN_TYPE='native'
APP_MAIN_EXE='linux/main/binary/StrikeSuitZero'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID libc.so.6 libstdc++.so.6 libGL.so.1 libSDL2-2.0.so.0"

# Use persistent storage for user data

CONFIG_FILES='linux/main/binary/settings.sav'
DATA_FILES='linux/main/binary/Main.sav linux/main/binary/background.sav'

# Set working directory to the directory containing the game binary before running it

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
# Set working directory to the directory containing the game binary before running it
cd "$(dirname "$APP_EXE")"
APP_EXE=$(basename "$APP_EXE")'

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Include icons from the optional archive if it is provided

ARCHIVE_OPTIONAL_ICONS='strike-suit-zero_icons.tar.gz'
ARCHIVE_OPTIONAL_ICONS_MD5='3fe8bbad7ecca5c0e3afdbbfedb8945d'
ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/resources/strike-suit-zero/'

ARCHIVE_ICONS_PATH='.'
ARCHIVE_ICONS_FILES='16x16 32x32 48x48'

archive_initialize_optional \
	'ARCHIVE_ICONS' \
	'ARCHIVE_OPTIONAL_ICONS'
if [ -n "$ARCHIVE_ICONS" ]; then
	PKG='PKG_DATA'
	(
		ARCHIVE='ARCHIVE_ICONS'
		extract_data_from "$ARCHIVE_ICONS"
	)
	organize_data 'ICONS' "$PATH_ICON_BASE"
	rm --recursive "${PLAYIT_WORKDIR}/gamedata"
else
	case "${LANG%_*}" in
		('fr')
			message='Lʼarchive suivante nʼayant pas été fournie, le lanceur pour ce jeu nʼutilisera pas dʼicône spécifique : %s\n'
			message="$message"'Cette archive peut être téléchargée depuis %s\n'
		;;
		('en'|*)
			message='Due to the following archive missing, the game launcher will not use a specific icon: %s\n'
			message="$message"'This archive can be downloaded from %s\n'
		;;
	esac
	print_warning
	printf "$message" "$ARCHIVE_OPTIONAL_ICONS" "$ARCHIVE_OPTIONAL_ICONS_URL"
	printf '\n'
fi

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
set_standard_permissions "${PLAYIT_WORKDIR}/gamedata"
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
