#!/bin/sh
set -o errexit

###
# Copyright (c) 2018, Mopi
# Copyright (c) 2020, Igor Telmenko
# Copyright (c) 2021, Antoine Le Gonidec <vv221@dotslashplay.it>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Syberia
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220931.1

# Set game-specific variables

GAME_ID='syberia-1'
GAME_NAME='Syberia'

ARCHIVE_BASE_RU_2='setup_syberia_1.0.0_hotfix4_(russian)_(53936).exe'
ARCHIVE_BASE_RU_2_MD5='98308bdd7980d5d2804fed458816296c'
ARCHIVE_BASE_RU_2_TYPE='innosetup'
ARCHIVE_BASE_RU_2_PART1='setup_syberia_1.0.0_hotfix4_(russian)_(53936)-1.bin'
ARCHIVE_BASE_RU_2_PART1_MD5='79a2c6f522d812a034f263dea9ae1fa3'
ARCHIVE_BASE_RU_2_PART1_TYPE='innosetup'
ARCHIVE_BASE_RU_2_SIZE='1600000'
ARCHIVE_BASE_RU_2_VERSION='1.0.0-gog53936'
ARCHIVE_BASE_RU_2_URL='https://www.gog.com/game/syberia'

ARCHIVE_BASE_EN_2='setup_syberia_1.0.0_hotfix4_(53936).exe'
ARCHIVE_BASE_EN_2_MD5='d2a928c368926e6b5acb0007e86292c0'
ARCHIVE_BASE_EN_2_TYPE='innosetup'
ARCHIVE_BASE_EN_2_PART1='setup_syberia_1.0.0_hotfix4_(53936)-1.bin'
ARCHIVE_BASE_EN_2_PART1_MD5='20a068f18d692deddf517bd5def14903'
ARCHIVE_BASE_EN_2_PART1_TYPE='innosetup'
ARCHIVE_BASE_EN_2_SIZE='1600000'
ARCHIVE_BASE_EN_2_VERSION='1.0.0-gog53936'
ARCHIVE_BASE_EN_2_URL='https://www.gog.com/game/syberia'

ARCHIVE_BASE_FR_2='setup_syberia_1.0.0_hotfix4_(french)_(53936).exe'
ARCHIVE_BASE_FR_2_MD5='d4f6fb1f650a6e82b4456c2c1e2e2b8d'
ARCHIVE_BASE_FR_2_TYPE='innosetup'
ARCHIVE_BASE_FR_2_PART1='setup_syberia_1.0.0_hotfix4_(french)_(53936)-1.bin'
ARCHIVE_BASE_FR_2_PART1_MD5='b8544dbc5ea5d125b224a8a1008913a7'
ARCHIVE_BASE_FR_2_PART1_TYPE='innosetup'
ARCHIVE_BASE_FR_2_SIZE='1600000'
ARCHIVE_BASE_FR_2_VERSION='1.0.0-gog53936'
ARCHIVE_BASE_FR_2_URL='https://www.gog.com/game/syberia'

ARCHIVE_BASE_RU_1='setup_syberia_russian_1.0.0_hotfix3_(18946).exe'
ARCHIVE_BASE_RU_1_MD5='cdf5ac1869d57d139495a20102d5ffb4'
ARCHIVE_BASE_RU_1_TYPE='innosetup'
ARCHIVE_BASE_RU_1_SIZE='1600000'
ARCHIVE_BASE_RU_1_VERSION='1.0.0-gog18946'

ARCHIVE_BASE_EN_1='setup_syberia_1.0.0_hotfix3_(18946).exe'
ARCHIVE_BASE_EN_1_MD5='53d91df35a154584812d31b9ee353cb8'
ARCHIVE_BASE_EN_1_TYPE='innosetup'
ARCHIVE_BASE_EN_1_SIZE='1600000'
ARCHIVE_BASE_EN_1_VERSION='1.0.0-gog18946'

ARCHIVE_BASE_FR_1='setup_syberia_french_1.0.0_hotfix3_(18946).exe'
ARCHIVE_BASE_FR_1_MD5='41881248eefd53929bbaa97c1905a7fe'
ARCHIVE_BASE_FR_1_TYPE='innosetup'
ARCHIVE_BASE_FR_1_SIZE='1600000'
ARCHIVE_BASE_FR_1_VERSION='1.0.0-gog18946'

ARCHIVE_BASE_EN_0='setup_syberia_1.0.0_hotfix2_(17897).exe'
ARCHIVE_BASE_EN_0_MD5='d52b7a776df7659d7fda9995715468a0'
ARCHIVE_BASE_EN_0_TYPE='innosetup'
ARCHIVE_BASE_EN_0_SIZE='1600000'
ARCHIVE_BASE_EN_0_VERSION='1.0.0-gog17897'

ARCHIVE_BASE_FR_0='setup_syberia_french_1.0.0_hotfix2_(17897).exe'
ARCHIVE_BASE_FR_0_MD5='d8a956a47c1b186a4364eff56c8cecb6'
ARCHIVE_BASE_FR_0_TYPE='innosetup'
ARCHIVE_BASE_FR_0_SIZE='1600000'
ARCHIVE_BASE_FR_0_VERSION='1.0.0-gog17897'

CONTENT_PATH_DEFAULT='.'
ARCHIVE_DOC_L10N_FILES='
*.pdf
*.txt'
ARCHIVE_GAME_BIN_FILES='
dlls
*.dll
*.exe
*.ini
*/*.ini'
ARCHIVE_GAME_L10N_FILES='
sounds
splash
cmo/citstation.cmo
cmo/valreceptioninn.cmo
data/font_syberia?.dat
data/string.dat
data/animations/momo/mo_tcheque.nmo
video/an
video/*_hansanna.syb
video/*_hansannab.syb
video/c1_intro.syb
textures/ingame
textures/valreceptioninn'
ARCHIVE_GAME_DATA_FILES='
cmo
data
textures
video'
## Alternative inner path for old archives
CONTENT_PATH_DEFAULT_EN_1='app'
CONTENT_PATH_DEFAULT_FR_1='app'
CONTENT_PATH_DEFAULT_RU_1='app'
CONTENT_PATH_DEFAULT_EN_0='app'
CONTENT_PATH_DEFAULT_FR_0='app'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='game.exe'
APP_MAIN_ICON='syberia.exe'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine libGL.so.1"

# Localization

PACKAGES_LIST="PKG_L10N $PACKAGES_LIST"
PKG_L10N_ID="${GAME_ID}-l10n"
PKG_L10N_PROVIDE="$PKG_L10N_ID"
PKG_BIN_DEPS="$PKG_BIN_DEPS $PKG_L10N_ID"

## English

PKG_L10N_ID_EN="${PKG_L10N_ID}-en"
PKG_L10N_DESCRIPTION_EN='English localization'

## French

PKG_L10N_ID_FR="${PKG_L10N_ID}-fr"
PKG_L10N_DESCRIPTION_FR='French localization'

## Russian

PKG_L10N_ID_RU="${PKG_L10N_ID}-ru"
PKG_L10N_DESCRIPTION_RU='Russian localization'

# Use persistent storage for user data

CONFIG_FILES='./*.ini ./*/*.ini'
APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
saves:users/${USER}/Documents/Syberia Saves'
DATA_DIRS='./saves'

# Clean upgrade from packages generated with pre-20210716.5 game script

PKG_BIN_PROVIDE='syberia'
PKG_DATA_PROVIDE='syberia-data'

# Load common functions

target_version='2.15'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Create player.ini file if one is not already provided

PKG='PKG_BIN'
package_path=$(package_get_path "$PKG")
config_file="${package_path}${PATH_GAME}/player.ini"
if [ ! -e "$config_file" ]; then
	cat > "$config_file" <<- EOF
	800 600 16 0 BaseCMO.cmo
	EOF
fi

# Work around a crash on nvidia drivers
# cf. https://bugs.winehq.org/show_bug.cgi?id=43199
#     https://bugs.winehq.org/show_bug.cgi?id=44009

PKG='PKG_BIN'
package_path=$(package_get_path "$PKG")
registry_file='registry-tweaks/no-xvidmode.reg'
APP_REGEDIT="$APP_REGEDIT $registry_file"
registry_file_path="${package_path}${PATH_GAME}/${registry_file}"
registry_file_directory=$(dirname "$registry_file_path")
mkdir --parents "$registry_file_directory"
cat > "$registry_file_path" << 'EOF'
Windows Registry Editor Version 5.00

[HKEY_CURRENT_USER\Software\Wine\X11 Driver]
"UseXVidMode"="N"
EOF

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
