#!/bin/sh
set -o errexit

###
# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# The Dark Eye: Chains of Satinav
# build native Linux packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20211125.6

# Set game-specific variables

GAME_ID='the-dark-eye-chains-of-satinav'
GAME_NAME='The Dark Eye: Chains of Satinav'

ARCHIVE_BASE_1='setup_the_dark_eye_chains_of_satinav_2.0.0.4.exe'
ARCHIVE_BASE_1_MD5='022a59739b9d7b16f036fb2fecd5bca2'
ARCHIVE_BASE_1_TYPE='innosetup'
ARCHIVE_BASE_1_PART1='setup_the_dark_eye_chains_of_satinav_2.0.0.4-1.bin'
ARCHIVE_BASE_1_PART1_MD5='aa50ac1bf998b7d945f58b6104f58298'
ARCHIVE_BASE_1_PART1_TYPE='innosetup'
ARCHIVE_BASE_1_PART2='setup_the_dark_eye_chains_of_satinav_2.0.0.4-2.bin'
ARCHIVE_BASE_1_PART2_MD5='6748d3208d3c59f91cce0de4e6e56af7'
ARCHIVE_BASE_1_PART2_TYPE='innosetup'
ARCHIVE_BASE_1_PART3='setup_the_dark_eye_chains_of_satinav_2.0.0.4-3.bin'
ARCHIVE_BASE_1_PART3_MD5='4c1208642ea83d7dde6e90ac3ce885fb'
ARCHIVE_BASE_1_PART3_TYPE='innosetup'
ARCHIVE_BASE_1_PART4='setup_the_dark_eye_chains_of_satinav_2.0.0.4-4.bin'
ARCHIVE_BASE_1_PART4_MD5='284a6c2e37897e44a69fac6f8c0971e0'
ARCHIVE_BASE_1_PART4_TYPE='innosetup'
ARCHIVE_BASE_1_SIZE='5500000'
ARCHIVE_BASE_1_VERSION='1.0-gog2.0.0.4'
ARCHIVE_BASE_1_URL='https://www.gog.com/game/the_dark_eye_chains_of_satinav'

ARCHIVE_BASE_0='setup_the_dark_eye_chains_of_satinav_2.0.0.4.exe'
ARCHIVE_BASE_0_MD5='d1c375ba007b7ed6574a16cca823258a'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1='setup_the_dark_eye_chains_of_satinav_2.0.0.4-1.bin'
ARCHIVE_BASE_0_PART1_MD5='0c9ea69bdb3e2c66d13f2d27812279b6'
ARCHIVE_BASE_0_PART1_TYPE='innosetup'
ARCHIVE_BASE_0_PART2='setup_the_dark_eye_chains_of_satinav_2.0.0.4-2.bin'
ARCHIVE_BASE_0_PART2_MD5='d87f0693751554c1d382f770202e8c45'
ARCHIVE_BASE_0_PART2_TYPE='innosetup'
ARCHIVE_BASE_0_PART3='setup_the_dark_eye_chains_of_satinav_2.0.0.4-3.bin'
ARCHIVE_BASE_0_PART3_MD5='ef662b59635829ed4505f6d7272e4bb7'
ARCHIVE_BASE_0_PART3_TYPE='innosetup'
ARCHIVE_BASE_0_PART4='setup_the_dark_eye_chains_of_satinav_2.0.0.4-4.bin'
ARCHIVE_BASE_0_PART4_MD5='555d8af3bb598ed4c481e3e3d63b0221'
ARCHIVE_BASE_0_PART4_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='5500000'
ARCHIVE_BASE_0_VERSION='1.0-gog2.0.0.4'

ARCHIVE_DOC_PATH='app/documents/licenses'
ARCHIVE_DOC_FILES='*'

ARCHIVE_GAME_BIN_PATH='app'
ARCHIVE_GAME_BIN_FILES='
*.dll
satinav.exe
visionaireconfigurationtool.exe
config.ini'

ARCHIVE_GAME_DATA_PATH='app'
ARCHIVE_GAME_DATA_FILES='
*.jpg
*.vis
*.xml
characters
lua
scenes
videos'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='satinav.exe'
APP_MAIN_ICON='satinav.exe'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine"

# Use persistent storage for user data

APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
userdata:users/${USER}/Local Settings/Application Data/Daedalic Entertainment/Satinav'
CONFIG_FILES='userdata/config.ini'
DATA_DIRS='userdata/Savegames'

# Load common functions

target_version='2.14'

if [ -z "$PLAYIT_LIB2" ]; then
	for path in \
		"$PWD" \
		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
		'/usr/local/share/games/play.it' \
		'/usr/local/share/play.it' \
		'/usr/share/games/play.it' \
		'/usr/share/play.it'
	do
		if [ -e "${path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=play.it-2/lib/libplayit2.sh
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Delete temporary files

rm --recursive "$PLAYIT_WORKDIR/gamedata"

# Include game icons

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
