#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# The Guild 2 Renaissance
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220628.2

GAME_ID='the-guild-2-renaissance'
GAME_NAME='The Guild 2 Renaissance'

ARCHIVE_BASE_0='setup_the_guild2_renaissance_2.2.0.5.exe'
ARCHIVE_BASE_0_MD5='86389c3154c2ea6ef3b072278f1e9c6c'
ARCHIVE_BASE_0_TYPE='rar' # This is actually a InnoSetup installer based on a RAR archive
ARCHIVE_BASE_0_PART1='setup_the_guild2_renaissance_2.2.0.5-1.bin'
ARCHIVE_BASE_0_PART1_MD5='ae4c17c8e3793befeec8b9a16e4f2b0c'
ARCHIVE_BASE_0_PART1_TYPE='rar'
ARCHIVE_BASE_0_SIZE='3800000'
ARCHIVE_BASE_0_VERSION='4.21-gog2.2.0.5'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/the_guild_2_renaissance'

CONTENT_PATH_DEFAULT='game'
ARCHIVE_DOC_DATA_FILES='
manual.pdf
*.txt'
ARCHIVE_GAME_BIN_FILES='
dbghelp.dll
fmod.dll
guildii.exe
mfc71.dll
modlauncher.exe
msvcp71.dll
msvcr71.dll
stlport.5.0.dll
stlportd.5.0.dll
wmencoderen.exe'
ARCHIVE_GAME_DATA_FILES='
camerapaths
*.raw
db
gui
*.url
mods
movie
msx
objects
particles
resource
savegames
scenes
scripts
sfx
shader
shots
sim_commands.dat
textures
worlds'
ARCHIVE_CONFIG_DATA_PATH='support/app'
ARCHIVE_CONFIG_DATA_FILES='
config.ini
input.ini'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='guildii.exe'
APP_MAIN_ICON='guildii.exe'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine"

# Set up a WINE virtual desktop on first launch, using the current desktop resolution

PKG_BIN_DEPS="$PKG_BIN_DEPS winetricks xrandr sed"
sed_expression='s/.*primary.* ([0-9]+x[0-9]+).*/\1/p'
sed_options="--regexp-extended --silent --expression='$sed_expression'"
APP_WINETRICKS="$APP_WINETRICKS vd=\$(LANG=C xrandr | sed $sed_options)"

# Use persistent storage for user data

CONFIG_FILES='./*.ini'

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE_PART1'
tolower "${PLAYIT_WORKDIR}/gamedata"
PKG='PKG_DATA'
organize_data 'CONFIG_DATA' "$PATH_GAME"
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
