#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# The Guild 2
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220708.1

GAME_ID='the-guild-2'
GAME_NAME='The Guild 2'

ARCHIVE_BASE_0='setup_the_guild2_2.0.0.4.exe'
ARCHIVE_BASE_0_MD5='2b14191f4831b3486e95d52245d6cc64'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='2400000'
ARCHIVE_BASE_0_VERSION='1.4-gog2.0.0.4'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/the_guild_2'

CONTENT_PATH_DEFAULT='app'
ARCHIVE_DOC_DATA_FILES='
*.pdf
*.txt'
ARCHIVE_GAME_BIN_FILES='
*.dll
*.exe
*.ini'
ARCHIVE_GAME_DATA_FILES='
*.dat
camerapaths
db
editor
gui
movie
msx
objects
particles
resource
savegames
scenes
scripts
sfx
shader
shots
textures
worlds'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='guildii.exe'
APP_MAIN_ICON='guildii.exe'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine"

# Use persistent storage for user data

DATA_FILES='*.ini'

# Set up a WINE virtual desktop on first launch, using the current desktop resolution

PKG_BIN_DEPS="$PKG_BIN_DEPS winetricks xrandr sed"
sed_expression='s/.*primary.* ([0-9]+x[0-9]+).*/\1/p'
sed_options="--regexp-extended --silent --expression='$sed_expression'"
APP_WINETRICKS="$APP_WINETRICKS vd=\$(LANG=C xrandr | sed $sed_options)"

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Disable intro movie

PKG='PKG_BIN'
package_path=$(package_get_path "$PKG")
ini_file="${package_path}${PATH_GAME}/config.ini"

ini_field='SplashScreen'
ini_value='0'
sed_expression="s/^${ini_field}=.*$/${ini_field}=${ini_value}/"

sed --in-place --expression="$sed_expression" "$ini_file"

# Include game icon

PKG='PKG_BIN'
icons_get_from_package 'APP_MAIN'
icons_move_to 'PKG_DATA'

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
