#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Mopi
# SPDX-FileCopyrightText: © 2018 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# The Last Tinker
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220128.9

# Set game-specific variables

GAME_ID='the-last-tinker'
GAME_NAME='The Last Tinker: City of Colors'

ARCHIVE_BASE_LINUX_0='last_tinker_city_of_colors_the_en_23_02_2018_18902.sh'
ARCHIVE_BASE_LINUX_0_MD5='d0dbfac723aee309869c2404d88b4eb4'
ARCHIVE_BASE_LINUX_0_TYPE='mojosetup'
ARCHIVE_BASE_LINUX_0_SIZE='2100000'
ARCHIVE_BASE_LINUX_0_VERSION='2018.02.23-gog18902'
ARCHIVE_BASE_LINUX_0_URL='https://www.gog.com/game/the_last_tinker_city_of_colors'

ARCHIVE_BASE_WINDOWS_1='setup_the_last_tinker_-_city_of_colors_23.02.2018_(18831).exe'
ARCHIVE_BASE_WINDOWS_1_MD5='ec303722fba022e2b1d04f69091213d9'
ARCHIVE_BASE_WINDOWS_1_TYPE='innosetup'
ARCHIVE_BASE_WINDOWS_1_PART1='setup_the_last_tinker_-_city_of_colors_23.02.2018_(18831)-1.bin'
ARCHIVE_BASE_WINDOWS_1_PART1_MD5='91e843b4d7be0d842bf3dc1f9930f11d'
ARCHIVE_BASE_WINDOWS_1_PART1_TYPE='innosetup'
ARCHIVE_BASE_WINDOWS_1_SIZE='2000000'
ARCHIVE_BASE_WINDOWS_1_VERSION='2018.02.23-gog18831'
ARCHIVE_BASE_WINDOWS_1_URL='https://www.gog.com/game/the_last_tinker_city_of_colors'

ARCHIVE_BASE_WINDOWS_0='setup_the_last_tinker_2.0.0.2.exe'
ARCHIVE_BASE_WINDOWS_0_MD5='7afa966efb4beb5535e19f2d69b245ae'
ARCHIVE_BASE_WINDOWS_0_TYPE='innosetup'
ARCHIVE_BASE_WINDOWS_0_SIZE='2100000'
ARCHIVE_BASE_WINDOWS_0_VERSION='1.0-gog2.0.0.2'

UNITY3D_NAME='the last tinker'

CONTENT_PATH_DEFAULT_WINDOWS='app'
CONTENT_PATH_DEFAULT_LINUX='data/noarch/game'
ARCHIVE_GAME_BIN_FILES_WINDOWS='
*.dll
*.exe
the?last?tinker_data/mono'
ARCHIVE_GAME_BIN_FILES_LINUX='
libsteam_api.so
libSteamworksNative.so
the?last?tinker.x86
the?last?tinker_Data/Mono'
ARCHIVE_GAME_DATA_FILES_WINDOWS='
the?last?tinker_data'
ARCHIVE_GAME_DATA_FILES_LINUX='
the?last?tinker_Data'

APP_MAIN_TYPE_WINDOWS='wine'
APP_MAIN_EXE_WINDOWS="${UNITY3D_NAME}.exe"
APP_MAIN_ICON_WINDOWS="${UNITY3D_NAME}.exe"

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_ID_LINUX="${PKG_DATA_ID}-linux"
PKG_DATA_ID_WINDOWS="${PKG_DATA_ID}-windows"
PKG_DATA_PROVIDE="$PKG_DATA_ID"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ID="$GAME_ID"
PKG_BIN_ID_LINUX="${PKG_BIN_ID}-linux"
PKG_BIN_ID_WINDOWS="${PKG_BIN_ID}-windows"
PKG_BIN_PROVIDE="$PKG_BIN_ID"
PKG_BIN_ARCH='32'
PKG_BIN_DEPS_WINDOWS="$PKG_DATA_ID_WINDOWS wine"
PKG_BIN_DEPS_LINUX="$PKG_DATA_ID_LINUX libc.so.6 libstdc++.so.6 libGL.so.1 libgtk-x11-2.0.so.0 libGLU.so.1 libX11.so.6 libgdk-x11-2.0.so.0 libgdk_pixbuf-2.0.so.0 libgobject-2.0.so.0 libglib-2.0.so.0 xcursor freetype"
PKG_BIN_DEPS_ARCH_LINUX='lib32-libxext lib32-atk lib32-pango lib32-cairo lib32-fontconfig'
PKG_BIN_DEPS_DEB_LINUX='libxext6, libatk1.0-0, libpangoft2-1.0-0, libpangocairo-1.0-0, libcairo2, libpango-1.0-0, libfontconfig1'
PKG_BIN_DEPS_GENTOO_LINUX='x11-libs/libXext[abi_x86_32] dev-libs/atk[abi_x86_32] x11-libs/pango[abi_x86_32] x11-libs/cairo[abi_x86_32] media-libs/fontconfig[abi_x86_32]'

# Load common functions

target_version='2.15'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Include game icon

case "$ARCHIVE" in
	('ARCHIVE_BASE_LINUX_'*)
		PKG='PKG_DATA'
		icons_get_from_package 'APP_MAIN'
	;;
	('ARCHIVE_BASE_WINDOWS_'*)
		PKG='PKG_BIN'
		icons_get_from_package 'APP_MAIN'
		icons_move_to 'PKG_DATA'
	;;
esac

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
APP_MAIN_EXE=$(get_context_specific_value 'archive' 'APP_MAIN_EXE')
APP_MAIN_TYPE=$(get_context_specific_value 'archive' 'APP_MAIN_TYPE')
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
