#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Mopi
# SPDX-FileCopyrightText: © 2018 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# The Longest Journey
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220419.1

# Set game-specific variables

GAME_ID='the-longest-journey'
GAME_NAME='The Longest Journey'

ARCHIVE_BASE_1='setup_the_longest_journey_142_lang_update_(24607).exe'
ARCHIVE_BASE_1_MD5='540b2e016ab90dd509c53fc7df4397fd'
ARCHIVE_BASE_1_TYPE='innosetup'
ARCHIVE_BASE_1_PART1='setup_the_longest_journey_142_lang_update_(24607)-1.bin'
ARCHIVE_BASE_1_PART1_MD5='efb1cd664b1cbbd29d0e641ad2f81e05'
ARCHIVE_BASE_1_PART1_TYPE='innosetup'
ARCHIVE_BASE_1_SIZE='1900000'
ARCHIVE_BASE_1_VERSION='142-gog24607'
ARCHIVE_BASE_1_URL='https://www.gog.com/game/the_longest_journey'

ARCHIVE_BASE_0='setup_the_longest_journey_2.0.0.12.exe'
ARCHIVE_BASE_0_MD5='89b3cae144856579ed5fee10ecc76154'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='1900000'
ARCHIVE_BASE_0_VERSION='142-gog2.0.0.12'

CONTENT_PATH_DEFAULT='.'
CONTENT_PATH_DEFAULT_0='app'
ARCHIVE_DOC_DATA_FILES='
*.txt
*.pdf
*.html
tlj_faq_files'
ARCHIVE_GAME_BIN_WINE_FILES='
tljregfix.exe
*.dll'
ARCHIVE_GAME_DATA_FILES='
??
*.ini
game.exe
fonts
global
static
station_fix
x.xarc'
ARCHIVE_GAME0_DATA_PATH='app'
ARCHIVE_GAME0_DATA_FILES='
data1.tag'

APP_WINE_TYPE='wine'
APP_WINE_EXE='game.exe'
APP_WINE_ICON='game.exe'

APP_SCUMMVM_TYPE='scummvm'
APP_SCUMMVM_SCUMMID='tlj'

PACKAGES_LIST='PKG_BIN_SCUMMVM PKG_BIN_WINE PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ID="$GAME_ID"
PKG_BIN_DEPS="$PKG_DATA_ID"

PKG_BIN_SCUMMVM_ID="${PKG_BIN_ID}-scummvm"
PKG_BIN_SCUMMVM_PROVIDE="$PKG_BIN_ID"
PKG_BIN_SCUMMVM_DEPS="$PKG_BIN_DEPS scummvm"

PKG_BIN_WINE_ID="${PKG_BIN_ID}-wine"
PKG_BIN_WINE_PROVIDE="$PKG_BIN_ID"
PKG_BIN_WINE_ARCH='32'
PKG_BIN_WINE_DEPS="$PKG_BIN_DEPS wine"

# Use persistent storage for user data
# WINE only

DATA_DIRS='./save'

# Apply registry fix
# WINE only

APP_WINE_PRERUN="$APP_WINE_PRERUN"'
# Apply registry fix
if [ ! -e regfix_applied ]; then
	wine tljregfix.exe
	touch regfix_applied
fi'

# Load common functions

target_version='2.15'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Include game icon

PKG='PKG_DATA'
icons_get_from_package 'APP_WINE'

# Write launchers

PKG='PKG_BIN_SCUMMVM'
launchers_write 'APP_SCUMMVM'

PKG='PKG_BIN_WINE'
### Work around the binary presence check
package_path=$(package_get_path "$PKG")
application_exe=$(application_exe 'APP_WINE')
binary_path="${package_path}${PATH_GAME}/${application_exe}"
binary_directory=$(dirname "$binary_path")
mkdir --parents "$binary_directory"
touch "$binary_path"
launchers_write 'APP_WINE'
rm "$binary_path"
rmdir --parents --ignore-fail-on-non-empty "$binary_directory"

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

printf '\n'
printf 'ScummVM:'
print_instructions 'PKG_BIN_SCUMMVM' 'PKG_DATA'
printf 'WINE:'
print_instructions 'PKG_BIN_WINE' 'PKG_DATA'

exit 0
