#!/bin/sh
set -o errexit

###
# Copyright © 2015-2022, Antoine Le Gonidec <vv221@dotslashplay.it>
# Copyright © 2016-2022, Mopi
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# The Stanley Parable
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220112.2

# Set game-specific variables

GAME_ID='the-stanley-parable'
GAME_NAME='The Stanley Parable'

ARCHIVE_BASE_0='The_Stanley_Parable_Setup.tar'
ARCHIVE_BASE_0_MD5='10a98d7fb93017eb666281bf2d3da28d'
ARCHIVE_BASE_0_SIZE='2100000'
ARCHIVE_BASE_0_VERSION='1.0-humble161007'
ARCHIVE_BASE_0_URL='https://www.humblebundle.com/store/the-stanley-parable'

CONTENT_PATH_DEFAULT='data'
ARCHIVE_DOC_DATA_FILES='
thirdpartylegalnotices.doc'
ARCHIVE_GAME_BIN_FILES='
thestanleyparable/bin
stanley_linux
bin/base.fgd
bin/bsppack.so
bin/crashhandler.so
bin/customcolors.dat
bin/datacache.so
bin/dedicated.so
bin/dxsupport.cfg
bin/dxsupport_episodic.cfg
bin/dxsupport_mac.cfg
bin/engine.so
bin/filesystem_stdio.so
bin/GameConfig.txt
bin/halflife2.fgd
bin/inputsystem.so
bin/launcher.so
bin/libsteam_api_linux.so
bin/libsteam_api.so
bin/libsteam.so
bin/libtcmalloc_minimal.so.4
bin/libtier0.so
bin/libtogl.so
bin/libvpx.so.1
bin/libvpx.so.1.0
bin/libvpx.so.1.0.0
bin/libvstdlib.so
bin/localize.so
bin/materialsystem.so
bin/portal2.fgd
bin/portal.fgd
bin/puzzlemaker_dll.so
bin/scenefilecache.so
bin/shaderapidx9.so
bin/shaderapiempty.so
bin/soundemittersystem.so
bin/stdshader_dx9.so
bin/studiorender.so
bin/valve_avi.so
bin/vaudio_miles.so
bin/vaudio_speex.so
bin/vbsp_linux
bin/vbsp_osx
bin/vgui2.so
bin/vguimatsurface.so
bin/vidcfg.bin
bin/vphysics.so
bin/vrad_dll.so
bin/vrad_linux
bin/vrad_osx
bin/vscript.so
bin/vvis_dll.so
bin/vvis_linux
bin/vvis_osx'
ARCHIVE_GAME_DATA_FILES='
platform
stanley.png
thestanleyparable'

APP_MAIN_TYPE='native'
APP_MAIN_EXE='stanley_linux'
APP_MAIN_LIBS='bin'
APP_MAIN_ICON='stanley.png'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID libc.so.6 libopenal.so.1 libSDL2-2.0.so.0 freetype"
PKG_BIN_DEPS_ARCH='lib32-fontconfig lib32-util-linux'
PKG_BIN_DEPS_DEB='libfontconfig1, libuuid1'
PKG_BIN_DEPS_GENTOO='media-libs/fontconfig[abi_x86_32] sys-apps/util-linux[abi_x86_32]'

# Use persistent storage for user data

CONFIG_DIRS='thestanleyparable/cfg'
DATA_DIRS='thestanleyparable/save'
DATA_FILES='thestanleyparable/stats.vdf'

# Load common functions

target_version='2.15'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
(
	ARCHIVE='ARCHIVE_INNER_1'
	ARCHIVE_INNER_1="${PLAYIT_WORKDIR}/gamedata/The Stanley Parable Setup"
	ARCHIVE_INNER_1_TYPE='mojosetup'
	extract_data_from "$ARCHIVE_INNER_1"
	rm "$ARCHIVE_INNER_1"
)
(
	cd "${PLAYIT_WORKDIR}/gamedata"
	rm --recursive --force 'guis' 'meta' 'scripts'
)
(
	ARCHIVE='ARCHIVE_INNER_2'
	ARCHIVE_INNER_2="${PLAYIT_WORKDIR}/gamedata/data/tsp.tar"
	extract_data_from "$ARCHIVE_INNER_2"
	rm "$ARCHIVE_INNER_2"
)
set_standard_permissions "$PLAYIT_WORKDIR/gamedata"
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Include game icon

PKG='PKG_DATA'
icons_get_from_package 'APP_MAIN'

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
