#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2023 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# The Swords of Ditto
# send your bug reports to contact@dotslashplay.it
###

script_version=20230815.1

GAME_ID='the-swords-of-ditto'
GAME_NAME='The Swords of Ditto: Mormoʼs Curse'

ARCHIVE_BASE_0='the_swords_of_ditto_1_17_02_204_30316.sh'
ARCHIVE_BASE_0_MD5='9191f474d17f2744c1d6f9153be74780'
ARCHIVE_BASE_0_SIZE='1200000'
ARCHIVE_BASE_0_VERSION='1.17.02.204'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/the_swords_of_ditto'

CONTENT_PATH_DEFAULT='data/noarch/game'
CONTENT_GAME_BIN_FILES='
The_Swords_of_Ditto'
CONTENT_GAME_DATA_FILES='
assets'

APP_MAIN_EXE='The_Swords_of_Ditto'
APP_MAIN_ICON='assets/icon.png'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libcurl.so.4
libdl.so.2
libgcc_s.so.1
libGL.so.1
libGLU.so.1
libm.so.6
libopenal.so.1
libpthread.so.0
librt.so.1
libstdc++.so.6
libX11.so.6
libXext.so.6
libXrandr.so.2
libXxf86vm.so.1
libz.so.1'

# Load common functions

target_version='2.25'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Ensure availability of OpenSSL 1.1 libraries

ARCHIVE_REQUIRED_OPENSSL='openssl_1.1.1n.tar.xz'
ARCHIVE_REQUIRED_OPENSSL_URL='https://downloads.dotslashplay.it/resources/openssl1.1/'
ARCHIVE_REQUIRED_OPENSSL_MD5='dade7a54b213be8ac6e0bc2b571570cc'
CONTENT_OPENSSL_PATH='x86_64-linux-gnu'
CONTENT_OPENSSL_FILES='
libcrypto.so.1.1
libssl.so.1.1'
archive_initialize_required \
	'ARCHIVE_OPENSSL' \
	'ARCHIVE_REQUIRED_OPENSSL'
archive_extraction 'ARCHIVE_OPENSSL'
content_inclusion 'OPENSSL' 'PKG_BIN' "$(path_libraries)"
rm --recursive "${PLAYIT_WORKDIR}/gamedata"
PKG_BIN_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES
libc.so.6
libdl.so.2
libpthread.so.0"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
