#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2018 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# The Westport Independent
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220628.1

GAME_ID='the-westport-independent'
GAME_NAME='The Westport Independent'

ARCHIVE_BASE_0='gog_the_westport_independent_2.0.0.1.sh'
ARCHIVE_BASE_0_MD5='7032059f085e94f52444e9bf4ed0195c'
ARCHIVE_BASE_0_TYPE='mojosetup'
ARCHIVE_BASE_0_SIZE='130000'
ARCHIVE_BASE_0_VERSION='1.0.0-gog2.0.0.1'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/westport_independent_the'

CONTENT_PATH_DEFAULT='data/noarch/game/linux32'
ARCHIVE_DOC_DATA_FILES='
*.txt'
ARCHIVE_GAME_BIN32_FILES='
the_westport_independent'
ARCHIVE_GAME_DATA_FILES='
config.json
assets'
ARCHIVE_GAME_BIN64_PATH="${CONTENT_PATH_DEFAULT}/../linux64"
ARCHIVE_GAME_BIN64_FILES='
the_westport_independent'

APP_MAIN_TYPE='native'
APP_MAIN_EXE='the_westport_independent'
APP_MAIN_ICON='data/noarch/support/icon.png'

PACKAGES_LIST='PKG_BIN32 PKG_BIN64 PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN32_ARCH='32'
PKG_BIN32_DEPS="$PKG_DATA_ID libc.so.6 libstdc++.so.6 libGL.so.1 libopenal.so.1"

PKG_BIN64_ARCH='64'
PKG_BIN64_DEPS="$PKG_BIN32_DEPS"

# Use persistent storage for user data

CONFIG_FILES='./config.json'

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Include icons from the optional archive if it is provided

ARCHIVE_OPTIONAL_ICONS='the-westport-independent_icons.tar.gz'
ARCHIVE_OPTIONAL_ICONS_MD5='054b51fe4c02f256b8130b40e93d28ae'
ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/resources/the-westport-independant/'

ARCHIVE_ICONS_PATH='.'
ARCHIVE_ICONS_FILES='*'

archive_initialize_optional \
	'ARCHIVE_ICONS' \
	'ARCHIVE_OPTIONAL_ICONS'
if [ -n "$ARCHIVE_ICONS" ]; then
	PKG='PKG_DATA'
	(
		ARCHIVE='ARCHIVE_ICONS'
		extract_data_from "$ARCHIVE_ICONS"
	)
	organize_data 'ICONS' "$PATH_ICON_BASE"
	rm --recursive "${PLAYIT_WORKDIR}/gamedata"
else
	case "${LANG%_*}" in
		('fr')
			message='Lʼarchive suivante nʼayant pas été fournie, lʼicône spécifique à GOG sera utilisée au lieu de lʼicône originale : %s\n'
			message="$message"'Cette archive peut être téléchargée depuis %s\n'
		;;
		('en'|*)
			message='Due to the following archive missing, the GOG-specific icon will be used instead of the original one: %s\n'
			message="$message"'This archive can be downloaded from %s\n'
		;;
	esac
	print_warning
	printf "$message" "$ARCHIVE_OPTIONAL_ICONS" "$ARCHIVE_OPTIONAL_ICONS_URL"
	printf '\n'
fi

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Include GOG-specific icon if the optional archive has not been provided.

if [ -z "$ARCHIVE_ICONS" ]; then
	PKG='PKG_DATA'
	icons_get_from_workdir 'APP_MAIN'
fi

# Delete temporary files

rm --recursive "$PLAYIT_WORKDIR/gamedata"

# Write launchers

for PKG in 'PKG_BIN32' 'PKG_BIN64'; do
	launchers_write 'APP_MAIN'
done

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
