#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Mopi
# SPDX-FileCopyrightText: © 2017 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# The Whispered World
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220628.1

GAME_ID='the-whispered-world'
GAME_NAME='The Whispered World'

ARCHIVES_LIST='ARCHIVE_BASE_0'

ARCHIVE_BASE_0='gog_the_whispered_world_special_edition_2.0.0.1.sh'
ARCHIVE_BASE_0_MD5='485368f130f2d82f564a0159cd497437'
ARCHIVE_BASE_0_TYPE='mojosetup'
ARCHIVE_BASE_0_SIZE='2200000'
ARCHIVE_BASE_0_VERSION='3.2.0418-gog2.0.0.1'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/the_whispered_world_special_edition'


CONTENT_PATH_DEFAULT='data/noarch/game'
ARCHIVE_GAME_BIN_FILES='
TWWSE
config.ini
libs64'
ARCHIVE_GAME_SCENES_FILES='
scenes'
ARCHIVE_GAME_VIDEO_FILES='
videos'
ARCHIVE_GAME_DATA_FILES='
characters
data.vis
lua'
ARCHIVE_DOC_DATA_PATH="${CONTENT_PATH_DEFAULT}/documents/licenses"
ARCHIVE_DOC_DATA_FILES='*'

APP_MAIN_TYPE='native'
APP_MAIN_EXE='TWWSE'
APP_MAIN_LIBS='libs64'
APP_MAIN_ICON='data/noarch/support/icon.png'

PACKAGES_LIST='PKG_SCENES PKG_VIDEO PKG_DATA PKG_BIN'

PKG_SCENES_ID="${GAME_ID}-scenes"
PKG_SCENES_DESCRIPTION='scenes'

PKG_VIDEO_ID="${GAME_ID}-videos"
PKG_VIDEO_DESCRIPTION='videos'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_SCENES_ID $PKG_VIDEO_ID $PKG_DATA_ID libGL.so.1 libopenal.so.1"

# Use persistent storage for user data

CONFIG_FILES='./config.ini'

# Create required directory for saved games storage

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
# Create required directory for saved games storage
mkdir --parents "$HOME/.local/share/Daedalic Entertainment GmbH/The Whispered World Special Edition/Savegames"'

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Include icons from the optional archive if it is provided

ARCHIVE_OPTIONAL_ICONS='the-whispered-world_icons.tar.gz'
ARCHIVE_OPTIONAL_ICONS_MD5='3ec301bf71cf279aa8de91c136e16388'
ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/resources/the-whispered-world/'

ARCHIVE_ICONS_PATH='.'
ARCHIVE_ICONS_FILES='16x16 32x32 48x48 256x256'

archive_initialize_optional \
	'ARCHIVE_ICONS' \
	'ARCHIVE_OPTIONAL_ICONS'
if [ -n "$ARCHIVE_ICONS" ]; then
	PKG='PKG_DATA'
	(
		ARCHIVE='ARCHIVE_ICONS'
		extract_data_from "$ARCHIVE_ICONS"
	)
	organize_data 'ICONS' "$PATH_ICON_BASE"
	rm --recursive "${PLAYIT_WORKDIR}/gamedata"
else
	case "${LANG%_*}" in
		('fr')
			message='Lʼarchive suivante nʼayant pas été fournie, lʼicône spécifique à GOG sera utilisée au lieu de lʼicône originale : %s\n'
			message="$message"'Cette archive peut être téléchargée depuis %s\n'
		;;
		('en'|*)
			message='Due to the following archive missing, the GOG-specific icon will be used instead of the original one: %s\n'
			message="$message"'This archive can be downloaded from %s\n'
		;;
	esac
	print_warning
	printf "$message" "$ARCHIVE_OPTIONAL_ICONS" "$ARCHIVE_OPTIONAL_ICONS_URL"
	printf '\n'
fi

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Include GOG-specific icon if the optional archive has not been provided.

if [ -z "$ARCHIVE_ICONS" ]; then
	PKG='PKG_DATA'
	icons_get_from_workdir 'APP_MAIN'
fi

# Delete temporary files

rm --recursive "$PLAYIT_WORKDIR/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
