#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2019 BetaRays
# SPDX-FileCopyrightText: © 2020 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# The Witcher 1
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220808.2

GAME_ID='the-witcher-1'
GAME_NAME='The Witcher'

ARCHIVE_BASE_0='setup_the_witcher_enhanced_edition_1.5_(a)_(10712).exe'
ARCHIVE_BASE_0_MD5='2440cfb5fb4890ff4b9bc4b88b434d38'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1='setup_the_witcher_enhanced_edition_1.5_(a)_(10712)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='e530a1a2e86094740b45a14f63260804'
ARCHIVE_BASE_0_PART2='setup_the_witcher_enhanced_edition_1.5_(a)_(10712)-2.bin'
ARCHIVE_BASE_0_PART2_MD5='fb3a478bcb6e4702e1e8d392cb55391d'
ARCHIVE_BASE_0_PART3='setup_the_witcher_enhanced_edition_1.5_(a)_(10712)-3.bin'
ARCHIVE_BASE_0_PART3_MD5='2df8369af401815a736f5d88f85fbf8d'
ARCHIVE_BASE_0_SIZE='15000000'
ARCHIVE_BASE_0_VERSION='1.5.726-gog10712'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/the_witcher'

CONTENT_PATH_DEFAULT='app'
ARCHIVE_DOC_DATA_FILES='
manual.pdf
readme.rtf
release.txt'
ARCHIVE_GAME_BIN_FILES='
*.exe
installed
thewitchergdf.dll
launcher
register
system'
ARCHIVE_GAME_VOICES_FILES='
data/voices_*.bif'
ARCHIVE_GAME_DATA_FILES='
data'
ARCHIVE_ADDONS_PATH="${CONTENT_PATH_DEFAULT}/__support/add/the witcher"
ARCHIVE_ADDONS_FILES='
*'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='system/witcher.exe'
APP_MAIN_ICON='system/witcher.exe'

PACKAGES_LIST='PKG_BIN PKG_VOICES PKG_DATA'

PKG_VOICES_ID="${GAME_ID}-voices"
PKG_VOICES_DESCRIPTION='voices'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'
PKG_DATA_DEPS="$PKG_VOICES_ID"

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine libGL.so.1 xcursor"

# Use persistent storage for user data

APP_WINE_LINK_DIRS='
saves:users/${USER}/Documents/The Witcher/saves'
USER_PERSISTENT_DIRECTORIES='
saves'
WINE_REGEDIT_PERSISTENT_KEYS='
HKEY_CURRENT_USER\Software\CD Projekt RED\Witcher\Settings
HKEY_CURRENT_USER\Software\CD Projekt RED\Witcher\Bindings'

# Work around texture display issue
# cf. https://bugs.winehq.org/show_bug.cgi?id=46553

APP_WINETRICKS="$APP_WINETRICKS d3dx9_35"
PKG_BIN_DEPS="$PKG_BIN_DEPS winetricks"

# Include "Enhanced Edition" add-ons

APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
# Include "Enhanced Edition" add-ons
if [ ! -e "$WINEPREFIX/drive_c/users/Public/Documents/the witcher" ]; then
	mkdir --parents "$WINEPREFIX/drive_c/users/Public/Documents/the witcher"
	ln --symbolic "$PATH_GAME"/addons/* "$WINEPREFIX/drive_c/users/Public/Documents/the witcher"
fi'

# Set required registry keys

install_folder="C:\\\\${GAME_ID}\\\\"
registry_dump_init_file='registry-dumps/init.reg'
registry_dump_init_content='Windows Registry Editor Version 5.00

[HKEY_LOCAL_MACHINE\Software\CD Projekt Red\The Witcher]
"InstallFolder"="'"${install_folder}"'"
"IsDjinniInstalled"=dword:00000001
"Language"="3"
"RegionVersion"="WE"'
## Work around invisible models and flickering
## cf. https://bugs.winehq.org/show_bug.cgi?id=34052
registry_dump_init_content="$registry_dump_init_content"'

[HKEY_CURRENT_USER\Software\Wine\Direct3D]
"CheckFloatConstants"="enabled"'
ARCHIVE_GAME_BIN_FILES="$ARCHIVE_GAME_BIN_FILES
$registry_dump_init_file"
APP_REGEDIT="$APP_REGEDIT $registry_dump_init_file"
SCRIPT_DEPS="$SCRIPT_DEPS iconv"

# Load common functions

target_version='2.18'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

(
	content_path=$(content_path_default)
	cd "${PLAYIT_WORKDIR}/gamedata/${content_path}"

	# Set required registry keys
	mkdir --parents "$(dirname "$registry_dump_init_file")"
	printf '%s' "$registry_dump_init_content" | iconv \
		--from-code=UTF-8 --to-code=UTF-16 \
		--output="$registry_dump_init_file"
)

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

prepare_package_layout
## Include "Enhanced Edition" add-ons
PKG='PKG_DATA'
organize_data 'ADDONS' "${PATH_GAME}/addons"

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
