#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2020 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Vampire: The Masquerade - Redemption
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220327.7

# Set game-specific variables

GAME_ID='vampire-the-masquerade-redemption'
GAME_NAME='Vampire: The Masquerade - Redemption'

ARCHIVE_BASE_0='setup_vampire_the_masquerade_redemption_2.0.0.3.exe'
ARCHIVE_BASE_0_MD5='96c19b0ce487e53dd8fe24ef963d31fc'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='1300000'
ARCHIVE_BASE_0_VERSION='1.1-gog2.0.0.3'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/vampire_the_masquerade_redemption'

CONTENT_PATH_DEFAULT='app'
ARCHIVE_DOC_DATA_FILES='
*.pdf
*.rtf'
ARCHIVE_GAME_BIN_FILES='
*.dll
*.exe
*.inf
*.isu
extras/cs
miles'
ARCHIVE_GAME_DATA_FILES='
*.dat
*.nob
*.pub
*.zip
vampireankh.ico
chronicles
extras
sounds
video'

APP_MAIN_TYPE='wine'
APP_MAIN_EXE='vampire.exe'
APP_MAIN_ICON='vampireankh.ico'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID wine libGL.so.1"

# Use persistent storage for user data

CONFIG_FILES='./*.ini'
DATA_DIRS='./savegames'

# Prevent the game from messing up desktop gamma values

PKG_BIN_DEPS="${PKG_BIN_DEPS} xrandr"
APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
# Store current gamma values
SCREENS_ID=$(LANG=C xrandr | sed -n "s/^\\([^ ]*\\) connected\\( primary\\)\\? [0-9x+]\\+ .*$/\\1/p")
GAMMA_VALUE=$(LANG=C xrandr --verbose | sed -n "s/^\\s*Gamma:\\s*\\([0-9:.]*\\).*$/\\1/p" | head --lines=1)'
APP_MAIN_POSTRUN="$APP_MAIN_POSTRUN"'
# Restore previous gamma values
for screen_id in $SCREENS_ID; do
	xrandr --output $screen_id --gamma $GAMMA_VALUE
done'

# Load common functions

target_version='2.15'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Set required registry keys

PKG='PKG_BIN'
package_path=$(package_get_path "$PKG")

registry_dump_file='registry-dumps/init-vampire.reg'
registry_dump_path="${package_path}${PATH_GAME}/${registry_dump_file}"
registry_dump_directory=$(dirname "$registry_dump_path")
APP_REGEDIT="$APP_REGEDIT $registry_dump_file"

game_id=$(game_id)
installdir="C:\\\\${game_id}"
installdirexe="C:\\\\${game_id}\\\\vampire.exe"

mkdir --parents "$registry_dump_directory"

{
	cat <<- 'EOF'
	Windows Registry Editor Version 5.00

	[HKEY_LOCAL_MACHINE\Software\Activision\Vampire: The Masquerade - Redemption\v1.0]
	"CDDRIVE"="c:"
	EOF
	cat <<- EOF
	"INSTALLDIR"="${installdir}"
	"INSTALLDIREXE"="${installdirexe}"
	EOF
	cat <<- 'EOF'
	"INSTALLTYPE"=dword:00000002
	"Version"="0.1"

	[HKEY_LOCAL_MACHINE\Software\WON\CDKeys]
	"Vampire"=hex:4e,07,4a,bf,8e,4d,c1,71,9c,de,2b,b9,91,2e,a3,e9
	EOF
} > "$registry_dump_path"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Include game icon

PKG='PKG_DATA'
icons_get_from_package 'APP_MAIN'

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
