#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2021 Mopi
# SPDX-FileCopyrightText: © 2021 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Whispers of a Machine
# send your bug reports to contact@dotslashplay.it
###

script_version=20230322.1

GAME_ID='whispers-of-a-machine'
GAME_NAME='Whispers of a Machine'

ARCHIVE_BASE_0='setup_whispers_of_a_machine_1.0.6d_(35876).exe'
ARCHIVE_BASE_0_MD5='92244849a09e9b47a290618acd9dc9b6'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='770000'
ARCHIVE_BASE_0_VERSION='1.0.6d-gog35876'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/whispers_of_a_machine'

CONTENT_PATH_DEFAULT='.'
CONTENT_GAME_BIN_WINE_FILES='
*.dll
winsetup.exe'
CONTENT_GAME_DATA_FILES='
acsetup.cfg
whispers.exe
*.vox
*.tra'

APP_WINE_LINK_DIRS='
userdata:users/${USER}/Saved Games/Whispers of a Machine'
USER_PERSISTENT_FILES='
userdata/agssave.*
userdata/user.cfg'

APP_MAIN_ICONS_LIST='APP_MAIN_ICON'
APP_MAIN_ICON='whispers.exe'

APP_SCUMMVM_SCUMMID='ags:whispersofamachine'

APP_WINE_EXE='whispers.exe'

PACKAGES_LIST='PKG_BIN_SCUMMVM PKG_BIN_WINE PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ID="$GAME_ID"

PKG_BIN_WINE_ID="${PKG_BIN_ID}-wine"
PKG_BIN_WINE_PROVIDE="$PKG_BIN_ID"
PKG_BIN_WINE_ARCH='32'
PKG_BIN_WINE_DEPS="$PKG_DATA_ID"

PKG_BIN_SCUMMVM_ID="${PKG_BIN_ID}-scummvm"
PKG_BIN_SCUMMVM_PROVIDE="$PKG_BIN_ID"
PKG_BIN_SCUMMVM_DEPS="$PKG_DATA_ID scummvm"

# Load common functions

target_version='2.22'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_inclusion 'APP_MAIN'

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN_SCUMMVM'
launchers_write 'APP_SCUMMVM'

PKG='PKG_BIN_WINE'
## Bypass binary presence check,
## as it is provided by another package.
launcher_target_presence_check() { return 0 ; }
launchers_write 'APP_WINE'

# Build packages

write_metadata
build_pkg

# Print instructions

printf '\n'
printf 'ScummVM:'
print_instructions 'PKG_BIN_SCUMMVM' 'PKG_DATA'
printf 'WINE:'
print_instructions 'PKG_BIN_WINE' 'PKG_DATA'

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
